@@ -32,11 +32,9 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <ctype.h>
-#ifndef IS_MINGW
-#ifndef IS_SOLARIS
+#if !defined (IS_MINGW) && !defined (IS_SOLARIS) && !defined (__FreeBSD__)
 #include <endian.h>
 #endif
-#endif
 #include <sys/stat.h>
 #include <pthread.h>
 
@@ -921,7 +919,7 @@ static void detach_stream (lives_clip_data_t *cdata) {
     av_free(priv->ctx);
   }
 
-  if (priv->picture!=NULL) av_free(priv->picture);
+  if (priv->picture!=NULL) av_frame_free(&priv->picture);
 
   priv->ctx=NULL;
   priv->picture=NULL;
@@ -1464,7 +1462,7 @@ static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
 	  if (priv->st->codec->extradata_size && (priv->st->codec->bits_per_coded_sample <= 8)) {
 
 
-#ifndef IS_MINGW
+#if !defined (IS_MINGW) && !defined (IS_SOLARIS) && !defined (__FreeBSD__)
 # if __BYTE_ORDER == __BIG_ENDIAN
             int i;
             for (i = 0; i < FFMIN(priv->st->codec->extradata_size, AVPALETTE_SIZE)/4; i++)
@@ -2163,7 +2161,7 @@ static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
   pthread_mutex_unlock(&priv->idxc->mutex);
   priv->def_packet_size=priv->asf->hdr.max_pktsize*10;
 
-  priv->picture = avcodec_alloc_frame();
+  priv->picture = av_frame_alloc();
 
   do {
     if (priv->avpkt.data!=NULL) free(priv->avpkt.data);
@@ -2560,7 +2558,7 @@ static lives_clip_data_t *asf_clone(lives_clip_data_t *cdata) {
 
   }
 
-  if (dpriv->picture!=NULL) av_free(dpriv->picture);
+  if (dpriv->picture!=NULL) av_frame_free(&dpriv->picture);
   dpriv->picture=NULL;
 
   return clone;
@@ -2636,7 +2634,7 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
   cdata->asigned=TRUE;
   cdata->ainterleaf=TRUE;
 
-  if (priv->picture!=NULL) av_free(priv->picture);
+  if (priv->picture!=NULL) av_frame_free(&priv->picture);
   priv->picture=NULL;
 
   return cdata;
@@ -2762,7 +2760,7 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
 
   if (tframe!=priv->last_frame) {
 
-    if (priv->picture!=NULL) av_free(priv->picture);
+    if (priv->picture!=NULL) av_frame_free(&priv->picture);
     priv->picture=NULL;
 
     if (priv->last_frame==-1 || (tframe<priv->last_frame) || (tframe - priv->last_frame > rescan_limit)) {
@@ -2826,7 +2824,7 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
 
 
       // decode any frames from this packet
-      if (priv->picture==NULL) priv->picture=avcodec_alloc_frame();
+      if (priv->picture==NULL) priv->picture=av_frame_alloc();
 
 #if LIBAVCODEC_VERSION_MAJOR >= 53
       avcodec_decode_video2( priv->ctx, priv->picture, &got_picture, &priv->avpkt );
@@ -2844,7 +2842,7 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
 
       // otherwise discard this frame
       if (got_picture) {
-	av_free(priv->picture);
+	av_frame_free(&priv->picture);
 	priv->picture=NULL;
 	tfrag=-1;
 	nextframe++;
