@@ -610,7 +610,7 @@ static void detach_stream (lives_clip_data_t *cdata) {
   if (priv->idxc!=NULL) idxc_release(cdata);
   priv->idxc=NULL;
 
-  if (priv->picture!=NULL) av_free(priv->picture);
+  if (priv->picture!=NULL) av_frame_free(&priv->picture);
 
   priv->ctx=NULL;
   priv->codec=NULL;
@@ -1147,7 +1147,7 @@ static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
   priv->avpkt.data = pack.data;
   priv->avpkt.dts=priv->avpkt.pts=pack.dts;
 
-  priv->picture = avcodec_alloc_frame();
+  priv->picture = av_frame_alloc();
 
   while (!got_picture) {
     int len;
@@ -1478,11 +1478,10 @@ static lives_clip_data_t *flv_clone(lives_clip_data_t *cdata) {
 
   }
 
-  if (dpriv->picture!=NULL) av_free(dpriv->picture);
+  if (dpriv->picture!=NULL) av_frame_free(&dpriv->picture);
   dpriv->picture=NULL;
 
   dpriv->last_frame=-1;
-  dpriv->picture=NULL;
   dpriv->avpkt.data=NULL;
   dpriv->avpkt.size=0;
 
@@ -1561,7 +1560,7 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
   cdata->asigned=TRUE;
   cdata->ainterleaf=TRUE;
 
-  if (priv->picture!=NULL) av_free(priv->picture);
+  if (priv->picture!=NULL) av_frame_free(&priv->picture);
   priv->picture=NULL;
 
   if (cdata->width!=cdata->frame_width||cdata->height!=cdata->frame_height)
@@ -1711,7 +1710,7 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
     priv->ctx->skip_frame=AVDISCARD_NONREF;
 
     priv->last_frame=tframe;
-    if (priv->picture==NULL) priv->picture = avcodec_alloc_frame();
+    if (priv->picture==NULL) priv->picture = av_frame_alloc();
 
 
     // do this until we reach target frame //////////////
