@@ -190,6 +190,11 @@
 #define av_new_stream(a, b) avformat_new_stream(a, NULL)
 #endif
 
+#if HAVE_AVFORMAT_CLOSE_INPUT
+#define av_close_input_file(a) avformat_close_input(&a)
+#endif
+
+
 #if !HAVE_AV_SET_PTS_INFO
 #if HAVE_AVFORMAT_INTERNAL_H
 
@@ -221,6 +226,14 @@ static void av_set_pts_info(AVStream *s, int pts_wrap_bits,
 #endif
 #endif
 
+
+#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(55,28,1)
+#define av_frame_alloc  avcodec_alloc_frame
+#define av_frame_free  avcodec_free_frame
+#endif
+
+
+
 #endif // HAVE_LIBAV_LIBS
 
 #endif // HAVE_LIBAV_HELPER_H
