@@ -1,6 +1,6 @@
 // audio.c
 // LiVES (lives-exe)
-// (c) G. Finch 2005 - 2012
+// (c) G. Finch 2005 - 2014
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -62,14 +62,142 @@ void audio_free_fnames(void) {
 }
 
 
+void append_to_audio_bufferf(lives_audio_buf_t *abuf, float *src, uint64_t nsamples, int channum) { 
+  // append float audio to the audio frame buffer
+  size_t nsampsize;
+
+  if (!prefs->push_audio_to_gens) return;
+
+  if (abuf->bufferf==NULL) free_audio_frame_buffer(abuf);
+
+  nsampsize=(abuf->samples_filled+nsamples)*sizeof(float);
+
+  channum++;
+  if (channum>abuf->out_achans) {
+    register int i;
+    abuf->bufferf=(float **)g_realloc(abuf->bufferf,channum*sizeof(float *));
+    for (i=abuf->out_achans;i<channum;i++) {
+      abuf->bufferf[i]=NULL;
+    }
+    abuf->out_achans=channum;
+  }
+  channum--;
+  abuf->bufferf[channum]=(float *)g_realloc(abuf->bufferf[channum],nsampsize);
+  lives_memcpy(&abuf->bufferf[channum][abuf->samples_filled],src,nsamples*sizeof(float));
+}
+
+
+
+void append_to_audio_buffer16(lives_audio_buf_t *abuf, void *src, uint64_t nsamples, int channum) { 
+  // append 16 bit audio to the audio frame buffer
+  size_t nsampsize;
+
+  if (!prefs->push_audio_to_gens) return;
+
+  if (abuf->buffer16==NULL) free_audio_frame_buffer(abuf);
+
+  nsampsize=(abuf->samples_filled+nsamples)*2;
+  channum++;
+  if (abuf->buffer16==NULL||channum>abuf->out_achans) {
+    register int i;
+    abuf->buffer16=(int16_t **)g_realloc(abuf->buffer16,channum*sizeof(int16_t *));
+    for (i=abuf->out_achans;i<channum;i++) {
+      abuf->buffer16[i]=NULL;
+    }
+    abuf->out_achans=channum;
+  }
+  channum--;
+  abuf->buffer16[channum]=(int16_t *)g_realloc(abuf->buffer16[channum],nsampsize);
+  lives_memcpy(&abuf->buffer16[channum][abuf->samples_filled],src,nsamples*2);
+#ifdef DEBUG_AFB
+  g_print("append16 to afb\n");
+#endif
+}
+
+
+
+void init_audio_frame_buffer(short aplayer) {
+  // function should be called when the first video generator with audio input is enabled
+
+  lives_audio_buf_t *abuf;
+  abuf=mainw->audio_frame_buffer=(lives_audio_buf_t *)g_malloc0(sizeof(lives_audio_buf_t));
+
+  abuf->samples_filled=0;
+  abuf->swap_endian=FALSE;
+  abuf->out_achans=0;
+
+  switch (aplayer) {
+#ifdef HAVE_PULSE_AUDIO
+  case AUD_PLAYER_PULSE:
+    abuf->in_interleaf=TRUE;
+    abuf->s16_signed=TRUE;
+    abuf->arate=mainw->pulsed->out_arate;
+    break;
+#endif
+#ifdef ENABLE_JACK
+  case AUD_PLAYER_JACK:
+    abuf->in_interleaf=FALSE;
+    abuf->out_interleaf=FALSE;
+    abuf->arate=mainw->jackd->sample_out_rate;
+    break;
+#endif
+  default:
+    break;
+  }
+#ifdef DEBUG_AFB
+  g_print("init afb\n");
+#endif
+}
+
+
+
+void free_audio_frame_buffer(lives_audio_buf_t *abuf) {
+  // function should be called to clear samples
+  register int i;
+  if (abuf!=NULL) {
+    if (abuf->bufferf!=NULL) {
+      for (i=0;i<abuf->out_achans;i++) g_free(abuf->bufferf[i]);
+      g_free(abuf->bufferf);
+      abuf->bufferf=NULL;
+    }
+    if (abuf->buffer32!=NULL) {
+      for (i=0;i<abuf->out_achans;i++) g_free(abuf->buffer32[i]);
+      g_free(abuf->buffer32);
+      abuf->buffer32=NULL;
+    }
+    if (abuf->buffer24!=NULL) {
+      for (i=0;i<abuf->out_achans;i++) g_free(abuf->buffer24[i]);
+      g_free(abuf->buffer24);
+      abuf->buffer24=NULL;
+    }
+    if (abuf->buffer16!=NULL) {
+      for (i=0;i<abuf->out_achans;i++) g_free(abuf->buffer16[i]);
+      g_free(abuf->buffer16);
+      abuf->buffer16=NULL;
+    }
+    if (abuf->buffer8!=NULL) {
+      for (i=0;i<abuf->out_achans;i++) g_free(abuf->buffer8[i]);
+      g_free(abuf->buffer8);
+      abuf->buffer8=NULL;
+    }
+
+    abuf->samples_filled=0;
+    abuf->out_achans=0;
+  }
+#ifdef DEBUG_AFB
+  g_print("clear afb\n");
+#endif
+}
+
 
 
 LIVES_INLINE void sample_silence_dS (float *dst, uint64_t nsamples) {
+  // send silence to the jack player
   memset(dst,0,nsamples*sizeof(float));
 }
 
 
-void sample_move_d8_d16(short *dst, unsigned char *src,
+void sample_move_d8_d16(short *dst, uint8_t *src,
 			uint64_t nsamples, size_t tbytes, float scale, int nDstChannels, int nSrcChannels, int swap_sign) {
   // convert 8 bit audio to 16 bit audio
 
@@ -124,14 +252,14 @@ void sample_move_d8_d16(short *dst, unsigned char *src,
 
 
 /* convert from any number of source channels to any number of destination channels - both interleaved */
-void sample_move_d16_d16(short *dst, short *src,
+void sample_move_d16_d16(int16_t *dst, int16_t *src,
 			 uint64_t nsamples, size_t tbytes, float scale, int nDstChannels, int nSrcChannels, int swap_endian, int swap_sign) {
   register int nSrcCount, nDstCount;
   register float src_offset_f=0.f;
   register int src_offset_i=0;
   register int ccount=0;
-  short *ptr;
-  short *src_end;
+  int16_t *ptr;
+  int16_t *src_end;
 
   if(!nSrcChannels) return;
 
@@ -151,7 +279,7 @@ void sample_move_d16_d16(short *dst, short *src,
       ptr=src+src_offset_i;
       ptr=ptr>src?(ptr<src_end?ptr:src_end):src;
 
-      lives_memcpy(dst,ptr,nSrcChannels*sizeof(short));
+      lives_memcpy(dst,ptr,nSrcChannels*2);
       dst+=nDstCount;
     } 
     else {
@@ -317,13 +445,16 @@ void sample_move_d16_float (float *dst, short *src, uint64_t nsamples, uint64_t
 
 
 
-void sample_move_float_float (float *dst, float *src, uint64_t nsamples, uint64_t src_skip, float vol) {
-  // copy one channel of (interleaved) float to a buffer, applying the volume
+void sample_move_float_float (float *dst, float *src, uint64_t nsamples, float scale, int dst_skip) {
+  // copy one channel of float to a buffer, applying the scale (scale 2.0 to double the rate, etc)
+  size_t offs=0;
+  float offs_f=0.;
   register int i;
 
   for (i=0;i<nsamples;i++) {
-    *(dst++)=*src*vol;
-    src+=src_skip;
+    *dst=src[offs];
+    dst+=dst_skip;
+    offs=(size_t)(offs_f+=scale);
   }
 }
 
@@ -1345,7 +1476,6 @@ void jack_rec_audio_to_clip(int fileno, int old_file, lives_rec_audio_type_t rec
       
       // start jack recording
 
-      // TODO - only if not active
       if (!jackd_read_started) {
 	jack_open_device_read(mainw->jackd_read);
 	jack_read_driver_activate(mainw->jackd_read,FALSE);
@@ -1414,17 +1544,21 @@ void jack_rec_audio_to_clip(int fileno, int old_file, lives_rec_audio_type_t rec
     on_playsel_activate(NULL,NULL);
     mainw->current_file=current_file;
   }
-  jack_rec_audio_end(TRUE);
+  jack_rec_audio_end(!(prefs->perm_audio_reader&&prefs->audio_src==AUDIO_SRC_EXT),TRUE);
 }
 
 
 
-void jack_rec_audio_end(boolean close_fd) {
+void jack_rec_audio_end(boolean close_device, boolean close_fd) {
   // recording ended
 
-  // stop recording
-  if (mainw->jackd_read!=NULL) jack_close_device(mainw->jackd_read);
-  mainw->jackd_read=NULL;
+  if (close_device) {
+    // stop recording
+    if (mainw->jackd_read!=NULL) jack_close_device(mainw->jackd_read);
+    mainw->jackd_read=NULL;
+  }
+  else mainw->jackd_read->in_use=FALSE;
+
 
   if (close_fd&&mainw->aud_rec_fd!=-1) {
     // close file
@@ -1558,24 +1692,28 @@ void pulse_rec_audio_to_clip(int fileno, int old_file, lives_rec_audio_type_t re
     on_playsel_activate(NULL,NULL);
     mainw->current_file=current_file;
   }
-  pulse_rec_audio_end(TRUE);
+  pulse_rec_audio_end(!(prefs->perm_audio_reader&&prefs->audio_src==AUDIO_SRC_EXT),TRUE);
 }
 
 
 
-void pulse_rec_audio_end(boolean close_fd) {
+void pulse_rec_audio_end(boolean close_device, boolean close_fd) {
   // recording ended
 
   // stop recording
 
   if (mainw->pulsed_read!=NULL) {
     pa_threaded_mainloop_lock(mainw->pulsed_read->mloop);
+
     if (mainw->pulsed_read->playing_file>-1)
       pulse_flush_read_data(mainw->pulsed_read,mainw->pulsed_read->playing_file,0,mainw->pulsed_read->reverse_endian,NULL);
-    pulse_close_client(mainw->pulsed_read);
+
+    if (close_device) pulse_close_client(mainw->pulsed_read);
+
     pa_threaded_mainloop_unlock(mainw->pulsed_read->mloop);
 
-    mainw->pulsed_read=NULL;
+    if (close_device) mainw->pulsed_read=NULL;
+    else mainw->pulsed_read->in_use=FALSE;
   }
 
   if (mainw->aud_rec_fd!=-1&&close_fd) {
@@ -2424,6 +2562,8 @@ lives_audio_buf_t *audio_cache_init (void) {
 
 
 void audio_cache_end (void) {
+  // TODO - check why we are using free() here
+
   int i;
   lives_audio_buf_t *xcache_buffer;
 
@@ -2809,6 +2949,139 @@ boolean apply_rte_audio(int nframes) {
 
 
 
+boolean push_audio_to_channel(weed_plant_t *achan, lives_audio_buf_t *abuf) {
+  // push audio from abuf into an audio channel
+  // audio will be formatted to the channel requested format
+
+  // NB: if player is jack, we will have non-interleaved float
+  // if player is pulse, we will have interleaved S16
+  void *dst,*src;
+
+  weed_plant_t *ctmpl;
+
+  float scale;
+
+  size_t samps,offs;
+
+  boolean tinter;
+  int trate,tlen,tchans;
+  int alen;
+  int error;
+
+  register int i;
+
+  if (abuf->samples_filled==0) {
+    weed_set_int_value(achan,"audio_data_length",0);
+    weed_set_voidptr_value(achan,"audio_data",NULL);
+    return FALSE;
+  }
+
+  ctmpl=weed_get_plantptr_value(achan,"template",&error);
+
+  if (weed_plant_has_leaf(achan,"audio_rate")) trate=weed_get_int_value(achan,"audio_rate",&error);
+  else if (weed_plant_has_leaf(ctmpl,"audio_rate")) trate=weed_get_int_value(ctmpl,"audio_rate",&error);
+  else trate=DEFAULT_AUDIO_RATE;
+
+  if (weed_plant_has_leaf(achan,"audio_channels")) tchans=weed_get_int_value(achan,"audio_channels",&error);
+  else if (weed_plant_has_leaf(ctmpl,"audio_channels")) tchans=weed_get_int_value(ctmpl,"audio_channels",&error);
+  else tchans=DEFAULT_AUDIO_CHANS;
+
+  if (weed_plant_has_leaf(achan,"audio_interleaf")) tinter=weed_get_boolean_value(achan,"audio_interleaf",&error);
+  else if (weed_plant_has_leaf(ctmpl,"audio_interleaf")) tinter=weed_get_boolean_value(ctmpl,"audio_interleaf",&error);
+  else tinter=FALSE;
+
+  if (weed_plant_has_leaf(ctmpl,"audio_data_length")) tlen=weed_get_int_value(ctmpl,"audio_data_length",&error);
+  else tlen=0;
+
+#ifdef DEBUG_AFB
+  g_print("push from afb %d\n",abuf->samples_filled);
+#endif
+
+  // plugin will get float, so we first convert to that
+  if (abuf->bufferf==NULL) {
+    // try 8 bit -> 16 -> float
+    if (abuf->buffer8!=NULL&&abuf->buffer16==NULL) {
+      int swap=0;
+      if (!abuf->s8_signed) swap=SWAP_U_TO_S;
+      abuf->s16_signed=TRUE;
+      abuf->buffer16=(int16_t **)g_malloc(abuf->out_achans*sizeof(int16_t *));
+      for (i=0;i<abuf->out_achans;i++) {
+	abuf->bufferf[i]=(float *)g_malloc(abuf->samples_filled*2);
+	sample_move_d8_d16 (abuf->buffer16[i],abuf->buffer8[i], abuf->samples_filled, abuf->samples_filled*2, 
+			    1.0, abuf->out_achans, abuf->out_achans, swap);
+
+      }
+    }
+
+
+    // try convert S16 -> float
+    if (abuf->buffer16!=NULL) {
+      abuf->bufferf=(float **)g_malloc(abuf->out_achans*sizeof(float *));
+      for (i=0;i<abuf->out_achans;i++) {
+	abuf->bufferf[i]=(float *)g_malloc(abuf->samples_filled*sizeof(float));
+	if (!abuf->in_interleaf) {
+	  sample_move_d16_float(abuf->bufferf[i],abuf->buffer16[i],abuf->samples_filled,1,
+				(abuf->s16_signed?AFORM_SIGNED:AFORM_UNSIGNED),abuf->swap_endian,1.0);
+	}
+	else {
+	  sample_move_d16_float(abuf->bufferf[i],&abuf->buffer16[0][i],abuf->samples_filled,abuf->out_achans,
+				(abuf->s16_signed?AFORM_SIGNED:AFORM_UNSIGNED),abuf->swap_endian,1.0);
+	}
+      }
+      abuf->out_interleaf=FALSE;
+    }
+  }
+
+  if (abuf->bufferf==NULL) return FALSE;
+  // now we should have float
+
+  samps=abuf->samples_filled;
+
+  // push to achan "audio_data", taking into account "audio_data_length", "audio_interleaf", "audio_channels"
+
+  alen=samps;
+  if (alen>tlen&&tlen>0) alen=tlen;
+
+  offs=samps-alen;
+
+  scale=(float)trate/(float)abuf->arate;
+
+  // malloc audio_data
+  dst=g_malloc(alen*tchans*sizeof(float));
+
+  // set channel values
+  weed_set_voidptr_value(achan,"audio_data",dst);
+  weed_set_boolean_value(achan,"audio_interleaf",tinter);
+  weed_set_int_value(achan,"audio_data_length",alen);
+  weed_set_int_value(achan,"audio_channels",tchans);
+  weed_set_int_value(achan,"audio_rate",trate);
+
+  // copy data from abuf->bufferf[] to "audio_data"
+  for (i=0;i<tchans;i++) {
+    src=abuf->bufferf[i%abuf->out_achans]+offs;
+    if (!tinter) {
+      if ((int)abuf->arate==trate) {
+	lives_memcpy(dst,src,alen*sizeof(float));
+      }
+      else {
+	// needs resample
+	sample_move_float_float((float *)dst,(float *)src,alen,scale,1);
+      }
+      dst+=alen*sizeof(float);
+    }
+    else {
+      // interleaved
+      for (i=0;i<tchans;i++) {
+	sample_move_float_float((float *)dst,(float *)src,alen,scale,tchans);
+	dst+=sizeof(float);
+      }
+    }
+  }
+  return TRUE;
+}
+
+
+
 
 ////////////////////////////////////////
 // audio streaming
