@@ -111,6 +111,10 @@ typedef struct {
   int32_t **buffer32; ///< sample data in 32 bit format (or NULL)
   float   **bufferf; ///< sample data in float format (or NULL)
 
+  boolean s8_signed;
+  boolean s16_signed;
+  boolean s24_signed;
+  boolean s32_signed;
   
   // ring buffer 
   size_t samples_filled; ///< number of samples filled (readonly client)
@@ -163,7 +167,7 @@ int64_t sample_move_abuf_float (float **obuf, int nchans, int nsamps, int out_ar
 
 int64_t sample_move_abuf_int16 (short *obuf, int nchans, int nsamps, int out_arate);
 
-void sample_move_float_float (float *dst, float *src, uint64_t nsamples, uint64_t src_skip, float vol);
+void sample_move_float_float (float *dst, float *src, uint64_t nsamples, float scale, int dst_skip);
 
 boolean float_deinterleave(float *fbuffer, int nsamps, int nchans);
 boolean float_interleave(float *fbuffer, int nsamps, int nchans);
@@ -182,12 +186,12 @@ typedef enum {
 
 #ifdef ENABLE_JACK
 void jack_rec_audio_to_clip(int fileno, int oldfileno, lives_rec_audio_type_t rec_type);  ///< record from external source to clip
-void jack_rec_audio_end(boolean close_fd);
+void jack_rec_audio_end(boolean close_dev, boolean close_fd);
 #endif
 
 #ifdef HAVE_PULSE_AUDIO
 void pulse_rec_audio_to_clip(int fileno, int oldfileno, lives_rec_audio_type_t rec_type);  ///< record from external source to clip
-void pulse_rec_audio_end(boolean close_fd);
+void pulse_rec_audio_end(boolean close_dev, boolean close_fd);
 #endif
 
 void fill_abuffer_from(lives_audio_buf_t *abuf, weed_plant_t *event_list, weed_plant_t *st_event, boolean exact);
@@ -217,6 +221,12 @@ boolean apply_rte_audio_init(void);
 void apply_rte_audio_end(boolean del);
 boolean apply_rte_audio(int nframes);
 
+void init_audio_frame_buffer(short aplayer);
+void free_audio_frame_buffer(lives_audio_buf_t *abuf);
+void append_to_audio_bufferf(lives_audio_buf_t *abuf, float *src, uint64_t nsamples, int channum);
+void append_to_audio_buffer16(lives_audio_buf_t *abuf, void *src, uint64_t nsamples, int channum);
+boolean push_audio_to_channel(weed_plant_t *achan, lives_audio_buf_t *abuf);
+
 boolean start_audio_stream(void);
 void stop_audio_stream(void);
 void clear_audio_stream(void);
