@@ -26,7 +26,7 @@ static volatile boolean b1_held;
 
 static volatile boolean noupdate=FALSE;
 
-static GtkWidget *fbord_eventbox;
+static LiVESWidget *fbord_eventbox;
 
 
 static double calc_fd_scale(int width, int height) {
@@ -45,7 +45,7 @@ static double calc_fd_scale(int width, int height) {
 
 }
 
-static void start_preview (GtkButton *button, lives_rfx_t *rfx) {
+static void start_preview (LiVESButton *button, lives_rfx_t *rfx) {
   int i;
   gchar *com;
 
@@ -116,8 +116,8 @@ static void start_preview (GtkButton *button, lives_rfx_t *rfx) {
 void framedraw_connect_spinbutton(lives_special_framedraw_rect_t *framedraw, lives_rfx_t *rfx) {
   framedraw->rfx=rfx;
 
-  g_signal_connect_after (GTK_OBJECT (mainw->framedraw_spinbutton), "value_changed",
-			  G_CALLBACK (after_framedraw_frame_spinbutton_changed),
+  lives_signal_connect_after (LIVES_GUI_OBJECT (mainw->framedraw_spinbutton), "value_changed",
+			  LIVES_GUI_CALLBACK (after_framedraw_frame_spinbutton_changed),
 			  framedraw);
 
 }
@@ -128,17 +128,17 @@ void framedraw_connect(lives_special_framedraw_rect_t *framedraw, int width, int
 
 
   // add mouse fn's so we can draw on frames
-  g_signal_connect (GTK_OBJECT (mainw->framedraw), "motion_notify_event",
-		    G_CALLBACK (on_framedraw_mouse_update),
+  lives_signal_connect (LIVES_GUI_OBJECT (mainw->framedraw), "motion_notify_event",
+		    LIVES_GUI_CALLBACK (on_framedraw_mouse_update),
 		    framedraw);
-  g_signal_connect (GTK_OBJECT (mainw->framedraw), "button_release_event",
-		    G_CALLBACK (on_framedraw_mouse_reset),
+  lives_signal_connect (LIVES_GUI_OBJECT (mainw->framedraw), "button_release_event",
+		    LIVES_GUI_CALLBACK (on_framedraw_mouse_reset),
 		    framedraw);
-  g_signal_connect (GTK_OBJECT (mainw->framedraw), "button_press_event",
-		    G_CALLBACK (on_framedraw_mouse_start),
+  lives_signal_connect (LIVES_GUI_OBJECT (mainw->framedraw), "button_press_event",
+		    LIVES_GUI_CALLBACK (on_framedraw_mouse_start),
 		    framedraw);
-  g_signal_connect (GTK_OBJECT(mainw->framedraw), "enter-notify-event",G_CALLBACK (on_framedraw_enter),framedraw);
-  g_signal_connect (GTK_OBJECT(mainw->framedraw), "leave-notify-event",G_CALLBACK (on_framedraw_leave),framedraw);
+  lives_signal_connect (LIVES_GUI_OBJECT(mainw->framedraw), "enter-notify-event",LIVES_GUI_CALLBACK (on_framedraw_enter),framedraw);
+  lives_signal_connect (LIVES_GUI_OBJECT(mainw->framedraw), "leave-notify-event",LIVES_GUI_CALLBACK (on_framedraw_leave),framedraw);
 
   framedraw_connect_spinbutton(framedraw,rfx);
 
@@ -150,7 +150,7 @@ void framedraw_connect(lives_special_framedraw_rect_t *framedraw, int width, int
 
 
 void framedraw_add_label(LiVESVBox *box) {
-  GtkWidget *label;
+  LiVESWidget *label;
 
   // TRANSLATORS - Preview refers to preview window; keep this phrase short
   label=lives_standard_label_new(_("You can click in Preview to change these values"));
@@ -159,24 +159,24 @@ void framedraw_add_label(LiVESVBox *box) {
 
 
 void framedraw_add_reset(LiVESVBox *box, lives_special_framedraw_rect_t *framedraw) {
-  GtkWidget *hbox_rst;
+  LiVESWidget *hbox_rst;
  
   framedraw_add_label(box);
 
-  mainw->framedraw_reset = lives_button_new_from_stock ("gtk-refresh");
+  mainw->framedraw_reset = lives_button_new_from_stock (LIVES_STOCK_REFRESH);
   hbox_rst = lives_hbox_new (FALSE, 0);
   lives_box_pack_start (LIVES_BOX (box), hbox_rst, FALSE, FALSE, 0);
   
-  lives_button_set_label (GTK_BUTTON (mainw->framedraw_reset),_ ("_Reset Values"));
-  gtk_button_set_use_underline (GTK_BUTTON (mainw->framedraw_reset), TRUE);
+  lives_button_set_label (LIVES_BUTTON (mainw->framedraw_reset),_ ("_Reset Values"));
+  lives_button_set_use_underline (LIVES_BUTTON (mainw->framedraw_reset), TRUE);
   lives_box_pack_start (LIVES_BOX (hbox_rst), mainw->framedraw_reset, TRUE, FALSE, 0);
   lives_widget_set_sensitive (mainw->framedraw_reset,FALSE);
   
-  g_signal_connect (mainw->framedraw_reset, "clicked",G_CALLBACK (on_framedraw_reset_clicked),framedraw);
+  lives_signal_connect (mainw->framedraw_reset, LIVES_WIDGET_CLICKED_EVENT,LIVES_GUI_CALLBACK (on_framedraw_reset_clicked),framedraw);
 }
 
 
-static boolean expose_fd_event (GtkWidget *widget, GdkEventExpose ev) {
+static boolean expose_fd_event (LiVESWidget *widget, GdkEventExpose ev) {
   redraw_framedraw_image();
   return TRUE;
 }
@@ -188,12 +188,12 @@ void widget_add_framedraw (LiVESVBox *box, int start, int end, boolean add_previ
 
   // an example of this is in 'trim frames'
 
-  GtkWidget *vseparator;
-  GtkWidget *vbox;
-  GtkWidget *hbox;
-  GtkWidget *label;
-  GtkAdjustment *spinbutton_adj;
-  GtkWidget *frame;
+  LiVESWidget *vseparator;
+  LiVESWidget *vbox;
+  LiVESWidget *hbox;
+  LiVESWidget *label;
+  LiVESAdjustment *spinbutton_adj;
+  LiVESWidget *frame;
  
   lives_rfx_t *rfx;
 
@@ -222,7 +222,7 @@ void widget_add_framedraw (LiVESVBox *box, int start, int end, boolean add_previ
   fbord_eventbox=lives_event_box_new();
   lives_container_set_border_width(LIVES_CONTAINER(fbord_eventbox),widget_opts.border_width);
 
-  frame = gtk_frame_new (NULL);
+  frame = lives_frame_new (NULL);
 
   add_fill_to_box(LIVES_BOX(hbox));
   lives_box_pack_start (LIVES_BOX (hbox), frame, FALSE, FALSE, 0);
@@ -236,16 +236,16 @@ void widget_add_framedraw (LiVESVBox *box, int start, int end, boolean add_previ
   mainw->fd_frame=frame;
 
   label = lives_standard_label_new (_("Preview"));
-  gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+  lives_frame_set_label_widget (LIVES_FRAME (frame), label);
 
-  gtk_frame_set_shadow_type (GTK_FRAME(frame), LIVES_SHADOW_NONE);
+  lives_frame_set_shadow_type (LIVES_FRAME(frame), LIVES_SHADOW_NONE);
 
   mainw->framedraw=lives_event_box_new();
   lives_widget_set_size_request (mainw->framedraw, width, height);
   lives_container_set_border_width(LIVES_CONTAINER(mainw->framedraw),1);
 
-  gtk_widget_set_events (mainw->framedraw, GDK_BUTTON1_MOTION_MASK | GDK_BUTTON_RELEASE_MASK | 
-			 GDK_BUTTON_PRESS_MASK| GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);
+  lives_widget_set_events (mainw->framedraw, LIVES_BUTTON1_MOTION_MASK | LIVES_BUTTON_RELEASE_MASK | 
+			 LIVES_BUTTON_PRESS_MASK| LIVES_ENTER_NOTIFY_MASK | LIVES_LEAVE_NOTIFY_MASK);
 
   mainw->framedraw_frame=start;
 
@@ -257,8 +257,8 @@ void widget_add_framedraw (LiVESVBox *box, int start, int end, boolean add_previ
     lives_widget_set_fg_color (mainw->framedraw, LIVES_WIDGET_STATE_NORMAL, &palette->normal_fore);
   }
 
-  g_signal_connect_after (GTK_OBJECT (mainw->framedraw), LIVES_WIDGET_EVENT_EXPOSE_EVENT,
-			  G_CALLBACK (expose_fd_event), NULL);
+  lives_signal_connect_after (LIVES_GUI_OBJECT (mainw->framedraw), LIVES_WIDGET_EXPOSE_EVENT,
+			  LIVES_GUI_CALLBACK (expose_fd_event), NULL);
 
 
   hbox = lives_hbox_new (FALSE, 2);
@@ -267,20 +267,20 @@ void widget_add_framedraw (LiVESVBox *box, int start, int end, boolean add_previ
   mainw->framedraw_spinbutton = lives_standard_spin_button_new (_("_Frame"),
 								TRUE,start,start,end,1.,10.,0,LIVES_BOX(hbox),NULL);
 
-  spinbutton_adj=gtk_spin_button_get_adjustment(LIVES_SPIN_BUTTON(mainw->framedraw_spinbutton));
+  spinbutton_adj=lives_spin_button_get_adjustment(LIVES_SPIN_BUTTON(mainw->framedraw_spinbutton));
 
   mainw->framedraw_scale=lives_hscale_new(LIVES_ADJUSTMENT(spinbutton_adj));
   lives_box_pack_start (LIVES_BOX (hbox), mainw->framedraw_scale, TRUE, TRUE, 0);
   gtk_scale_set_draw_value(GTK_SCALE(mainw->framedraw_scale),FALSE);
 
   rfx=(lives_rfx_t *)g_object_get_data(G_OBJECT(lives_widget_get_toplevel(LIVES_WIDGET(box))),"rfx");
-  mainw->framedraw_preview = lives_button_new_from_stock ("gtk-refresh");
-  lives_button_set_label (GTK_BUTTON (mainw->framedraw_preview),_ ("_Preview"));
-  gtk_button_set_use_underline (GTK_BUTTON (mainw->framedraw_preview), TRUE);
+  mainw->framedraw_preview = lives_button_new_from_stock (LIVES_STOCK_REFRESH);
+  lives_button_set_label (LIVES_BUTTON (mainw->framedraw_preview),_ ("_Preview"));
+  lives_button_set_use_underline (LIVES_BUTTON (mainw->framedraw_preview), TRUE);
   lives_box_pack_start (LIVES_BOX (hbox), mainw->framedraw_preview, TRUE, FALSE, 0);
   lives_widget_set_sensitive(mainw->framedraw_spinbutton,FALSE);
   lives_widget_set_sensitive(mainw->framedraw_scale,FALSE);
-  g_signal_connect (mainw->framedraw_preview, "clicked",G_CALLBACK (start_preview),rfx);
+  lives_signal_connect (mainw->framedraw_preview, LIVES_WIDGET_CLICKED_EVENT,LIVES_GUI_CALLBACK (start_preview),rfx);
   
   lives_widget_show_all (vbox);
 
@@ -292,7 +292,7 @@ void widget_add_framedraw (LiVESVBox *box, int start, int end, boolean add_previ
 
 
 
-void framedraw_redraw (lives_special_framedraw_rect_t * framedraw, boolean reload, GdkPixbuf *pixbuf) {
+void framedraw_redraw (lives_special_framedraw_rect_t * framedraw, boolean reload, LiVESPixbuf *pixbuf) {
   // this will draw the mask (framedraw_bitmap) and optionally reload the image
   // and then combine them
 
@@ -638,7 +638,7 @@ void load_rfx_preview(lives_rfx_t *rfx) {
 
 
 
-void after_framedraw_frame_spinbutton_changed (GtkSpinButton *spinbutton, lives_special_framedraw_rect_t *framedraw) {
+void after_framedraw_frame_spinbutton_changed (LiVESSpinButton *spinbutton, lives_special_framedraw_rect_t *framedraw) {
   // update the single frame/framedraw preview
   // after the "frame number" spinbutton has changed
   mainw->framedraw_frame=lives_spin_button_get_value_as_int(spinbutton);
@@ -684,7 +684,7 @@ void load_framedraw_image(LiVESPixbuf *pixbuf) {
       mainw->do_not_free=(gpointer)lives_pixbuf_get_pixels_readonly(pixbuf);
       mainw->free_fn=lives_free_with_check;
     }
-    g_object_unref(pixbuf);
+    lives_object_unref(pixbuf);
     mainw->do_not_free=NULL;
     mainw->free_fn=lives_free_normal;
 
@@ -746,7 +746,7 @@ void redraw_framedraw_image(void) {
     mainw->free_fn=lives_free_with_check;
   }
 
-  g_object_unref(pixbuf);
+  lives_object_unref(pixbuf);
   mainw->do_not_free=NULL;
   mainw->free_fn=lives_free_normal;
 
@@ -756,7 +756,7 @@ void redraw_framedraw_image(void) {
 
 // change cursor maybe when we enter or leave the framedraw window
 
-boolean on_framedraw_enter (GtkWidget *widget, GdkEventCrossing *event, lives_special_framedraw_rect_t *framedraw) {
+boolean on_framedraw_enter (LiVESWidget *widget, GdkEventCrossing *event, lives_special_framedraw_rect_t *framedraw) {
 
   if (framedraw==NULL&&mainw->multitrack!=NULL) {
     framedraw=mainw->multitrack->framedraw;
@@ -795,7 +795,7 @@ boolean on_framedraw_enter (GtkWidget *widget, GdkEventCrossing *event, lives_sp
 }
 
 
-boolean on_framedraw_leave (GtkWidget *widget, GdkEventCrossing *event, lives_special_framedraw_rect_t *framedraw) {
+boolean on_framedraw_leave (LiVESWidget *widget, GdkEventCrossing *event, lives_special_framedraw_rect_t *framedraw) {
   if (framedraw==NULL) return FALSE;
   lives_set_cursor_style (LIVES_CURSOR_NORMAL,mainw->framedraw);
   return FALSE;
@@ -804,7 +804,7 @@ boolean on_framedraw_leave (GtkWidget *widget, GdkEventCrossing *event, lives_sp
 
 // using these 3 functions, the user can draw on frames
 
-boolean on_framedraw_mouse_start (GtkWidget *widget, GdkEventButton *event, lives_special_framedraw_rect_t *framedraw) {
+boolean on_framedraw_mouse_start (LiVESWidget *widget, LiVESXEventButton *event, lives_special_framedraw_rect_t *framedraw) {
   // user clicked in the framedraw widget (or multitrack playback widget)
 
   int fd_height;
@@ -924,7 +924,7 @@ boolean on_framedraw_mouse_start (GtkWidget *widget, GdkEventButton *event, live
   return FALSE;
 }
 
-boolean on_framedraw_mouse_update (GtkWidget *widget, GdkEventMotion *event, lives_special_framedraw_rect_t *framedraw) {
+boolean on_framedraw_mouse_update (LiVESWidget *widget, LiVESXEventMotion *event, lives_special_framedraw_rect_t *framedraw) {
   // pointer moved in the framedraw widget
   int xcurrenti,ycurrenti;
 
@@ -1062,7 +1062,7 @@ boolean on_framedraw_mouse_update (GtkWidget *widget, GdkEventMotion *event, liv
 }
 
 
-boolean on_framedraw_mouse_reset (GtkWidget *widget, GdkEventButton *event, lives_special_framedraw_rect_t *framedraw) {
+boolean on_framedraw_mouse_reset (LiVESWidget *widget, LiVESXEventButton *event, lives_special_framedraw_rect_t *framedraw) {
   // user released the mouse button in framedraw widget
   if (event->button!=1||!b1_held) return FALSE;
 
@@ -1089,7 +1089,7 @@ boolean on_framedraw_mouse_reset (GtkWidget *widget, GdkEventButton *event, live
 }
 
 
-void after_framedraw_widget_changed (GtkWidget *widget, lives_special_framedraw_rect_t *framedraw) {
+void after_framedraw_widget_changed (LiVESWidget *widget, lives_special_framedraw_rect_t *framedraw) {
   if (mainw->block_param_updates||noupdate) return;
 
   // redraw mask when spin values change
@@ -1104,7 +1104,7 @@ void after_framedraw_widget_changed (GtkWidget *widget, lives_special_framedraw_
 
 
 
-void on_framedraw_reset_clicked (GtkButton *button, lives_special_framedraw_rect_t *framedraw) {
+void on_framedraw_reset_clicked (LiVESButton *button, lives_special_framedraw_rect_t *framedraw) {
   // reset to defaults
 
   noupdate=TRUE;
