@@ -1,6 +1,6 @@
 // jack.c
 // LiVES (lives-exe)
-// (c) G. Finch 2005 - 2013
+// (c) G. Finch 2005 - 2014
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -153,16 +153,12 @@ static void jack_transport_check_state (void) {
     mainw->jack_can_start=FALSE;
     mainw->jack_can_stop=TRUE;
     // re - add the timer, as we will hang here, and we want to receive messages still during playback
-#if !GTK_CHECK_VERSION(3,0,0)
-    gtk_timeout_remove (mainw->kb_timer);
-    mainw->kb_timer=gtk_timeout_add(KEY_RPT_INTERVAL,&ext_triggers_poll,NULL);
-#else
-    mainw->kb_timer=g_timeout_add(KEY_RPT_INTERVAL,&ext_triggers_poll,NULL);
-#endif  
+    lives_timer_remove (mainw->kb_timer);
+    mainw->kb_timer=lives_timer_add(KEY_RPT_INTERVAL,&ext_triggers_poll,NULL);
+
     on_playall_activate(NULL,NULL);
-#if GTK_CHECK_VERSION(3,0,0)
+
     mainw->kb_timer_end=TRUE;
-#endif
 
   }
 
@@ -366,10 +362,22 @@ static int audio_process (nframes_t nframes, void *arg) {
       // assign local copy from cache_buffers
       if (mainw->playing_file==-1 || ( cache_buffer = pop_cache_buffer() )==NULL || !cache_buffer->is_ready ) {
 	// audio buffer is not ready yet
-	if (!jackd->is_silent) {
-	  for(i = 0; i < jackd->num_output_channels; i++) sample_silence_dS(out_buffer[i], nframes);
-	  jackd->is_silent=TRUE;
+	if (mainw->audio_frame_buffer!=NULL) {
+	  pthread_mutex_lock(&mainw->abuf_frame_mutex);
 	}
+	for(i = 0; i < jackd->num_output_channels; i++) {
+	  if (!jackd->is_silent) {
+	    sample_silence_dS(out_buffer[i], nframes);
+	  }
+	  if (mainw->audio_frame_buffer!=NULL) {
+	    append_to_audio_bufferf(mainw->audio_frame_buffer,out_buffer[i],nframes,i);
+	  }
+	}
+	if (mainw->audio_frame_buffer!=NULL) {
+	  mainw->audio_frame_buffer->samples_filled+=nframes;
+	  pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+	}
+	jackd->is_silent=TRUE;
 	return 0;
       }
       if (cache_buffer->fileno==-1) jackd->playing_file=-1;
@@ -392,7 +400,7 @@ static int audio_process (nframes_t nframes, void *arg) {
     uint64_t numFramesToWrite;              /* num frames we are writing this loop */
     int64_t in_frames=0;
     uint64_t in_bytes=0,xin_bytes=0;
-    gfloat shrink_factor=1.f;
+    float shrink_factor=1.f;
     double vol;
 
     lives_clip_t *xfile=afile;
@@ -409,7 +417,22 @@ static int audio_process (nframes_t nframes, void *arg) {
 			 ||jackd->is_paused) {
 
       /* output silence if nothing is being outputted */
-      if (!jackd->is_silent) for(i = 0; i < jackd->num_output_channels; i++) sample_silence_dS(out_buffer[i], nframes);
+      if (!jackd->is_silent) {
+	if (mainw->audio_frame_buffer!=NULL) {
+	  pthread_mutex_lock(&mainw->abuf_frame_mutex);
+	}
+	for(i = 0; i < jackd->num_output_channels; i++) {
+	  sample_silence_dS(out_buffer[i], nframes);
+	  if (mainw->audio_frame_buffer!=NULL) {
+	    append_to_audio_bufferf(mainw->audio_frame_buffer,out_buffer[i],nframes,i);
+	  }
+	}
+	if (mainw->audio_frame_buffer!=NULL) {
+	  mainw->audio_frame_buffer->samples_filled+=nframes;
+	  pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+	}
+      }
+
       jackd->is_silent=TRUE;
 
       // external streaming
@@ -450,7 +473,7 @@ static int audio_process (nframes_t nframes, void *arg) {
 	  in_bytes=ABS((in_frames=((double)jackd->sample_in_rate/(double)jackd->sample_out_rate*
 				   (double)jackFramesAvailable+((double)fastrand()/(double)G_MAXUINT32))))
 	    *jackd->num_input_channels*jackd->bytes_per_channel;
-	  if ((shrink_factor=(gfloat)in_frames/(gfloat)jackFramesAvailable)<0.f) {
+	  if ((shrink_factor=(float)in_frames/(float)jackFramesAvailable)<0.f) {
 	    // reverse playback
 	    if ((jackd->seek_pos-=in_bytes)<0) {
 	      // reached beginning backwards
@@ -497,7 +520,19 @@ static int audio_process (nframes_t nframes, void *arg) {
 	    if (!wait_cache_buffer&&((mainw->agen_key==0&&!mainw->agen_needs_reinit)||mainw->multitrack!=NULL)) 
 	      push_cache_buffer( cache_buffer, jackd, in_bytes, nframes, shrink_factor );
 
-	    for(i = 0; i < jackd->num_output_channels; i++) sample_silence_dS(out_buffer[i], nframes);
+	    if (mainw->audio_frame_buffer!=NULL) {
+	      pthread_mutex_lock(&mainw->abuf_frame_mutex);
+	    }
+	    for(i = 0; i < jackd->num_output_channels; i++) {
+	      sample_silence_dS(out_buffer[i], nframes);
+	      if (mainw->audio_frame_buffer!=NULL) {
+		append_to_audio_bufferf(mainw->audio_frame_buffer,out_buffer[i],nframes,i);
+	      }
+	    }
+	    if (mainw->audio_frame_buffer!=NULL) {
+	      mainw->audio_frame_buffer->samples_filled+=nframes;
+	      pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+	    }
 
 	    // external streaming
 	    rbytes=nframes*jackd->num_output_channels*2;
@@ -553,7 +588,21 @@ static int audio_process (nframes_t nframes, void *arg) {
 
 	if (!jackd->in_use||in_bytes==0) {
 	  // reached end of audio with no looping
-	  for(i = 0; i < jackd->num_output_channels; i++) sample_silence_dS(out_buffer[i], nframes);
+
+	  if (mainw->audio_frame_buffer!=NULL) {
+	    pthread_mutex_lock(&mainw->abuf_frame_mutex);
+	  }
+	  for(i = 0; i < jackd->num_output_channels; i++) {
+	    sample_silence_dS(out_buffer[i], nframes);
+	    if (mainw->audio_frame_buffer!=NULL) {
+	      append_to_audio_bufferf(mainw->audio_frame_buffer,out_buffer[i],nframes,i);
+	    }
+	  }
+	  if (mainw->audio_frame_buffer!=NULL) {
+	    mainw->audio_frame_buffer->samples_filled+=nframes;
+	    pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+	  }
+
 	  jackd->is_silent=TRUE;
 
 	  // external streaming
@@ -616,9 +665,35 @@ static int audio_process (nframes_t nframes, void *arg) {
 	      // get back non-interleaved float fbuffer; rate and channels should match
 
 	      for (i=0;i<jackd->num_output_channels;i++) {
-		if (pl_error) sample_silence_dS(out_buffer[i], nframes);
+		if (pl_error) {
+		  if (mainw->audio_frame_buffer!=NULL) {
+		    pthread_mutex_lock(&mainw->abuf_frame_mutex);
+		  }
+		  for(i = 0; i < jackd->num_output_channels; i++) {
+		    sample_silence_dS(out_buffer[i], numFramesToWrite);
+		    if (mainw->audio_frame_buffer!=NULL) {
+		      append_to_audio_bufferf(mainw->audio_frame_buffer,out_buffer[i],nframes,i);
+		    }
+		  }
+		  if (mainw->audio_frame_buffer!=NULL) {
+		    mainw->audio_frame_buffer->samples_filled+=numFramesToWrite;
+		    pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+		  }
+		}
 		else {
-		   lives_memcpy(out_buffer[i],fbuffer+(i*numFramesToWrite),numFramesToWrite*sizeof(float));
+		  if (mainw->audio_frame_buffer!=NULL) {
+		    pthread_mutex_lock(&mainw->abuf_frame_mutex);
+		  }
+		  for(i = 0; i < jackd->num_output_channels; i++) {
+		    lives_memcpy(out_buffer[i],fbuffer+(i*numFramesToWrite),numFramesToWrite*sizeof(float));
+		    if (mainw->audio_frame_buffer!=NULL) {
+		      append_to_audio_bufferf(mainw->audio_frame_buffer,out_buffer[i],nframes,i);
+		    }
+		  }
+		  if (mainw->audio_frame_buffer!=NULL) {
+		    mainw->audio_frame_buffer->samples_filled+=nframes;
+		    pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+		  }
 		}
 	      }
 
@@ -726,8 +801,20 @@ static int audio_process (nframes_t nframes, void *arg) {
 	    
 	  }
 	  else {
-	    for(i = 0; i < jackd->num_output_channels; i++) sample_silence_dS(out_buffer[i], numFramesToWrite);
-	  
+	    if (mainw->audio_frame_buffer!=NULL) {
+	      pthread_mutex_lock(&mainw->abuf_frame_mutex);
+	    }
+	    for(i = 0; i < jackd->num_output_channels; i++) {
+	      sample_silence_dS(out_buffer[i], numFramesToWrite);
+	      if (mainw->audio_frame_buffer!=NULL) {
+		append_to_audio_bufferf(mainw->audio_frame_buffer,out_buffer[i],nframes,i);
+	      }
+	    }
+	    if (mainw->audio_frame_buffer!=NULL) {
+	      mainw->audio_frame_buffer->samples_filled+=numFramesToWrite;
+	      pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+	    }
+
 	    // external streaming
 	    if (jackd->astream_fd!=-1) {
 	      rbytes=numFramesToWrite*jackd->num_output_channels*2;
@@ -751,7 +838,19 @@ static int audio_process (nframes_t nframes, void *arg) {
 		unsigned char *inbuf=(unsigned char *)out_buffer;
 		xbuf=(unsigned char *)g_try_malloc(nbytes);
 		if (!xbuf) {
-		  for(i = 0; i < jackd->num_output_channels; i++) sample_silence_dS(out_buffer[i], numFramesToWrite);
+		  if (mainw->audio_frame_buffer!=NULL) {
+		    pthread_mutex_lock(&mainw->abuf_frame_mutex);
+		  }
+		  for(i = 0; i < jackd->num_output_channels; i++) {
+		    sample_silence_dS(out_buffer[i], numFramesToWrite);
+		    if (mainw->audio_frame_buffer!=NULL) {
+		      append_to_audio_bufferf(mainw->audio_frame_buffer,out_buffer[i],nframes,i);
+		    }
+		  }
+		  if (mainw->audio_frame_buffer!=NULL) {
+		    mainw->audio_frame_buffer->samples_filled+=numFramesToWrite;
+		    pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+		  }
 		  
 		  // external streaming
 		  rbytes=numFramesToWrite*jackd->num_output_channels*2;
@@ -785,7 +884,19 @@ static int audio_process (nframes_t nframes, void *arg) {
 	    }
 	  }
 	  else {
-	    for(i = 0; i < jackd->num_output_channels; i++) sample_silence_dS(out_buffer[i], nframes);
+	    if (mainw->audio_frame_buffer!=NULL) {
+	      pthread_mutex_lock(&mainw->abuf_frame_mutex);
+	    }
+	    for(i = 0; i < jackd->num_output_channels; i++) {
+	      if (mainw->audio_frame_buffer!=NULL) {
+		sample_silence_dS(out_buffer[i], numFramesToWrite);
+	      }
+	      append_to_audio_bufferf(mainw->audio_frame_buffer,out_buffer[i],nframes,i);
+	    }
+	    if (mainw->audio_frame_buffer!=NULL) {
+	      mainw->audio_frame_buffer->samples_filled+=numFramesToWrite;
+	      pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+	    }
 	    
 	    // external streaming
 	    rbytes=numFramesToWrite*jackd->num_output_channels*2;
@@ -797,7 +908,19 @@ static int audio_process (nframes_t nframes, void *arg) {
       else {
 	// no input frames
 	nframes=jackFramesAvailable;
-	for(i = 0; i < jackd->num_output_channels; i++) sample_silence_dS(out_buffer[i], nframes);
+	if (mainw->audio_frame_buffer!=NULL) {
+	  pthread_mutex_lock(&mainw->abuf_frame_mutex);
+	}
+	for(i = 0; i < jackd->num_output_channels; i++) {
+	  sample_silence_dS(out_buffer[i], numFramesToWrite);
+	  if (mainw->audio_frame_buffer!=NULL) {
+	    append_to_audio_bufferf(mainw->audio_frame_buffer,out_buffer[i],nframes,i);
+	  }
+	}
+	if (mainw->audio_frame_buffer!=NULL) {
+	  mainw->audio_frame_buffer->samples_filled+=numFramesToWrite;
+	  pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+	}
 	  
 	// external streaming
 	rbytes=numFramesToWrite*jackd->num_output_channels*2;
@@ -805,7 +928,6 @@ static int audio_process (nframes_t nframes, void *arg) {
 	audio_stream(zero_buff,rbytes,jackd->astream_fd);
       }
 
-
     }
 
 
@@ -826,11 +948,24 @@ static int audio_process (nframes_t nframes, void *arg) {
 #ifdef DEBUG_AJACK
       g_printerr("buffer underrun of %ld frames\n", jackFramesAvailable);
 #endif
-      for(i = 0 ; i < jackd->num_output_channels; i++) 
-	sample_silence_dS(out_buffer[i] + (nframes - jackFramesAvailable), jackFramesAvailable);
+      for(i = 0 ; i < jackd->num_output_channels; i++) {
+	if (mainw->audio_frame_buffer!=NULL) {
+	  pthread_mutex_lock(&mainw->abuf_frame_mutex);
+	}
+	for(i = 0; i < jackd->num_output_channels; i++) {
+	  sample_silence_dS(out_buffer[i] + (nframes - jackFramesAvailable), jackFramesAvailable);
+	  if (mainw->audio_frame_buffer!=NULL) {
+	    append_to_audio_bufferf(mainw->audio_frame_buffer,out_buffer[i],nframes,i);
+	  }
+	}
+	if (mainw->audio_frame_buffer!=NULL) {
+	  mainw->audio_frame_buffer->samples_filled+=jackFramesAvailable;
+	  pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+	}
+      }
 
       // external streaming
-      rbytes=numFramesToWrite*jackd->num_output_channels*2;
+      rbytes=jackFramesAvailable*jackd->num_output_channels*2;
 
       check_zero_buff(rbytes);
       audio_stream(zero_buff,rbytes,jackd->astream_fd);
@@ -844,7 +979,20 @@ static int audio_process (nframes_t nframes, void *arg) {
 #endif
     
     /* output silence if nothing is being outputted */
-    for(i = 0; i < jackd->num_output_channels; i++) sample_silence_dS(out_buffer[i], nframes);
+    if (mainw->audio_frame_buffer!=NULL) {
+      pthread_mutex_lock(&mainw->abuf_frame_mutex);
+    }
+    for(i = 0; i < jackd->num_output_channels; i++) {
+      sample_silence_dS(out_buffer[i], nframes);
+      if (mainw->audio_frame_buffer!=NULL) {
+	append_to_audio_bufferf(mainw->audio_frame_buffer,out_buffer[i],nframes,i);
+      }
+    }
+    if (mainw->audio_frame_buffer!=NULL) {
+      mainw->audio_frame_buffer->samples_filled+=nframes;
+      pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+    }
+
     jackd->is_silent=TRUE;
 
     // external streaming
@@ -958,6 +1106,8 @@ static int audio_read (nframes_t nframes, void *arg) {
 
   size_t rbytes;
 
+  if (!jackd->in_use) return 0;
+
   if (mainw->playing_file<0&&prefs->audio_src==AUDIO_SRC_EXT) return 0; 
 
   if (mainw->effects_paused) return 0; // pause during record
@@ -974,10 +1124,21 @@ static int audio_read (nframes_t nframes, void *arg) {
     // TODO - dont apply filters when doing ext window grab, or voiceover
 
     // in this case we read external audio, but maybe not record it
-    // we may wish to analyse the audio for example
+    // we may wish to analyse the audio for example, or push it to a video generator
 
     if (has_audio_filters(AF_TYPE_A)) {
 	uint64_t tc=jackd->audio_ticks+(uint64_t)(jackd->frames_written/(double)jackd->sample_in_rate*U_SEC);
+
+	if (mainw->audio_frame_buffer!=NULL) {
+	  // if we have audio triggered gens., push audio to it
+	  pthread_mutex_lock(&mainw->abuf_frame_mutex);
+	  for (i=0;i<jackd->num_input_channels;i++) {
+	    append_to_audio_bufferf(mainw->audio_frame_buffer,in_buffer[i],nframes,i);
+	  }
+	  mainw->audio_frame_buffer->samples_filled+=nframes;
+	  pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+	}
+
 	// apply any audio effects with in_channels and no out_channels
 	weed_apply_audio_effects_rt(in_buffer,jackd->num_input_channels,nframes,jackd->sample_in_rate,tc,TRUE);
     }
