@@ -81,12 +81,14 @@ boolean ext_triggers_poll(gpointer data) {
 
   if (mainw->is_exiting) return FALSE;
 
-#if GTK_CHECK_VERSION(3,0,0)
   if (mainw->kb_timer_end) {
     mainw->kb_timer_end=FALSE;
+#if GTK_CHECK_VERSION(3,0,0)
+    // below 3,0,0 the timer is removed by a function
     return FALSE;
-  }
 #endif
+  }
+
 
   if (mainw->playing_file>-1) plugin_poll_keyboard(); ///< keyboard control during playback
 
@@ -194,7 +196,7 @@ boolean plugin_poll_keyboard (void) {
   // we also auto-repeat our cached keys
   if (cached_key&&current_kb_time-last_kb_time>KEY_RPT_INTERVAL*10) {
     last_kb_time=current_kb_time;
-    lives_accel_groups_activate (G_OBJECT (mainw->LiVES),(uint32_t)cached_key, (GdkModifierType)cached_mod);
+    lives_accel_groups_activate (G_OBJECT (mainw->LiVES),(uint32_t)cached_key, (LiVESXModifierType)cached_mod);
   }
 
   return TRUE;
@@ -208,7 +210,7 @@ boolean pl_key_function (boolean down, uint16_t unicode, uint16_t keymod) {
   // (via a polling mechanism)
 
   // mask for ctrl and alt
-  LiVESModifierType state=(LiVESModifierType)(keymod&(LIVES_CONTROL_MASK|LIVES_ALT_MASK));
+  LiVESXModifierType state=(LiVESXModifierType)(keymod&(LIVES_CONTROL_MASK|LIVES_ALT_MASK));
 
   // hmmm...only works with GTK+2.x
 
@@ -333,82 +335,82 @@ boolean pl_key_function (boolean down, uint16_t unicode, uint16_t keymod) {
 // key callback functions - ones which have keys and need wrappers
 
 
-boolean slower_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
+boolean slower_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
   
   on_slower_pressed (NULL,user_data);
   return TRUE;
 }
 
-boolean faster_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
+boolean faster_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
   
   on_faster_pressed (NULL,user_data);
   return TRUE;
 }
 
-boolean skip_back_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
+boolean skip_back_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
   
   on_back_pressed (NULL,user_data);
   return TRUE;
 }
 
-boolean skip_forward_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
+boolean skip_forward_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
   
   on_forward_pressed (NULL,user_data);
   return TRUE;
 }
 
-boolean stop_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
+boolean stop_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
   on_stop_activate (NULL,NULL);
   return TRUE;
 }
 
-boolean fullscreen_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
+boolean fullscreen_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
   on_full_screen_pressed (NULL,NULL);
   return TRUE;
 }
 
-boolean sepwin_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
+boolean sepwin_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
   on_sepwin_pressed (NULL,NULL);
   return TRUE;
 }
 
-boolean loop_cont_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
+boolean loop_cont_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
   on_loop_button_activate (NULL,NULL);
   return TRUE;
 }
 
-boolean ping_pong_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
+boolean ping_pong_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
   on_ping_pong_activate (NULL,NULL);
   return TRUE;
 }
 
-boolean fade_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
+boolean fade_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
   on_fade_pressed (NULL,NULL);
   return TRUE;
 }
 
-boolean showfct_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
-  lives_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mainw->showfct),!prefs->show_framecount);
+boolean showfct_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
+  lives_check_menu_item_set_active(LIVES_CHECK_MENU_ITEM(mainw->showfct),!prefs->show_framecount);
   return TRUE;
 }
 
-boolean showsubs_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
-  lives_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mainw->showsubs),!prefs->show_subtitles);
+boolean showsubs_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
+  lives_check_menu_item_set_active(LIVES_CHECK_MENU_ITEM(mainw->showsubs),!prefs->show_subtitles);
   return TRUE;
 }
 
-boolean loop_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
-  lives_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mainw->loop_video),!mainw->loop);
+boolean loop_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
+  lives_check_menu_item_set_active(LIVES_CHECK_MENU_ITEM(mainw->loop_video),!mainw->loop);
   return TRUE;
 }
 
-boolean dblsize_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
+boolean dblsize_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
   on_double_size_pressed (NULL,NULL);
   return TRUE;
 }
 
-boolean rec_callback (GtkAccelGroup *group, GObject *obj, uint32_t keyval, GdkModifierType mod, gpointer user_data) {
-  lives_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mainw->record_perf),!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (mainw->record_perf)));
+boolean rec_callback (LiVESAccelGroup *group, LiVESObject *obj, uint32_t keyval, LiVESXModifierType mod, gpointer user_data) {
+  lives_check_menu_item_set_active(LIVES_CHECK_MENU_ITEM(mainw->record_perf),!lives_check_menu_item_get_active (LIVES_CHECK_MENU_ITEM (mainw->record_perf)));
   return TRUE;
 }
 
