@@ -11,7 +11,7 @@
 
 
 
-void on_camgrab_clicked (GtkButton *button, gpointer user_data) {
+void on_camgrab_clicked (LiVESButton *button, gpointer user_data) {
   gchar *msg;
   s_cam *cam=(s_cam *)user_data;
   if (dvgrabw->filename!=NULL) g_free(dvgrabw->filename);
@@ -30,7 +30,7 @@ void on_camgrab_clicked (GtkButton *button, gpointer user_data) {
 }
 
 
-void on_camstop_clicked (GtkButton *button, gpointer user_data) {
+void on_camstop_clicked (LiVESButton *button, gpointer user_data) {
   s_cam *cam=(s_cam *)user_data;
   lives_widget_set_sensitive(dvgrabw->stop,FALSE);
   dvgrabw->playing=FALSE;
@@ -42,51 +42,51 @@ void on_camstop_clicked (GtkButton *button, gpointer user_data) {
 
   lives_set_cursor_style(LIVES_CURSOR_NORMAL,dvgrabw->dialog);
   camstop(cam);
-  lives_button_set_label(GTK_BUTTON(dvgrabw->play),"gtk-media-play");
+  lives_button_set_label(LIVES_BUTTON(dvgrabw->play),"gtk-media-play");
   lives_widget_set_sensitive(dvgrabw->grab,TRUE);
   lives_entry_set_text(LIVES_ENTRY(dvgrabw->status_entry),_("Status: Ready"));
 }
 
 
-void on_camplay_clicked (GtkButton *button, gpointer user_data) {
+void on_camplay_clicked (LiVESButton *button, gpointer user_data) {
   s_cam *cam=(s_cam *)user_data;
   camplay(cam);
   dvgrabw->playing=!dvgrabw->playing;
   if (dvgrabw->playing) {
-    lives_button_set_label(GTK_BUTTON(dvgrabw->play),"gtk-media-pause");
+    lives_button_set_label(LIVES_BUTTON(dvgrabw->play),"gtk-media-pause");
   }
   else {
-    lives_button_set_label(GTK_BUTTON(dvgrabw->play),"gtk-media-play");
+    lives_button_set_label(LIVES_BUTTON(dvgrabw->play),"gtk-media-play");
   }
   lives_widget_set_sensitive(dvgrabw->stop,TRUE);
 }
 
-void on_camrew_clicked (GtkButton *button, gpointer user_data) {
+void on_camrew_clicked (LiVESButton *button, gpointer user_data) {
   s_cam *cam=(s_cam *)user_data;
   camrew(cam);
   lives_widget_set_sensitive(dvgrabw->stop,TRUE);
 }
 
 
-void on_camff_clicked (GtkButton *button, gpointer user_data) {
+void on_camff_clicked (LiVESButton *button, gpointer user_data) {
   s_cam *cam=(s_cam *)user_data;
   camff(cam);
   lives_widget_set_sensitive(dvgrabw->stop,TRUE);
 }
 
-void on_cameject_clicked (GtkButton *button, gpointer user_data) {
+void on_cameject_clicked (LiVESButton *button, gpointer user_data) {
   s_cam *cam=(s_cam *)user_data;
   cameject(cam);
 }
 
 
-boolean on_camdelete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
+boolean on_camdelete_event (LiVESWidget *widget, GdkEvent *event, gpointer user_data) {
   on_camquit_clicked(NULL,user_data);
   return FALSE;
 }
 
 
-void on_camquit_clicked (GtkButton *button, gpointer user_data) {
+void on_camquit_clicked (LiVESButton *button, gpointer user_data) {
   s_cam *cam=(s_cam *)user_data;
   on_camstop_clicked(button,user_data);
   //if (cam->format==CAM_FORMAT_HDV) close_raw1394(cam->rec_handle);
