@@ -32,19 +32,19 @@ void cameject (s_cam *cam);
 
 void close_raw1394(raw1394handle_t handle);
 
-gchar *find_free_camfile(gint format);
+gchar *find_free_camfile(int format);
 
 
 struct _dvgrabw {
-  GtkWidget *dialog;
-  GtkWidget *filent;
-  GtkWidget *stop;
-  GtkWidget *grab;
-  GtkWidget *play;
-  GtkWidget *quit;
-  GtkWidget *status_entry;
-  GtkWidget *split;
-  GdkCursor *cursor;
+  LiVESWidget *dialog;
+  LiVESWidget *filent;
+  LiVESWidget *stop;
+  LiVESWidget *grab;
+  LiVESWidget *play;
+  LiVESWidget *quit;
+  LiVESWidget *status_entry;
+  LiVESWidget *split;
+  LiVESXCursor *cursor;
   boolean playing;
   gchar *dirname;
   gchar *filename;
