@@ -10,18 +10,17 @@
 #include "ldvinterface.h"
 
 
-struct _dvgrabw *create_camwindow (s_cam *cam, int type)
-{
-  GtkWidget *hbuttonbox1;
-  GtkWidget *hbuttonbox2;
-  GtkWidget *button3;
-  GtkWidget *button4;
-  GtkWidget *buttond;
-  GtkWidget *image;
-  GtkWidget *vbox;
-  GtkWidget *hbox;
-  GtkWidget *label;
-  GtkWidget *direntry;
+struct _dvgrabw *create_camwindow (s_cam *cam, int type) {
+  LiVESWidget *hbuttonbox1;
+  LiVESWidget *hbuttonbox2;
+  LiVESWidget *button3;
+  LiVESWidget *button4;
+  LiVESWidget *buttond;
+  LiVESWidget *image;
+  LiVESWidget *vbox;
+  LiVESWidget *hbox;
+  LiVESWidget *label;
+  LiVESWidget *direntry;
 
   gchar *tmp;
 
@@ -35,8 +34,8 @@ struct _dvgrabw *create_camwindow (s_cam *cam, int type)
   lives_container_set_border_width (LIVES_CONTAINER (dvgrabw->dialog), widget_opts.border_width*2);
 
   if (prefs->show_gui) {
-    if (mainw->multitrack==NULL) lives_window_set_transient_for(LIVES_WINDOW(dvgrabw->dialog),GTK_WINDOW(mainw->LiVES));
-    else lives_window_set_transient_for(LIVES_WINDOW(dvgrabw->dialog),GTK_WINDOW(mainw->multitrack->window));
+    if (mainw->multitrack==NULL) lives_window_set_transient_for(LIVES_WINDOW(dvgrabw->dialog),LIVES_WINDOW(mainw->LiVES));
+    else lives_window_set_transient_for(LIVES_WINDOW(dvgrabw->dialog),LIVES_WINDOW(mainw->multitrack->window));
   }
 
   vbox=lives_dialog_get_content_area(LIVES_DIALOG(dvgrabw->dialog));
@@ -58,7 +57,7 @@ struct _dvgrabw *create_camwindow (s_cam *cam, int type)
   g_free(tmp);
 
 
-  g_signal_connect(buttond, "clicked", G_CALLBACK (on_filesel_button_clicked), (gpointer)direntry);
+  lives_signal_connect(buttond, LIVES_WIDGET_CLICKED_EVENT, LIVES_GUI_CALLBACK (on_filesel_button_clicked), (gpointer)direntry);
 
 
   //////////////////
@@ -82,11 +81,11 @@ struct _dvgrabw *create_camwindow (s_cam *cam, int type)
 
 
   // TODO - widget_opts.editable
-  dvgrabw->status_entry=gtk_entry_new();
+  dvgrabw->status_entry=lives_entry_new();
 
   lives_box_pack_start(LIVES_BOX(vbox),dvgrabw->status_entry,FALSE,FALSE,widget_opts.packing_height);
   lives_entry_set_text(LIVES_ENTRY(dvgrabw->status_entry),_("Status: Ready"));
-  gtk_editable_set_editable (GTK_EDITABLE(dvgrabw->status_entry),FALSE);
+  lives_editable_set_editable (LIVES_EDITABLE(dvgrabw->status_entry),FALSE);
 
   add_hsep_to_box(LIVES_BOX(vbox));
 
@@ -127,7 +126,7 @@ struct _dvgrabw *create_camwindow (s_cam *cam, int type)
 #endif
   lives_container_add (LIVES_CONTAINER (hbuttonbox1), dvgrabw->play);
   lives_widget_set_can_focus_and_default (dvgrabw->play);
-  gtk_button_set_use_stock(GTK_BUTTON(dvgrabw->play),TRUE);
+
 
 #if GTK_CHECK_VERSION(2,6,0)
   dvgrabw->grab = lives_button_new_from_stock (GTK_STOCK_MEDIA_RECORD);
@@ -142,8 +141,8 @@ struct _dvgrabw *create_camwindow (s_cam *cam, int type)
 #else
   image = lives_image_new_from_stock (GTK_STOCK_NO,LIVES_ICON_SIZE_BUTTON);
 #endif
-  lives_button_set_label(GTK_BUTTON(dvgrabw->grab),_("_Grab"));
-  gtk_button_set_image(GTK_BUTTON(dvgrabw->grab),image);
+  lives_button_set_label(LIVES_BUTTON(dvgrabw->grab),_("_Grab"));
+  lives_button_set_image(LIVES_BUTTON(dvgrabw->grab),image);
 
   label=lives_standard_label_new(_("\nUse this tool to control your camera and grab clips.\nAfter grabbing your clips, you can close this window \nand then load them into LiVES.\n"));
   lives_box_pack_start(LIVES_BOX(vbox),label,FALSE,FALSE,widget_opts.packing_height*4);
@@ -157,17 +156,17 @@ struct _dvgrabw *create_camwindow (s_cam *cam, int type)
   lives_widget_set_can_focus_and_default (dvgrabw->quit);
 
   image=lives_image_new_from_stock(LIVES_STOCK_CLOSE,LIVES_ICON_SIZE_BUTTON);
-  lives_button_set_label(GTK_BUTTON(dvgrabw->quit),_("_Close Window"));
-  gtk_button_set_image(GTK_BUTTON(dvgrabw->quit),image);
+  lives_button_set_label(LIVES_BUTTON(dvgrabw->quit),_("_Close Window"));
+  lives_button_set_image(LIVES_BUTTON(dvgrabw->quit),image);
 
   //////////////////////////////////////////////////////////////////////////////////////////
 
-  g_signal_connect (button3, "clicked",G_CALLBACK (on_camrew_clicked),(gpointer)cam);
-  g_signal_connect (button4, "clicked",G_CALLBACK (on_camff_clicked),(gpointer)cam);
-  g_signal_connect (dvgrabw->stop, "clicked",G_CALLBACK (on_camstop_clicked),(gpointer)cam);
-  g_signal_connect (dvgrabw->play, "clicked",G_CALLBACK (on_camplay_clicked),(gpointer)cam);
-  g_signal_connect (dvgrabw->grab, "clicked",G_CALLBACK (on_camgrab_clicked),(gpointer)cam);
-  g_signal_connect (dvgrabw->quit, "clicked",G_CALLBACK (on_camquit_clicked),(gpointer)cam);
+  lives_signal_connect (button3, LIVES_WIDGET_CLICKED_EVENT,LIVES_GUI_CALLBACK (on_camrew_clicked),(gpointer)cam);
+  lives_signal_connect (button4, LIVES_WIDGET_CLICKED_EVENT,LIVES_GUI_CALLBACK (on_camff_clicked),(gpointer)cam);
+  lives_signal_connect (dvgrabw->stop, LIVES_WIDGET_CLICKED_EVENT,LIVES_GUI_CALLBACK (on_camstop_clicked),(gpointer)cam);
+  lives_signal_connect (dvgrabw->play, LIVES_WIDGET_CLICKED_EVENT,LIVES_GUI_CALLBACK (on_camplay_clicked),(gpointer)cam);
+  lives_signal_connect (dvgrabw->grab, LIVES_WIDGET_CLICKED_EVENT,LIVES_GUI_CALLBACK (on_camgrab_clicked),(gpointer)cam);
+  lives_signal_connect (dvgrabw->quit, LIVES_WIDGET_CLICKED_EVENT,LIVES_GUI_CALLBACK (on_camquit_clicked),(gpointer)cam);
 
 
   lives_widget_show_all(dvgrabw->dialog);
