@@ -371,7 +371,7 @@ static boolean open_yuv4m_inner(const gchar *filename, const gchar *fname, int n
 
 
 
-void on_open_yuv4m_activate (GtkMenuItem *menuitem, gpointer user_data) {
+void on_open_yuv4m_activate (LiVESMenuItem *menuitem, gpointer user_data) {
   // open a general yuvmpeg stream
   // start "playing" but open frames in yuv4mpeg format on stdin
 
@@ -579,7 +579,7 @@ void lives_yuv_stream_stop_write (lives_yuv4m_t *yuv4mpeg) {
 
 
 
-void on_live_tvcard_activate (GtkMenuItem *menuitem, gpointer user_data) {
+void on_live_tvcard_activate (LiVESMenuItem *menuitem, gpointer user_data) {
   int cardno=0;
 
   int new_file=mainw->first_free_file;
@@ -594,7 +594,7 @@ void on_live_tvcard_activate (GtkMenuItem *menuitem, gpointer user_data) {
 
   gchar *fname;
 
-  GtkWidget *card_dialog;
+  LiVESWidget *card_dialog;
 
   lives_tvcardw_t *tvcardw;
 
@@ -606,7 +606,7 @@ void on_live_tvcard_activate (GtkMenuItem *menuitem, gpointer user_data) {
 
 
   response=lives_dialog_run(LIVES_DIALOG(card_dialog));
-  if (response==GTK_RESPONSE_CANCEL) {
+  if (response==LIVES_RESPONSE_CANCEL) {
     lives_widget_destroy(card_dialog);
     g_free(fifofile);
     g_free(tvcardw);
@@ -722,7 +722,7 @@ void on_live_tvcard_activate (GtkMenuItem *menuitem, gpointer user_data) {
 
 
 
-void on_live_fw_activate (GtkMenuItem *menuitem, gpointer user_data) {
+void on_live_fw_activate (LiVESMenuItem *menuitem, gpointer user_data) {
 
   gchar *com,*tmp;
   int cardno;
@@ -735,13 +735,13 @@ void on_live_fw_activate (GtkMenuItem *menuitem, gpointer user_data) {
   gchar *fifofile=g_strdup_printf("%s/firew.%d",prefs->tmpdir,capable->mainpid);
   gchar *fname;
 
-  GtkWidget *card_dialog;
+  LiVESWidget *card_dialog;
 
   mainw->open_deint=FALSE;
 
   card_dialog=create_cdtrack_dialog(5,NULL);
   response=lives_dialog_run(LIVES_DIALOG(card_dialog));
-  if (response==GTK_RESPONSE_CANCEL) {
+  if (response==LIVES_RESPONSE_CANCEL) {
     lives_widget_destroy(card_dialog);
     g_free(fifofile);
     return;
