@@ -34,9 +34,9 @@ typedef struct {
 void weed_layer_set_from_yuv4m (weed_plant_t *layer, lives_clip_t *);
 
 // callbacks
-void on_open_yuv4m_activate (GtkMenuItem *, gpointer);
-void on_live_tvcard_activate (GtkMenuItem *, gpointer);
-void on_live_fw_activate (GtkMenuItem *, gpointer);
+void on_open_yuv4m_activate (LiVESMenuItem *, gpointer);
+void on_live_tvcard_activate (LiVESMenuItem *, gpointer);
+void on_live_fw_activate (LiVESMenuItem *, gpointer);
 
 void lives_yuv_stream_stop_read (lives_yuv4m_t *);
 
@@ -48,9 +48,9 @@ void lives_yuv_stream_stop_write (lives_yuv4m_t *);
 
 
 typedef struct {
-  GtkWidget *dialog;
-  GtkWidget *card_spin;
-  GtkWidget * channel_spin;
+  LiVESWidget *dialog;
+  LiVESWidget *card_spin;
+  LiVESWidget * channel_spin;
 } lives_card_w;
 
 
