@@ -1,6 +1,6 @@
 // main.h
 // LiVES
-// (c) G. Finch (salsaman@gmail.com) 2003 - 2014
+// (c) G. Finch (salsaman@gmail.com) 2003 - 2015
 // see file ../COPYING for full licensing details
 
 /*  This program is free software; you can redistribute it and/or modify
@@ -13,7 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    agint64 with this program; if not, write to the Free Software
+    along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 */
 
@@ -51,9 +51,16 @@ POSSIBILITY OF SUCH DAMAGES.
 #ifndef HAS_LIVES_MAIN_H
 #define HAS_LIVES_MAIN_H
 
+#ifdef __cplusplus
+#undef HAVE_UNICAP
+#endif
+
 #define GUI_GTK
 #define PAINTER_CAIRO
 
+//#define GUI_QT
+//#define PAINTER_QPAINTER
+
 #ifdef GUI_GTK
 
 #include <gtk/gtk.h>
@@ -77,7 +84,6 @@ POSSIBILITY OF SUCH DAMAGES.
 #include <winbase.h>
 #include <tlhelp32.h>
 #include <sddl.h>
-#include <sys/stat.h>
 
 #define O_SYNC (FILE_FLAG_NO_BUFFERING|FILE_FLAG_WRITE_THROUGH)
 
@@ -96,53 +102,21 @@ typedef PROCESS_INFORMATION * lives_pgid_t;
 #ifndef GDK_WINDOWING_X11
 #define GDK_WINDOWING_X11
 #endif
-#endif
+#else
+#include <sys/types.h>
+#include <unistd.h>
+#endif // GUI_GTK
 
 typedef pid_t lives_pid_t;
 typedef int lives_pgid_t;
 
-#endif
+#endif // IS_MINGW
 
 
 
-#ifdef GUI_GTK
-
-#ifdef GDK_WINDOWING_WIN32
-#include <gdk/gdkwin32.h>
-
-#ifndef GDK_IS_WIN32_DISPLAY 
-#define GDK_IS_WIN32_DISPLAY(display) (TRUE)
-#endif
-
-#endif //GDK_WINDOWING_WIN32
-
-#ifdef GDK_WINDOWING_X11
-
-// needed for GDK_WINDOW_XID - for fileselector preview
-// needed for gdk_x11_screen_get_window_manager_name()
-
-#include <gdk/gdkx.h>
-
-#ifndef GDK_IS_X11_DISPLAY 
-#define GDK_IS_X11_DISPLAY(display) (TRUE)
-#endif
-
-#ifndef GDK_IS_WIN32_DISPLAY 
-#define GDK_IS_WIN32_DISPLAY(display) (FALSE)
-#endif
-
-
-#else
-
-#ifndef GDK_IS_X11_DISPLAY 
-#define GDK_IS_X11_DISPLAY(display) (FALSE)
-#endif
-
-#endif // GDK_WINDOWING_X11
-
-#endif // GUI_GTK
 
 
+#include <sys/stat.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -151,7 +125,13 @@ typedef int lives_pgid_t;
 #include <assert.h>
 #include <errno.h>
 
-#define  __STDC_CONSTANT_MACROS
+#ifdef __cplusplus
+#define __STDC_CONSTANT_MACROS
+#ifdef _STDINT_H
+#undef _STDINT_H
+#endif
+#endif
+
 #include <stdint.h>
 
 
@@ -216,7 +196,7 @@ typedef int lives_pgid_t;
 #define LIVES_FEATURE_URL "https://sourceforge.net/p/lives/feature-requests/"
 #define LIVES_TRANSLATE_URL "https://translations.launchpad.net/lives/trunk"
 
-#ifdef IS_DARWIN
+#if defined (IS_DARWIN) || defined (__FreeBSD__)
 #ifndef off64_t
 #define off64_t off_t
 #endif
@@ -276,6 +256,8 @@ typedef int lives_pgid_t;
 #define LIVES_LOG "lives.log"
 #endif
 
+uint64_t lives_random(void);
+
 #include "widget-helper.h"
 
 typedef  void *(*fn_ptr) (void *ptr);
@@ -289,16 +271,16 @@ typedef struct {
 } event;
 
 typedef struct {
-  GtkWidget *processing;
-  GtkWidget *progressbar;
-  GtkWidget *label;
-  GtkWidget *label2;
-  GtkWidget *label3;
-  GtkWidget *stop_button;
-  GtkWidget *pause_button;
-  GtkWidget *preview_button;
-  GtkWidget *cancel_button;
-  GtkWidget *scrolledwindow;
+  LiVESWidget *processing;
+  LiVESWidget *progressbar;
+  LiVESWidget *label;
+  LiVESWidget *label2;
+  LiVESWidget *label3;
+  LiVESWidget *stop_button;
+  LiVESWidget *pause_button;
+  LiVESWidget *preview_button;
+  LiVESWidget *cancel_button;
+  LiVESWidget *scrolledwindow;
   uint32_t frames_done;
 } xprocess;
 
@@ -527,7 +509,7 @@ typedef struct {
   int progress_start;
   int progress_end;
   boolean changed;
-  GtkWidget *menuentry;
+  LiVESWidget *menuentry;
   gulong menuentry_func;
   boolean orig_file_name;
   boolean was_renamed;
@@ -826,38 +808,38 @@ void kill_play_window (void);
 void make_preview_box (void);
 void play_window_set_title(void);
 void add_to_playframe (void);
-GtkWidget* create_cdtrack_dialog (int type, gpointer user_data);
-GtkTextView *create_output_textview(void);
-gchar *choose_file(gchar *dir, gchar *fname, gchar **filt, lives_file_chooser_action_t act, const char *title, GtkWidget *extra);
-GtkWidget *choose_file_with_preview (gchar *dir, const gchar *title, int preview_type);
-void add_suffix_check(GtkBox *box, const gchar *ext);
+LiVESWidget* create_cdtrack_dialog (int type, gpointer user_data);
+LiVESTextView *create_output_textview(void);
+gchar *choose_file(gchar *dir, gchar *fname, gchar **filt, LiVESFileChooserAction act, const char *title, LiVESWidget *extra);
+LiVESWidget *choose_file_with_preview (gchar *dir, const gchar *title, int preview_type);
+void add_suffix_check(LiVESBox *box, const gchar *ext);
 
 
 // dialogs.c
 boolean do_progress_dialog(boolean visible, boolean cancellable, const gchar *text);
 boolean do_warning_dialog(const gchar *text);
 boolean do_warning_dialog_with_check(const gchar *text, int warn_mask_number);
-boolean do_warning_dialog_with_check_transient(const gchar *text, int warn_mask_number, GtkWindow *transient);
+boolean do_warning_dialog_with_check_transient(const gchar *text, int warn_mask_number, LiVESWindow *transient);
 boolean do_yesno_dialog(const gchar *text);
 boolean do_yesno_dialog_with_check (const gchar *text, int warn_mask_number);
-boolean do_yesno_dialog_with_check_transient(const gchar *text, int warn_mask_number, GtkWindow *transient);
+boolean do_yesno_dialog_with_check_transient(const gchar *text, int warn_mask_number, LiVESWindow *transient);
 boolean do_yesno_dialog_with_check(const gchar *text, int warn_mask_number);
-boolean do_yesno_dialog_with_check_transient(const gchar *text, int warn_mask_number, GtkWindow *transient);
-int do_abort_cancel_retry_dialog(const gchar *text, GtkWindow *transient) WARN_UNUSED;
-void do_error_dialog(const gchar *text);
-void do_info_dialog(const gchar *text);
-void do_error_dialog_with_check(const gchar *text, int warn_mask_number);
-void do_blocking_error_dialog(const gchar *text);
-void do_blocking_info_dialog(const gchar *text);
-void do_error_dialog_with_check_transient(const gchar *text, boolean is_blocking, int warn_mask_number, 
-					  GtkWindow *transient);
-void do_info_dialog_with_transient(const gchar *text, boolean is_blocking, GtkWindow *transient);
+boolean do_yesno_dialog_with_check_transient(const gchar *text, int warn_mask_number, LiVESWindow *transient);
+int do_abort_cancel_retry_dialog(const gchar *text, LiVESWindow *transient) WARN_UNUSED;
+int do_error_dialog(const gchar *text);
+int do_info_dialog(const gchar *text);
+int do_error_dialog_with_check(const gchar *text, int warn_mask_number);
+int do_blocking_error_dialog(const gchar *text);
+int do_blocking_info_dialog(const gchar *text);
+int do_error_dialog_with_check_transient(const gchar *text, boolean is_blocking, int warn_mask_number, 
+					 LiVESWindow *transient);
+int do_info_dialog_with_transient(const gchar *text, boolean is_blocking, LiVESWindow *transient);
 
 
 void do_system_failed_error(const char *com, int retval, const char *addinfo);
-int do_write_failed_error_s_with_retry(const gchar *fname, const gchar *errtext, GtkWindow *transient) WARN_UNUSED;
+int do_write_failed_error_s_with_retry(const gchar *fname, const gchar *errtext, LiVESWindow *transient) WARN_UNUSED;
 void do_write_failed_error_s(const char *filename, const char *addinfo);
-int do_read_failed_error_s_with_retry(const gchar *fname, const gchar *errtext, GtkWindow *transient) WARN_UNUSED;
+int do_read_failed_error_s_with_retry(const gchar *fname, const gchar *errtext, LiVESWindow *transient) WARN_UNUSED;
 void do_read_failed_error_s(const char *filename, const char *addinfo);
 boolean do_header_write_error(int clip);
 int do_header_read_error_with_retry(int clip) WARN_UNUSED;
@@ -876,7 +858,7 @@ gchar *get_new_install_msg(void);
 
 boolean ask_permission_dialog(int what);
 boolean do_abort_check(void);
-void add_warn_check (GtkBox *box, int warn_mask_number);
+void add_warn_check (LiVESBox *box, int warn_mask_number);
 void do_memory_error_dialog (void);
 void too_many_files(void);
 void tempdir_warning (void);
@@ -957,7 +939,7 @@ boolean process_one (boolean visible);
 void do_threaded_dialog(gchar *translated_text, boolean has_cancel);
 void end_threaded_dialog(void);
 void threaded_dialog_spin (void);
-void response_ok (GtkButton *button, gpointer user_data);
+void response_ok (LiVESButton *button, gpointer user_data);
 void pump_io_chan(GIOChannel *iochan);
 
 void do_splash_progress(void);
@@ -988,7 +970,7 @@ boolean get_handle_from_info_file(int index);
 void create_cfile(void);
 void save_file (int clip, int start, int end, const char *filename);
 void play_file (void);
-void save_frame (GtkMenuItem *menuitem, gpointer user_data);
+void save_frame (LiVESMenuItem *menuitem, gpointer user_data);
 boolean save_frame_inner(int clip, int frame, const gchar *file_name, int width, int height, boolean from_osc);
 void wait_for_stop (const gchar *stop_command);
 boolean save_clip_values(int which_file);
@@ -1032,7 +1014,7 @@ boolean startup_message_info(const gchar *msg);
 boolean startup_message_nonfatal_dismissable(const gchar *msg, int warning_mask);
 capability *get_capabilities(void);
 void get_monitors(void);
-void set_ce_frame_from_pixbuf(GtkImage *image, GdkPixbuf *pixbuf, lives_painter_t *);
+void set_ce_frame_from_pixbuf(LiVESImage *image, LiVESPixbuf *pixbuf, lives_painter_t *);
 void load_start_image(int frame);
 void load_end_image(int frame);
 void load_preview_image(boolean update_always);
@@ -1046,7 +1028,7 @@ LiVESPixbuf *pull_lives_pixbuf_at_size(int clip, int frame, const char *image_ex
 				       int width, int height, LiVESInterpType interp);
 LiVESPixbuf *pull_lives_pixbuf(int clip, int frame, const char *image_ext, weed_timecode_t tc);
 
-GError * lives_pixbuf_save(GdkPixbuf *pixbuf, gchar *fname, lives_image_type_t imgtype, 
+GError * lives_pixbuf_save(LiVESPixbuf *pixbuf, gchar *fname, lives_image_type_t imgtype, 
 			   int quality, boolean do_chmod, GError **gerrorptr);
 
 void init_track_decoders(void);
@@ -1082,13 +1064,13 @@ void frame_size_update(void);
 void splash_init(void);
 void splash_end(void);
 void splash_msg(const gchar *msg, double pct);
-void add_message_scroller(GtkWidget *conter);
+void add_message_scroller(LiVESWidget *conter);
 void resize_widgets_for_monitor(boolean get_play_times);
 #if GTK_CHECK_VERSION(3,0,0)
 void calibrate_sepwin_size(void);
-boolean expose_pim (GtkWidget *widget, lives_painter_t *cr, gpointer user_data);
-boolean expose_sim (GtkWidget *widget, lives_painter_t *cr, gpointer user_data);
-boolean expose_eim (GtkWidget *widget, lives_painter_t *cr, gpointer user_data);
+boolean expose_pim (LiVESWidget *widget, lives_painter_t *cr, gpointer user_data);
+boolean expose_sim (LiVESWidget *widget, lives_painter_t *cr, gpointer user_data);
+boolean expose_eim (LiVESWidget *widget, lives_painter_t *cr, gpointer user_data);
 #endif
 // system calls in utils.c
 int lives_system(const char *com, boolean allow_error);
@@ -1123,7 +1105,6 @@ int lives_win32_get_num_logical_cpus(void);
 int lives_kill(lives_pid_t pid, int sig);
 int lives_killpg(lives_pgid_t pgrp, int sig);
 void lives_srandom(unsigned int seed);
-uint64_t lives_random(void);
 ssize_t lives_readlink(const char *path, char *buf, size_t bufsiz);
 boolean lives_setenv(const char *name, const char *value);
 boolean lives_fsync(int fd);
@@ -1158,9 +1139,9 @@ char *get_val_from_cached_list(const char *key, size_t maxlen);
 
 void get_location(const char *exe, char *val, int maxlen);
 
-void set_menu_text(GtkWidget *menu, const char *text, boolean use_mnemonic);
-void get_menu_text(GtkWidget *menu, char *text);
-void get_menu_text_long(GtkWidget *menuitem, char *text);
+void set_menu_text(LiVESWidget *menu, const char *text, boolean use_mnemonic);
+void get_menu_text(LiVESWidget *menu, char *text);
+void get_menu_text_long(LiVESWidget *menuitem, char *text);
 void reset_clipmenu (void);
 void get_play_times(void);
 void get_total_time (lives_clip_t *file);
@@ -1224,7 +1205,7 @@ void set_undoable (const char *what, boolean sensitive);
 void set_redoable (const char *what, boolean sensitive);
 void zero_spinbuttons (void);
 void draw_little_bars (double ptrtime);
-void set_sel_label (GtkWidget *label);
+void set_sel_label (LiVESWidget *label);
 void clear_mainw_msg (void);
 int get_token_count (const char *string, int delim);
 LiVESPixbuf *lives_pixbuf_new_blank(int width, int height, int palette);
@@ -1266,15 +1247,17 @@ boolean check_encoder_restrictions (boolean get_extension, boolean user_audio, b
 //callbacks.c
 void lives_exit (void);
 void count_opening_frames(void);
-void on_fileread_clicked (GtkFileChooser *, gpointer widget);
-boolean dirchange_callback (GtkAccelGroup *, GObject *, uint32_t, GdkModifierType, gpointer user_data);
-void on_effects_paused (GtkButton *, gpointer user_data);
-void on_cancel_keep_button_clicked (GtkButton *, gpointer user_data);
-void on_cleardisk_activate (GtkWidget *, gpointer user_data);
-void on_cleardisk_advanced_clicked (GtkWidget *, gpointer user_data);
-void popup_lmap_errors(GtkMenuItem *, gpointer);
-void on_filesel_button_clicked (GtkButton *, gpointer user_data);
+void on_fileread_clicked (LiVESFileChooser *, gpointer widget);
+boolean dirchange_callback (LiVESAccelGroup *, LiVESObject *, uint32_t, LiVESXModifierType, gpointer user_data);
+void on_effects_paused (LiVESButton *, gpointer user_data);
+void on_cancel_keep_button_clicked (LiVESButton *, gpointer user_data);
+void on_cleardisk_activate (LiVESWidget *, gpointer user_data);
+void on_cleardisk_advanced_clicked (LiVESWidget *, gpointer user_data);
+void popup_lmap_errors(LiVESMenuItem *, gpointer);
+void on_filesel_button_clicked (LiVESButton *, gpointer user_data);
 void switch_clip(int type, int newclip);
+void on_details_button_clicked (void);
+
 
 
 //preferences.c
@@ -1302,7 +1285,7 @@ LiVESPixbuf *make_thumb (lives_mt *, int file, int width, int height, int frame,
 LiVESPixbuf *mt_framedraw(lives_mt *, LiVESPixbuf *);
 
 // rte_window.c
-GtkWidget *refresh_rte_window (void);
+LiVESWidget *refresh_rte_window (void);
 
 // effects-weed.c
 void * lives_malloc(size_t size);
@@ -1337,7 +1320,7 @@ void lives_osc_notify_cancel (void);
 
 // ldvgrab.c
 #ifdef HAVE_LDVGRAB
-void on_open_fw_activate (GtkMenuItem *menuitem, gpointer format);
+void on_open_fw_activate (LiVESMenuItem *menuitem, gpointer format);
 
 #define CAM_FORMAT_DV 0
 #define CAM_FORMAT_HDV 1
