@@ -23,24 +23,24 @@ _merge_opts* merge_opts;
 void create_merge_dialog (void) {
   lives_rfx_t *rfx;
 
-  GtkWidget *dialog_vbox;
-  GtkWidget *vbox;
-  GtkWidget *align_start_button;
-  GtkWidget *align_end_button;
-  GtkWidget *hbox;
-  GtkWidget *label;
-  GtkWidget *fit_button;
-  GtkWidget *transition_combo;
-  GtkWidget *dialog_action_area;
-  GtkWidget *cancelbutton;
-  GtkWidget *okbutton;
+  LiVESWidget *dialog_vbox;
+  LiVESWidget *vbox;
+  LiVESWidget *align_start_button;
+  LiVESWidget *align_end_button;
+  LiVESWidget *hbox;
+  LiVESWidget *label;
+  LiVESWidget *fit_button;
+  LiVESWidget *transition_combo;
+  LiVESWidget *dialog_action_area;
+  LiVESWidget *cancelbutton;
+  LiVESWidget *okbutton;
 
   GSList *radiobutton_align_group = NULL;
   GSList *radiobutton_insdrop_group = NULL;
 
   GList *retvals;
 
-  GtkAccelGroup *accel_group;
+  LiVESAccelGroup *accel_group;
 
   gchar *txt;
 
@@ -84,11 +84,11 @@ void create_merge_dialog (void) {
 
   merge_opts->merge_dialog = lives_standard_dialog_new (_("LiVES: - Merge"),FALSE);
 
-  accel_group = GTK_ACCEL_GROUP(lives_accel_group_new ());
+  accel_group = LIVES_ACCEL_GROUP(lives_accel_group_new ());
   lives_window_add_accel_group (LIVES_WINDOW (merge_opts->merge_dialog), accel_group);
 
   if (prefs->show_gui) {
-    lives_window_set_transient_for(LIVES_WINDOW(merge_opts->merge_dialog),GTK_WINDOW(mainw->LiVES));
+    lives_window_set_transient_for(LIVES_WINDOW(merge_opts->merge_dialog),LIVES_WINDOW(mainw->LiVES));
   }
 
   dialog_vbox = lives_dialog_get_content_area(LIVES_DIALOG(merge_opts->merge_dialog));
@@ -137,8 +137,8 @@ void create_merge_dialog (void) {
     merge_opts->ins_frame_button=lives_standard_radio_button_new(_("_Insert Frames"),TRUE,radiobutton_insdrop_group,LIVES_BOX(hbox),NULL);
     radiobutton_insdrop_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (merge_opts->ins_frame_button));
 
-    merge_opts->ins_frame_function=g_signal_connect (GTK_OBJECT (merge_opts->ins_frame_button),
-						     "toggled",G_CALLBACK (on_ins_frames_toggled),NULL);
+    merge_opts->ins_frame_function=lives_signal_connect (LIVES_GUI_OBJECT (merge_opts->ins_frame_button),
+						     LIVES_WIDGET_TOGGLED_EVENT,LIVES_GUI_CALLBACK (on_ins_frames_toggled),NULL);
 
     merge_opts->drop_frame_button=lives_standard_radio_button_new(_("_Drop Frames"),TRUE,radiobutton_insdrop_group,LIVES_BOX(hbox),NULL);
 
@@ -153,15 +153,15 @@ void create_merge_dialog (void) {
     lives_spin_button_set_value (LIVES_SPIN_BUTTON (merge_opts->spinbutton_loops),mainw->last_transition_loops);
     lives_widget_set_sensitive(merge_opts->spinbutton_loops,!mainw->last_transition_loop_to_fit);
 
-    g_signal_connect_after (GTK_OBJECT (merge_opts->spinbutton_loops), "value_changed",
-			    G_CALLBACK (after_spinbutton_loops_changed),
+    lives_signal_connect_after (LIVES_GUI_OBJECT (merge_opts->spinbutton_loops), "value_changed",
+			    LIVES_GUI_CALLBACK (after_spinbutton_loops_changed),
 			    NULL);
 
     fit_button = lives_standard_check_button_new (_("_Loop Clipboard to Fit Selection"),TRUE,LIVES_BOX(hbox),NULL);
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(fit_button),mainw->last_transition_loop_to_fit);
 
-    g_signal_connect (GTK_OBJECT (fit_button), "toggled",
-		      G_CALLBACK (on_fit_toggled),
+    lives_signal_connect (LIVES_GUI_OBJECT (fit_button), LIVES_WIDGET_TOGGLED_EVENT,
+		      LIVES_GUI_CALLBACK (on_fit_toggled),
 		      NULL);
   }
 
@@ -204,35 +204,35 @@ void create_merge_dialog (void) {
 
 
   dialog_action_area = lives_dialog_get_action_area(LIVES_DIALOG (merge_opts->merge_dialog));
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
+  lives_button_box_set_layout (LIVES_BUTTON_BOX (dialog_action_area), LIVES_BUTTONBOX_END);
 
-  cancelbutton = lives_button_new_from_stock ("gtk-cancel");
-  lives_dialog_add_action_widget (LIVES_DIALOG (merge_opts->merge_dialog), cancelbutton, GTK_RESPONSE_CANCEL);
+  cancelbutton = lives_button_new_from_stock (LIVES_STOCK_CANCEL);
+  lives_dialog_add_action_widget (LIVES_DIALOG (merge_opts->merge_dialog), cancelbutton, LIVES_RESPONSE_CANCEL);
   lives_widget_set_can_focus (cancelbutton,TRUE);
 
-  okbutton = lives_button_new_from_stock ("gtk-ok");
-  lives_dialog_add_action_widget (LIVES_DIALOG (merge_opts->merge_dialog), okbutton, GTK_RESPONSE_OK);
+  okbutton = lives_button_new_from_stock (LIVES_STOCK_OK);
+  lives_dialog_add_action_widget (LIVES_DIALOG (merge_opts->merge_dialog), okbutton, LIVES_RESPONSE_OK);
   lives_widget_set_can_focus_and_default (okbutton);
   lives_widget_grab_default (okbutton);
 
-  g_signal_connect (GTK_OBJECT (cancelbutton), "clicked",
-                      G_CALLBACK (on_merge_cancel_clicked),
+  lives_signal_connect (LIVES_GUI_OBJECT (cancelbutton), LIVES_WIDGET_CLICKED_EVENT,
+                      LIVES_GUI_CALLBACK (on_merge_cancel_clicked),
                       rfx);
 
 
-  lives_widget_add_accelerator (cancelbutton, "activate", accel_group,
-                              LIVES_KEY_Escape,  (GdkModifierType)0, (GtkAccelFlags)0);
+  lives_widget_add_accelerator (cancelbutton, LIVES_WIDGET_CLICKED_EVENT, accel_group,
+                              LIVES_KEY_Escape,  (LiVESXModifierType)0, (LiVESAccelFlags)0);
 
 
-  g_signal_connect (GTK_OBJECT (okbutton), "clicked",
-                      G_CALLBACK (on_merge_ok_clicked),
+  lives_signal_connect (LIVES_GUI_OBJECT (okbutton), LIVES_WIDGET_CLICKED_EVENT,
+                      LIVES_GUI_CALLBACK (on_merge_ok_clicked),
                       rfx);
   
-  g_signal_connect (GTK_OBJECT(transition_combo),"changed",G_CALLBACK (on_trans_method_changed),NULL);
+  lives_signal_connect (LIVES_GUI_OBJECT(transition_combo),LIVES_WIDGET_CHANGED_EVENT,LIVES_GUI_CALLBACK (on_trans_method_changed),NULL);
   
 
-  g_signal_connect (GTK_OBJECT (align_start_button), "toggled",
-		    G_CALLBACK (on_align_start_end_toggled),
+  lives_signal_connect (LIVES_GUI_OBJECT (align_start_button), LIVES_WIDGET_TOGGLED_EVENT,
+		    LIVES_GUI_CALLBACK (on_align_start_end_toggled),
 		    rfx);
 
 
@@ -241,12 +241,12 @@ void create_merge_dialog (void) {
   }
 }
 
-static void bang (GtkWidget *widget, gpointer null) {
+static void bang (LiVESWidget *widget, gpointer null) {
   lives_widget_destroy (widget);
 }
 
 
-void on_trans_method_changed (GtkComboBox *combo, gpointer user_data) {
+void on_trans_method_changed (LiVESCombo *combo, gpointer user_data) {
   lives_rfx_t *rfx;
 
   GList *retvals;
@@ -262,7 +262,7 @@ void on_trans_method_changed (GtkComboBox *combo, gpointer user_data) {
 
   rfx=&mainw->rendered_fx[mainw->last_transition_idx];
 
-  gtk_container_foreach (LIVES_CONTAINER(merge_opts->param_vbox),bang,NULL);
+  lives_container_foreach (LIVES_CONTAINER(merge_opts->param_vbox),bang,NULL);
   on_paramwindow_cancel_clicked (NULL,rfx);
 
   idx=lives_list_index(merge_opts->trans_list,txt);
@@ -292,7 +292,7 @@ void on_trans_method_changed (GtkComboBox *combo, gpointer user_data) {
 
 
 void
-on_merge_activate                     (GtkMenuItem     *menuitem,
+on_merge_activate                     (LiVESMenuItem     *menuitem,
                                         gpointer         user_data)
 {
   create_merge_dialog();
@@ -307,7 +307,7 @@ on_merge_activate                     (GtkMenuItem     *menuitem,
 
 
 void
-on_merge_cancel_clicked                   (GtkButton       *button,
+on_merge_cancel_clicked                   (LiVESButton       *button,
 					   gpointer         user_data)
 {
   lives_rfx_t *rfx=(lives_rfx_t *)user_data;
@@ -330,7 +330,7 @@ on_merge_cancel_clicked                   (GtkButton       *button,
 
 
 void
-on_merge_ok_clicked                   (GtkButton       *button,
+on_merge_ok_clicked                   (LiVESButton       *button,
 				       gpointer         user_data)
 {
   gchar *msg;
@@ -577,30 +577,24 @@ on_merge_ok_clicked                   (GtkButton       *button,
 }
 
 
-void
-after_spinbutton_loops_changed           (GtkSpinButton   *spinbutton,
-					  gpointer user_data) {
+void after_spinbutton_loops_changed (LiVESSpinButton *spinbutton, gpointer user_data) {
   setmergealign ();
 }
 
 
-void
-on_align_start_end_toggled (GtkToggleButton *togglebutton, gpointer user_data) {
+void on_align_start_end_toggled (LiVESToggleButton *togglebutton, gpointer user_data) {
   merge_opts->align_start=!merge_opts->align_start;
   setmergealign ();
 }
 
 
-void
-on_fit_toggled (GtkToggleButton *togglebutton, gpointer user_data) {
-
+void on_fit_toggled (LiVESToggleButton *togglebutton, gpointer user_data) {
   merge_opts->loop_to_fit=!merge_opts->loop_to_fit;
   lives_widget_set_sensitive(merge_opts->spinbutton_loops,!merge_opts->loop_to_fit);
   setmergealign();
 }
 
 
-void
-on_ins_frames_toggled (GtkToggleButton *togglebutton, gpointer user_data) {
+void on_ins_frames_toggled (LiVESToggleButton *togglebutton, gpointer user_data) {
   merge_opts->ins_frames=!merge_opts->ins_frames;
 }
