@@ -121,7 +121,7 @@ static void remove_all_nodes(boolean every, omclearn_w *omclw) {
 static LIVES_INLINE int js_index(const gchar *string) {
   // js index, or midi channel number
   gchar **array=g_strsplit(string," ",-1);
-  gint res=atoi(array[1]);
+  int res=atoi(array[1]);
   g_strfreev(array);
   return res;
 }
@@ -130,7 +130,7 @@ static LIVES_INLINE int js_index(const gchar *string) {
 static LIVES_INLINE int midi_index(const gchar *string) {
   // midi controller number
   gchar **array;
-  gint res;
+  int res;
   if (get_token_count(string,' ')<3) return -1;
 
   array=g_strsplit(string," ",-1);
@@ -378,8 +378,8 @@ static int get_midi_len(int msgtype) {
 }
 
 
-static gint midi_msg_type(const gchar *string) {
-  gint type=atoi(string);
+static int midi_msg_type(const gchar *string) {
+  int type=atoi(string);
 
   if ((type&0XF0)==0X90) return OMC_MIDI_NOTE;
   if ((type&0XF0)==0x80) return OMC_MIDI_NOTE_OFF;
@@ -409,7 +409,7 @@ gchar *midi_mangle(void) {
 
   ssize_t bytes,tot=0,allowed=prefs->midi_rpt;
   unsigned char midbuf[4],xbuf[4];
-  gint target=1,mtype=0,idx;
+  int target=1,mtype=0,idx;
   boolean got_target=FALSE;
   gchar *str;
 
@@ -534,7 +534,7 @@ gchar *midi_mangle(void) {
 
 
 
-static LIVES_INLINE gchar *cut_string_elems(const gchar *string, gint nelems) {
+static LIVES_INLINE gchar *cut_string_elems(const gchar *string, int nelems) {
   // remove elements after nelems
 
   gchar *retval=g_strdup(string);
@@ -560,7 +560,7 @@ static LIVES_INLINE gchar *cut_string_elems(const gchar *string, gint nelems) {
 
 
 
-static gchar *omc_learn_get_pname(gint type, gint idx) {
+static gchar *omc_learn_get_pname(int type, int idx) {
   switch (type) {
   case OMC_MIDI_CONTROLLER:
   case OMC_MIDI_PITCH_BEND:
@@ -579,9 +579,9 @@ static gchar *omc_learn_get_pname(gint type, gint idx) {
 
 
 
-static gint omc_learn_get_pvalue(gint type, gint idx, const gchar *string) {
+static int omc_learn_get_pvalue(int type, int idx, const gchar *string) {
   gchar **array=g_strsplit(string," ",-1);
-  gint res;
+  int res;
 
   switch (type) {
   case OMC_MIDI_CONTROLLER:
@@ -598,33 +598,33 @@ static gint omc_learn_get_pvalue(gint type, gint idx, const gchar *string) {
 
 
 
-static void cell1_edited_callback (GtkCellRendererSpin *spinbutton, const gchar *path_string, const gchar *new_text, gpointer user_data) {
+static void cell1_edited_callback (LiVESCellRenderer *spinbutton, const gchar *path_string, const gchar *new_text, gpointer user_data) {
   lives_omc_match_node_t *mnode=(lives_omc_match_node_t *)user_data;
 
   lives_omc_macro_t omacro=omc_macros[mnode->macro];
 
-  gint vali;
-  gdouble vald;
+  int vali;
+  double vald;
 
-  GtkTreeIter iter;
+  LiVESTreeIter iter;
 
-  gint row;
+  int row;
 
-  gint *indices;
+  int *indices;
 
-  GtkTreePath *tpath=gtk_tree_path_new_from_string(path_string);
+  LiVESTreePath *tpath=lives_tree_path_new_from_string(path_string);
 
-  if (gtk_tree_path_get_depth(tpath)!=2) {
-    gtk_tree_path_free(tpath);
+  if (lives_tree_path_get_depth(tpath)!=2) {
+    lives_tree_path_free(tpath);
     return;
   }
 
-  indices=gtk_tree_path_get_indices(tpath);
+  indices=lives_tree_path_get_indices(tpath);
   row=indices[1];
 
-  gtk_tree_model_get_iter(GTK_TREE_MODEL(mnode->gtkstore2),&iter,tpath);
+  lives_tree_model_get_iter(LIVES_TREE_MODEL(mnode->gtkstore2),&iter,tpath);
 
-  gtk_tree_path_free(tpath);
+  lives_tree_path_free(tpath);
 
   if (row>(omacro.nparams-mnode->nvars)) {
     // text, so dont alter
@@ -642,38 +642,38 @@ static void cell1_edited_callback (GtkCellRendererSpin *spinbutton, const gchar
     break;
   }
   
-  gtk_tree_store_set(mnode->gtkstore2,&iter,VALUE2_COLUMN,new_text,-1);
+  lives_tree_store_set(mnode->gtkstore2,&iter,VALUE2_COLUMN,new_text,-1);
   
 }
 
 
 
-static void omc_macro_row_add_params(lives_omc_match_node_t *mnode, gint row, omclearn_w *omclw) {
+static void omc_macro_row_add_params(lives_omc_match_node_t *mnode, int row, omclearn_w *omclw) {
   lives_omc_macro_t macro=omc_macros[mnode->macro];
 
-  GtkCellRenderer *renderer;
-  GtkTreeViewColumn *column;
+  LiVESCellRenderer *renderer;
+  LiVESTreeViewColumn *column;
   
-  int i;
-  gchar *strval=NULL,*vname;
+  LiVESTreeIter iter1,iter2;
 
+  LiVESObject *spinadj;
+
+  gchar *strval=NULL,*vname;
   gchar *oldval=NULL,*final=NULL;
 
-  gint mfrom;
+  int mfrom;
+  register int i;
   
-  GtkTreeIter iter1,iter2;
 
-  GObject *spinadj;
-
-  mnode->gtkstore2 = gtk_tree_store_new (NUM2_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+  mnode->gtkstore2 = lives_tree_store_new (NUM2_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 
   if (macro.nparams==0) return;
 
-  gtk_tree_store_append (mnode->gtkstore2, &iter1, NULL);  /* Acquire an iterator */
-  gtk_tree_store_set (mnode->gtkstore2, &iter1, TITLE2_COLUMN, (_("Params.")), -1);
+  lives_tree_store_append (mnode->gtkstore2, &iter1, NULL);  /* Acquire an iterator */
+  lives_tree_store_set (mnode->gtkstore2, &iter1, TITLE2_COLUMN, (_("Params.")), -1);
 
   for (i=0;i<macro.nparams;i++) {
-    gtk_tree_store_append (mnode->gtkstore2, &iter2, &iter1);  /* Acquire a child iterator */
+    lives_tree_store_append (mnode->gtkstore2, &iter2, &iter1);  /* Acquire a child iterator */
        
     if (oldval!=NULL) {
       g_free(oldval);
@@ -700,42 +700,44 @@ static void omc_macro_row_add_params(lives_omc_match_node_t *mnode, gint row, om
 
     vname=macro.pname[i];
 
-    gtk_tree_store_set (mnode->gtkstore2, &iter2, TITLE2_COLUMN, vname, VALUE2_COLUMN, strval, -1);
+    lives_tree_store_set (mnode->gtkstore2, &iter2, TITLE2_COLUMN, vname, VALUE2_COLUMN, strval, -1);
   }
 
   g_free (strval);
 
-  mnode->treev2 = gtk_tree_view_new_with_model (GTK_TREE_MODEL (mnode->gtkstore2));
+  mnode->treev2 = lives_tree_view_new_with_model (LIVES_TREE_MODEL (mnode->gtkstore2));
 
   if (palette->style&STYLE_1) {
     lives_widget_set_base_color(mnode->treev2, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars);
     lives_widget_set_text_color(mnode->treev2, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars_fore);
   }
 
-  renderer = gtk_cell_renderer_text_new ();
-  column = gtk_tree_view_column_new_with_attributes (NULL,
+  renderer = lives_cell_renderer_text_new ();
+  column = lives_tree_view_column_new_with_attributes (NULL,
 						     renderer,
 						     "text", TITLE2_COLUMN,
 						     NULL);
   
-  gtk_tree_view_append_column (GTK_TREE_VIEW (mnode->treev2), column);
+  lives_tree_view_append_column (LIVES_TREE_VIEW (mnode->treev2), column);
   
-  renderer = gtk_cell_renderer_spin_new ();
+  renderer = lives_cell_renderer_spin_new ();
   
-  spinadj=(GObject *)gtk_adjustment_new (0., -100000., 100000., 1., 10., 0);
+  spinadj=(LiVESObject *)lives_adjustment_new (0., -100000., 100000., 1., 10., 0);
   
+#ifdef GUI_GTK
   g_object_set (renderer, "width-chars", 7, "mode", GTK_CELL_RENDERER_MODE_EDITABLE,
 		"editable", TRUE, "xalign", 1.0, "adjustment", spinadj, NULL);
-  
-  g_signal_connect(renderer, "edited", (GCallback) cell1_edited_callback, mnode);
+#endif  
+
+  lives_signal_connect(renderer, "edited", (GCallback) cell1_edited_callback, mnode);
   
   
-  //  renderer = gtk_cell_renderer_text_new ();
-  column = gtk_tree_view_column_new_with_attributes (_("value"),
+  //  renderer = lives_cell_renderer_text_new ();
+  column = lives_tree_view_column_new_with_attributes (_("value"),
 						     renderer,
 						     "text", VALUE2_COLUMN,
 						     NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (mnode->treev2), column);
+  lives_tree_view_append_column (LIVES_TREE_VIEW (mnode->treev2), column);
 
 
 
@@ -745,8 +747,8 @@ static void omc_macro_row_add_params(lives_omc_match_node_t *mnode, gint row, om
   lives_widget_show (mnode->treev2);
   
   lives_table_attach (LIVES_TABLE (omclw->table), mnode->treev2, 3, 4, row, row+1,
-		    (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
-		    (GtkAttachOptions) (0), 0, 0);
+		    (LiVESAttachOptions) (LIVES_FILL|LIVES_EXPAND),
+		    (LiVESAttachOptions) (0), 0, 0);
   
 
 
@@ -765,9 +767,9 @@ static void omc_learn_link_params(lives_omc_match_node_t *mnode) {
   if (mnode->fvali!=NULL) g_free(mnode->fvali);
   if (mnode->fvald!=NULL) g_free(mnode->fvald);
 
-  mnode->map=(gint *)g_malloc(omc_macro.nparams*sizint);
-  mnode->fvali=(gint *)g_malloc(omc_macro.nparams*sizint);
-  mnode->fvald=(gdouble *)g_malloc(omc_macro.nparams*sizdbl);
+  mnode->map=(int *)g_malloc(omc_macro.nparams*sizint);
+  mnode->fvali=(int *)g_malloc(omc_macro.nparams*sizint);
+  mnode->fvald=(double *)g_malloc(omc_macro.nparams*sizdbl);
 
   if (lps>mps) lps=mps;
 
@@ -800,14 +802,14 @@ static void omc_learn_link_params(lives_omc_match_node_t *mnode) {
 
 
 
-static void on_omc_combo_entry_changed (GtkComboBox *combo, gpointer ptr) {
+static void on_omc_combo_entry_changed (LiVESCombo *combo, gpointer ptr) {
   char *macro_text;
 
   int i;
     
   lives_omc_match_node_t *mnode=(lives_omc_match_node_t *)ptr;
 
-  gint row=GPOINTER_TO_INT(g_object_get_data(G_OBJECT(combo),"row"));
+  int row=GPOINTER_TO_INT(g_object_get_data(G_OBJECT(combo),"row"));
   omclearn_w *omclw=(omclearn_w *)g_object_get_data(G_OBJECT(combo),"omclw");
 
   macro_text=lives_combo_get_active_text(LIVES_COMBO(combo));
@@ -848,31 +850,31 @@ static void on_omc_combo_entry_changed (GtkComboBox *combo, gpointer ptr) {
 
 
 
-static void cell_toggled_callback (GtkCellRendererToggle *toggle, const gchar *path_string, gpointer user_data) {
+static void cell_toggled_callback (LiVESCellRenderer *toggle, const gchar *path_string, gpointer user_data) {
   lives_omc_match_node_t *mnode=(lives_omc_match_node_t *)user_data;
-  gint row;
+  int row;
 
   gchar *txt;
 
-  gint *indices;
+  int *indices;
 
-  GtkTreePath *tpath=gtk_tree_path_new_from_string(path_string);
+  LiVESTreePath *tpath=lives_tree_path_new_from_string(path_string);
 
-  GtkTreeIter iter;
+  LiVESTreeIter iter;
 
-  if (gtk_tree_path_get_depth(tpath)!=2) {
-    gtk_tree_path_free(tpath);
+  if (lives_tree_path_get_depth(tpath)!=2) {
+    lives_tree_path_free(tpath);
     return;
   }
 
-  indices=gtk_tree_path_get_indices(tpath);
+  indices=lives_tree_path_get_indices(tpath);
   row=indices[1];
 
-  gtk_tree_model_get_iter(GTK_TREE_MODEL(mnode->gtkstore),&iter,tpath);
+  lives_tree_model_get_iter(LIVES_TREE_MODEL(mnode->gtkstore),&iter,tpath);
 
-  gtk_tree_path_free(tpath);
+  lives_tree_path_free(tpath);
 
-  gtk_tree_model_get(GTK_TREE_MODEL(mnode->gtkstore),&iter,VALUE_COLUMN,&txt,-1);
+  lives_tree_model_get(LIVES_TREE_MODEL(mnode->gtkstore),&iter,VALUE_COLUMN,&txt,-1);
 
   if (!strcmp(txt,"-")) {
     g_free(txt);
@@ -883,7 +885,7 @@ static void cell_toggled_callback (GtkCellRendererToggle *toggle, const gchar *p
 
   mnode->matchp[row]=!(mnode->matchp[row]);
 
-  gtk_tree_store_set(mnode->gtkstore,&iter,FILTER_COLUMN,mnode->matchp[row],-1);
+  lives_tree_store_set(mnode->gtkstore,&iter,FILTER_COLUMN,mnode->matchp[row],-1);
 
   omc_learn_link_params(mnode);
 
@@ -891,33 +893,33 @@ static void cell_toggled_callback (GtkCellRendererToggle *toggle, const gchar *p
 
 
 
-static void cell_edited_callback (GtkCellRendererSpin *spinbutton, const gchar *path_string, const gchar *new_text, gpointer user_data) {
+static void cell_edited_callback (LiVESCellRenderer *spinbutton, const gchar *path_string, const gchar *new_text, gpointer user_data) {
   lives_omc_match_node_t *mnode=(lives_omc_match_node_t *)user_data;
 
-  gint col=GPOINTER_TO_INT(g_object_get_data(G_OBJECT(spinbutton),"colnum"));
+  int col=GPOINTER_TO_INT(g_object_get_data(G_OBJECT(spinbutton),"colnum"));
 
-  gint vali;
-  gdouble vald;
+  int vali;
+  double vald;
 
-  GtkTreeIter iter;
+  LiVESTreeIter iter;
 
-  gint row;
+  int row;
 
-  gint *indices;
+  int *indices;
 
-  GtkTreePath *tpath=gtk_tree_path_new_from_string(path_string);
+  LiVESTreePath *tpath=lives_tree_path_new_from_string(path_string);
 
-  if (gtk_tree_path_get_depth(tpath)!=2) {
-    gtk_tree_path_free(tpath);
+  if (lives_tree_path_get_depth(tpath)!=2) {
+    lives_tree_path_free(tpath);
     return;
   }
 
-  indices=gtk_tree_path_get_indices(tpath);
+  indices=lives_tree_path_get_indices(tpath);
   row=indices[1];
 
-  gtk_tree_model_get_iter(GTK_TREE_MODEL(mnode->gtkstore),&iter,tpath);
+  lives_tree_model_get_iter(LIVES_TREE_MODEL(mnode->gtkstore),&iter,tpath);
 
-  gtk_tree_path_free(tpath);
+  lives_tree_path_free(tpath);
 
   switch (col) {
   case OFFS1_COLUMN:
@@ -934,7 +936,7 @@ static void cell_edited_callback (GtkCellRendererSpin *spinbutton, const gchar *
     break;
   }
 
-  gtk_tree_store_set(mnode->gtkstore,&iter,col,new_text,-1);
+  lives_tree_store_set(mnode->gtkstore,&iter,col,new_text,-1);
  
 }
 
@@ -945,10 +947,10 @@ static void cell_edited_callback (GtkCellRendererSpin *spinbutton, const gchar *
 
 
 
-static GtkWidget *create_omc_macro_combo(lives_omc_match_node_t *mnode, gint row, omclearn_w *omclw) {
+static LiVESWidget *create_omc_macro_combo(lives_omc_match_node_t *mnode, int row, omclearn_w *omclw) {
   int i;
 
-  GtkWidget *combo;
+  LiVESWidget *combo;
   
   combo=lives_combo_new();
   
@@ -963,7 +965,7 @@ static GtkWidget *create_omc_macro_combo(lives_omc_match_node_t *mnode, gint row
     lives_combo_set_active_index (LIVES_COMBO(combo),mnode->macro);
   }
 
-  g_signal_connect_after (G_OBJECT (combo), "changed", G_CALLBACK (on_omc_combo_entry_changed), mnode);
+  lives_signal_connect_after (G_OBJECT (combo), LIVES_WIDGET_CHANGED_EVENT, LIVES_GUI_CALLBACK (on_omc_combo_entry_changed), mnode);
 
   g_object_set_data(G_OBJECT(combo),"row",GINT_TO_POINTER(row));
   g_object_set_data(G_OBJECT(combo),"omclw",(gpointer)omclw);
@@ -973,35 +975,33 @@ static GtkWidget *create_omc_macro_combo(lives_omc_match_node_t *mnode, gint row
 
 
 
-static void omc_learner_add_row(gint type, gint detail, lives_omc_match_node_t *mnode, const gchar *string, omclearn_w *omclw) {
-   GtkWidget *label,*combo;
-   GtkCellRenderer *renderer;
-   GtkTreeViewColumn *column;
+static void omc_learner_add_row(int type, int detail, lives_omc_match_node_t *mnode, const gchar *string, omclearn_w *omclw) {
+   LiVESWidget *label,*combo;
+   LiVESObject *spinadj;
+
+   LiVESCellRenderer *renderer;
+   LiVESTreeViewColumn *column;
   
-   int i,val;
+   LiVESTreeIter iter1,iter2;
+
    gchar *strval,*strval2,*strval3,*strval4,*vname,*valstr;
-
    gchar *oldval=NULL,*final=NULL;
-
    gchar *labelt=NULL;
 
-   GtkTreeIter iter1,iter2;
-
-   GObject *spinadj;
-
-   gint chan;
+   int chan,val;
+   register int i;
 
    omclw->tbl_rows++;
    lives_table_resize(LIVES_TABLE(omclw->table),omclw->tbl_rows,6);
 			
-   mnode->gtkstore = gtk_tree_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_STRING, 
+   mnode->gtkstore = lives_tree_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_STRING, 
 					 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 
-   gtk_tree_store_append (mnode->gtkstore, &iter1, NULL);  /* Acquire an iterator */
-   gtk_tree_store_set (mnode->gtkstore, &iter1, TITLE_COLUMN, (_("Vars.")), -1);
+   lives_tree_store_append (mnode->gtkstore, &iter1, NULL);  /* Acquire an iterator */
+   lives_tree_store_set (mnode->gtkstore, &iter1, TITLE_COLUMN, (_("Vars.")), -1);
 
    for (i=0;i<mnode->nvars;i++) {
-     gtk_tree_store_append (mnode->gtkstore, &iter2, &iter1);  /* Acquire a child iterator */
+     lives_tree_store_append (mnode->gtkstore, &iter2, &iter1);  /* Acquire a child iterator */
        
      if (oldval!=NULL) {
        g_free(oldval);
@@ -1033,7 +1033,7 @@ static void omc_learner_add_row(gint type, gint detail, lives_omc_match_node_t *
        else valstr=g_strdup("-");
      }
 
-     gtk_tree_store_set (mnode->gtkstore, &iter2, TITLE_COLUMN, vname, VALUE_COLUMN, valstr, FILTER_COLUMN, mnode->matchp[i], 
+     lives_tree_store_set (mnode->gtkstore, &iter2, TITLE_COLUMN, vname, VALUE_COLUMN, valstr, FILTER_COLUMN, mnode->matchp[i], 
 			 RANGE_COLUMN, strval, OFFS1_COLUMN, strval2, SCALE_COLUMN, strval3, OFFS2_COLUMN, strval4, -1);
 
      g_free (strval);
@@ -1044,7 +1044,7 @@ static void omc_learner_add_row(gint type, gint detail, lives_omc_match_node_t *
      g_free(vname);
    }
 
-   mnode->treev1 = gtk_tree_view_new_with_model (GTK_TREE_MODEL (mnode->gtkstore));
+   mnode->treev1 = lives_tree_view_new_with_model (LIVES_TREE_MODEL (mnode->gtkstore));
 
    if (type<0) type=-type;
 
@@ -1084,8 +1084,8 @@ static void omc_learner_add_row(gint type, gint detail, lives_omc_match_node_t *
      
    omclw->tbl_currow++;
    lives_table_attach (LIVES_TABLE (omclw->table), label, 0, 1, omclw->tbl_currow, omclw->tbl_currow+1,
-		     (GtkAttachOptions) (0),
-		     (GtkAttachOptions) (0), 0, 0);
+		     (LiVESAttachOptions) (0),
+		     (LiVESAttachOptions) (0), 0, 0);
 
    // properties
   if (palette->style&STYLE_1) {
@@ -1093,106 +1093,108 @@ static void omc_learner_add_row(gint type, gint detail, lives_omc_match_node_t *
     lives_widget_set_text_color(mnode->treev1, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars_fore);
   }
 
-   renderer = gtk_cell_renderer_text_new ();
-   column = gtk_tree_view_column_new_with_attributes (NULL,
+   renderer = lives_cell_renderer_text_new ();
+   column = lives_tree_view_column_new_with_attributes (NULL,
 						      renderer,
 						      "text", TITLE_COLUMN,
 						      NULL);
   
-   gtk_tree_view_append_column (GTK_TREE_VIEW (mnode->treev1), column);
+   lives_tree_view_append_column (LIVES_TREE_VIEW (mnode->treev1), column);
   
-   renderer = gtk_cell_renderer_text_new ();
-   column = gtk_tree_view_column_new_with_attributes (_("value"),
+   renderer = lives_cell_renderer_text_new ();
+   column = lives_tree_view_column_new_with_attributes (_("value"),
 						      renderer,
 						      "text", VALUE_COLUMN,
 						      NULL);
-   gtk_tree_view_append_column (GTK_TREE_VIEW (mnode->treev1), column);
+   lives_tree_view_append_column (LIVES_TREE_VIEW (mnode->treev1), column);
   
   
-   renderer = gtk_cell_renderer_toggle_new ();
-   column = gtk_tree_view_column_new_with_attributes (_("x"),
+   renderer = lives_cell_renderer_toggle_new ();
+   column = lives_tree_view_column_new_with_attributes (_("x"),
 						      renderer,
 						      "active", FILTER_COLUMN,
 						      NULL);
-   gtk_tree_view_append_column (GTK_TREE_VIEW (mnode->treev1), column);
+   lives_tree_view_append_column (LIVES_TREE_VIEW (mnode->treev1), column);
 
-   g_signal_connect(renderer, "toggled", (GCallback) cell_toggled_callback, mnode);
+   lives_signal_connect(renderer, LIVES_WIDGET_TOGGLED_EVENT, (GCallback) cell_toggled_callback, mnode);
 
-   renderer = gtk_cell_renderer_text_new ();
-   column = gtk_tree_view_column_new_with_attributes (_("range"),
+   renderer = lives_cell_renderer_text_new ();
+   column = lives_tree_view_column_new_with_attributes (_("range"),
 						      renderer,
 						      "text", RANGE_COLUMN,
 						      NULL);
-   gtk_tree_view_append_column (GTK_TREE_VIEW (mnode->treev1), column);
+   lives_tree_view_append_column (LIVES_TREE_VIEW (mnode->treev1), column);
 
 
-   renderer = gtk_cell_renderer_spin_new ();
+   renderer = lives_cell_renderer_spin_new ();
    g_object_set_data(G_OBJECT(renderer), "colnum", GUINT_TO_POINTER(OFFS1_COLUMN));
 
-   spinadj=(GObject *)gtk_adjustment_new (0., -100000., 100000., 1., 10., 0);
+   spinadj=(LiVESObject *)lives_adjustment_new (0., -100000., 100000., 1., 10., 0);
 
+#ifdef GUI_GTK
    g_object_set (renderer, "width-chars", 7, "mode", GTK_CELL_RENDERER_MODE_EDITABLE,
 		 "editable", TRUE, "xalign", 1.0, "adjustment", spinadj, NULL);
+#endif
 
-   g_signal_connect(renderer, "edited", (GCallback) cell_edited_callback, mnode);
+   lives_signal_connect(renderer, "edited", (GCallback) cell_edited_callback, mnode);
 
 
 
-   column = gtk_tree_view_column_new_with_attributes (_("+ offset1"),
+   column = lives_tree_view_column_new_with_attributes (_("+ offset1"),
 						      renderer,
 						       "text", OFFS1_COLUMN,
 						      NULL);
-   gtk_tree_view_append_column (GTK_TREE_VIEW (mnode->treev1), column);
+   lives_tree_view_append_column (LIVES_TREE_VIEW (mnode->treev1), column);
 
-   renderer = gtk_cell_renderer_spin_new ();
+   renderer = lives_cell_renderer_spin_new ();
 
-   spinadj=(GObject *)gtk_adjustment_new (1., -100000., 100000., 1., 10., 0);
+   spinadj=(LiVESObject *)lives_adjustment_new (1., -100000., 100000., 1., 10., 0);
 
    g_object_set (renderer, "width-chars", 12, "mode", GTK_CELL_RENDERER_MODE_EDITABLE,
 		 "editable", TRUE, "xalign", 1.0, "adjustment", spinadj, 
 		 "digits", OMC_FP_FIX, NULL);
 
    g_object_set_data(G_OBJECT(renderer), "colnum", GUINT_TO_POINTER(SCALE_COLUMN));
-   g_signal_connect(renderer, "edited", (GCallback) cell_edited_callback, mnode);
+   lives_signal_connect(renderer, "edited", (GCallback) cell_edited_callback, mnode);
 
 
-   column = gtk_tree_view_column_new_with_attributes (_("* scale"),
+   column = lives_tree_view_column_new_with_attributes (_("* scale"),
 						      renderer,
 						      "text", SCALE_COLUMN,
 						      NULL);
-   gtk_tree_view_append_column (GTK_TREE_VIEW (mnode->treev1), column);
+   lives_tree_view_append_column (LIVES_TREE_VIEW (mnode->treev1), column);
 
-   renderer = gtk_cell_renderer_spin_new ();
+   renderer = lives_cell_renderer_spin_new ();
 
 
-   spinadj=(GObject *)gtk_adjustment_new (0., -100000., 100000., 1., 10., 0);
+   spinadj=(LiVESObject *)lives_adjustment_new (0., -100000., 100000., 1., 10., 0);
 
    g_object_set (renderer, "width-chars", 7, "mode", GTK_CELL_RENDERER_MODE_EDITABLE,
 		 "editable", TRUE, "xalign", 1.0, "adjustment", spinadj, NULL);
 
    g_object_set_data(G_OBJECT(renderer), "colnum", GUINT_TO_POINTER(OFFS2_COLUMN));
-   g_signal_connect(renderer, "edited", (GCallback) cell_edited_callback, mnode);
+   lives_signal_connect(renderer, "edited", (GCallback) cell_edited_callback, mnode);
 
 
-   column = gtk_tree_view_column_new_with_attributes (_("+ offset2"),
+   column = lives_tree_view_column_new_with_attributes (_("+ offset2"),
 						      renderer,
 						      "text", OFFS2_COLUMN,
 						      NULL);
-   gtk_tree_view_append_column (GTK_TREE_VIEW (mnode->treev1), column);
+   lives_tree_view_append_column (LIVES_TREE_VIEW (mnode->treev1), column);
 
    lives_widget_show (mnode->treev1);
   
    lives_table_attach (LIVES_TABLE (omclw->table), mnode->treev1, 1, 2, omclw->tbl_currow, omclw->tbl_currow+1,
-		     (GtkAttachOptions) (0),
-		     (GtkAttachOptions) (0), 0, 0);
+		     (LiVESAttachOptions) (0),
+		     (LiVESAttachOptions) (0), 0, 0);
 
    combo=create_omc_macro_combo(mnode,omclw->tbl_currow,omclw);
 
    lives_widget_show (combo);
   
    lives_table_attach (LIVES_TABLE (omclw->table), combo, 2, 3, omclw->tbl_currow, omclw->tbl_currow+1,
-		     (GtkAttachOptions) 0,
-		     (GtkAttachOptions) (0), 0, 0);
+		     (LiVESAttachOptions) 0,
+		     (LiVESAttachOptions) (0), 0, 0);
 
 
   if (mnode->macro==-1) lives_widget_set_sensitive(omclw->clear_button,TRUE);
@@ -1204,7 +1206,7 @@ static void omc_learner_add_row(gint type, gint detail, lives_omc_match_node_t *
 
 
 
-static void killit(GtkWidget *widget, gpointer user_data) {
+static void killit(LiVESWidget *widget, gpointer user_data) {
   lives_widget_destroy(widget);
 }
 
@@ -1212,9 +1214,9 @@ static void killit(GtkWidget *widget, gpointer user_data) {
 static void show_existing(omclearn_w *omclw) {
   GSList *slist=omc_node_list;
   lives_omc_match_node_t *mnode;
-  gint type,supertype;
+  int type,supertype;
   gchar **array,*srch;
-  gint idx;
+  int idx;
 
   while (slist!=NULL) {
     mnode=(lives_omc_match_node_t *)slist->data;
@@ -1258,12 +1260,12 @@ static void show_existing(omclearn_w *omclw) {
 
 
 
-static void clear_unmatched (GtkButton *button, gpointer user_data) {
+static void clear_unmatched (LiVESButton *button, gpointer user_data) {
   omclearn_w *omclw=(omclearn_w *)user_data;
 
   // destroy everything in table
   
-  gtk_container_foreach(LIVES_CONTAINER(omclw->table),killit,NULL);
+  lives_container_foreach(LIVES_CONTAINER(omclw->table),killit,NULL);
 
   remove_all_nodes(FALSE,omclw);
 
@@ -1272,14 +1274,14 @@ static void clear_unmatched (GtkButton *button, gpointer user_data) {
 }
 
 
-static void del_all (GtkButton *button, gpointer user_data) {
+static void del_all (LiVESButton *button, gpointer user_data) {
   omclearn_w *omclw=(omclearn_w *)user_data;
 
   if (!do_warning_dialog(_("\nClick OK to delete all entries\n"))) return;
 
   // destroy everything in table
   
-  gtk_container_foreach(LIVES_CONTAINER(omclw->table),killit,NULL);
+  lives_container_foreach(LIVES_CONTAINER(omclw->table),killit,NULL);
 
   remove_all_nodes(TRUE,omclw);
 
@@ -1287,18 +1289,18 @@ static void del_all (GtkButton *button, gpointer user_data) {
 
 
 
-static void close_learner_dialog (GtkButton *button, gpointer user_data) {
+static void close_learner_dialog (LiVESButton *button, gpointer user_data) {
   mainw->cancelled=CANCEL_USER;
 }
 
 
 
 static omclearn_w *create_omclearn_dialog(void) {
-  GtkWidget *ok_button;
-  GtkWidget *hbuttonbox;
-  GtkWidget *scrolledwindow;
-  gint winsize_h,scr_width=mainw->scr_width;
-  gint winsize_v,scr_height=mainw->scr_height;
+  LiVESWidget *ok_button;
+  LiVESWidget *hbuttonbox;
+  LiVESWidget *scrolledwindow;
+  int winsize_h,scr_width=mainw->scr_width;
+  int winsize_v,scr_height=mainw->scr_height;
   
   omclearn_w *omclw=(omclearn_w *)g_malloc(sizeof(omclearn_w));
 
@@ -1334,8 +1336,8 @@ static omclearn_w *create_omclearn_dialog(void) {
   lives_container_add (LIVES_CONTAINER (hbuttonbox), omclw->clear_button);
   
 
-  g_signal_connect (GTK_OBJECT (omclw->clear_button), "clicked",
-		    G_CALLBACK (clear_unmatched),
+  lives_signal_connect (LIVES_GUI_OBJECT (omclw->clear_button), LIVES_WIDGET_CLICKED_EVENT,
+		    LIVES_GUI_CALLBACK (clear_unmatched),
 		    (gpointer)omclw);
 
   lives_widget_set_sensitive(omclw->clear_button,FALSE);
@@ -1345,8 +1347,8 @@ static omclearn_w *create_omclearn_dialog(void) {
   lives_container_add (LIVES_CONTAINER (hbuttonbox), omclw->del_all_button);
   
 
-  g_signal_connect (GTK_OBJECT (omclw->del_all_button), "clicked",
-		    G_CALLBACK (del_all),
+  lives_signal_connect (LIVES_GUI_OBJECT (omclw->del_all_button), LIVES_WIDGET_CLICKED_EVENT,
+		    LIVES_GUI_CALLBACK (del_all),
 		    (gpointer)omclw);
 
   lives_widget_set_sensitive(omclw->del_all_button,FALSE);
@@ -1360,24 +1362,21 @@ static omclearn_w *create_omclearn_dialog(void) {
 
   lives_widget_grab_default (ok_button);
 
-#if !GTK_CHECK_VERSION(3,0,0)
-  gtk_button_box_set_child_size (GTK_BUTTON_BOX (hbuttonbox), DEF_BUTTON_WIDTH, -1);
-#else
-  lives_widget_set_size_request(ok_button,DEF_BUTTON_WIDTH*4,-1);
-  lives_widget_set_size_request(omclw->clear_button,DEF_BUTTON_WIDTH*4,-1);
-  lives_widget_set_size_request(omclw->del_all_button,DEF_BUTTON_WIDTH*4,-1);
-#endif
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_SPREAD);
+  lives_button_box_set_button_width (LIVES_BUTTON_BOX (hbuttonbox), ok_button, DEF_BUTTON_WIDTH*4);
+  lives_button_box_set_button_width (LIVES_BUTTON_BOX (hbuttonbox), omclw->clear_button, DEF_BUTTON_WIDTH*4);
+  lives_button_box_set_button_width (LIVES_BUTTON_BOX (hbuttonbox), omclw->del_all_button, DEF_BUTTON_WIDTH*4);
+
+  lives_button_box_set_layout (LIVES_BUTTON_BOX (hbuttonbox), LIVES_BUTTONBOX_SPREAD);
   
   
-  g_signal_connect (GTK_OBJECT (ok_button), "clicked",
-		    G_CALLBACK (close_learner_dialog),
+  lives_signal_connect (LIVES_GUI_OBJECT (ok_button), LIVES_WIDGET_CLICKED_EVENT,
+		    LIVES_GUI_CALLBACK (close_learner_dialog),
 		    NULL);
   
   if (prefs->gui_monitor!=0) {
-    gint xcen=mainw->mgeom[prefs->gui_monitor-1].x+(mainw->mgeom[prefs->gui_monitor-1].width
+    int xcen=mainw->mgeom[prefs->gui_monitor-1].x+(mainw->mgeom[prefs->gui_monitor-1].width
 						    -lives_widget_get_allocation_width(omclw->dialog))/2;
-    gint ycen=mainw->mgeom[prefs->gui_monitor-1].y+(mainw->mgeom[prefs->gui_monitor-1].height
+    int ycen=mainw->mgeom[prefs->gui_monitor-1].y+(mainw->mgeom[prefs->gui_monitor-1].height
 						    -lives_widget_get_allocation_height(omclw->dialog))/2;
     lives_window_set_screen(LIVES_WINDOW(omclw->dialog),mainw->mgeom[prefs->gui_monitor-1].screen);
     lives_window_move(LIVES_WINDOW(omclw->dialog),xcen,ycen);
@@ -1514,14 +1513,14 @@ static void init_omc_macros(void) {
   for (i=0;i<N_OMC_MACROS;i++) {
     if (omc_macros[i].msg!=NULL) {
       if (omc_macros[i].nparams>0) {
-	omc_macros[i].ptypes=(gint *)g_malloc(omc_macros[i].nparams*sizint);
-	omc_macros[i].mini=(gint *)g_malloc(omc_macros[i].nparams*sizint);
-	omc_macros[i].maxi=(gint *)g_malloc(omc_macros[i].nparams*sizint);
-	omc_macros[i].vali=(gint *)g_malloc(omc_macros[i].nparams*sizint);
+	omc_macros[i].ptypes=(int *)g_malloc(omc_macros[i].nparams*sizint);
+	omc_macros[i].mini=(int *)g_malloc(omc_macros[i].nparams*sizint);
+	omc_macros[i].maxi=(int *)g_malloc(omc_macros[i].nparams*sizint);
+	omc_macros[i].vali=(int *)g_malloc(omc_macros[i].nparams*sizint);
 
-	omc_macros[i].mind=(gdouble *)g_malloc(omc_macros[i].nparams*sizdbl);
-	omc_macros[i].maxd=(gdouble *)g_malloc(omc_macros[i].nparams*sizdbl);
-	omc_macros[i].vald=(gdouble *)g_malloc(omc_macros[i].nparams*sizdbl);
+	omc_macros[i].mind=(double *)g_malloc(omc_macros[i].nparams*sizdbl);
+	omc_macros[i].maxd=(double *)g_malloc(omc_macros[i].nparams*sizdbl);
+	omc_macros[i].vald=(double *)g_malloc(omc_macros[i].nparams*sizdbl);
 	omc_macros[i].pname=(gchar **)g_malloc(omc_macros[i].nparams*sizeof(gchar *));
 
       }
@@ -1643,7 +1642,7 @@ static void init_omc_macros(void) {
 }
 
 
-static int get_nfixed(gint type, const gchar *string) {
+static int get_nfixed(int type, const gchar *string) {
   int nfixed=0;
 
   switch (type) {
@@ -1694,7 +1693,7 @@ static boolean match_filtered_params(lives_omc_match_node_t *mnode, const gchar
 
 
 
-static lives_omc_match_node_t *omc_match_sig(gint type, gint index, const gchar *sig) {
+static lives_omc_match_node_t *omc_match_sig(int type, int index, const gchar *sig) {
   GSList *nlist=omc_node_list;
   gchar *srch,*cnodex;
   lives_omc_match_node_t *cnode;
@@ -1730,7 +1729,7 @@ static lives_omc_match_node_t *omc_match_sig(gint type, gint index, const gchar
 
 
 /* not used yet */
-/*static gchar *omclearn_request_min(gint type) {
+/*static gchar *omclearn_request_min(int type) {
   gchar *msg=NULL;
 
   switch (type) {
@@ -1754,7 +1753,7 @@ static lives_omc_match_node_t *omc_match_sig(gint type, gint index, const gchar
 
 
 
-static LIVES_INLINE gint omclearn_get_fixed_elems(const gchar *string1, const gchar *string2) {
+static LIVES_INLINE int omclearn_get_fixed_elems(const gchar *string1, const gchar *string2) {
   // count how many (non-space) elements match
   // e.g "a b c" and "a b d" returns 2
 
@@ -1762,8 +1761,8 @@ static LIVES_INLINE gint omclearn_get_fixed_elems(const gchar *string1, const gc
 
   register int i;
 
-  gint match=0;
-  gint stlen=MIN(strlen(string1),strlen(string2));
+  int match=0;
+  int stlen=MIN(strlen(string1),strlen(string2));
 
   for (i=0;i<stlen;i++) {
     if (strcmp((string1+i),(string2+i))) return match;
@@ -1776,9 +1775,9 @@ static LIVES_INLINE gint omclearn_get_fixed_elems(const gchar *string1, const gc
 
 
 
-static LIVES_INLINE gint get_nth_elem(const gchar *string, gint idx) {
+static LIVES_INLINE int get_nth_elem(const gchar *string, int idx) {
   gchar **array=g_strsplit(string," ",-1);
-  gint retval=atoi(array[idx]);
+  int retval=atoi(array[idx]);
   g_strfreev(array);
   return retval;
 }
@@ -1787,7 +1786,7 @@ static LIVES_INLINE gint get_nth_elem(const gchar *string, gint idx) {
 
 
 
-static lives_omc_match_node_t *lives_omc_match_node_new(gint str_type, gint index, const gchar *string, gint nfixed) {
+static lives_omc_match_node_t *lives_omc_match_node_new(int str_type, int index, const gchar *string, int nfixed) {
   int i;
   gchar *tmp;
   gchar *srch_str;
@@ -1808,13 +1807,13 @@ static lives_omc_match_node_t *lives_omc_match_node_new(gint str_type, gint inde
   else mnode->nvars=get_token_count(string,' ')-nfixed;
 
   if (mnode->nvars>0) {
-    mnode->offs0=(gint *)g_malloc(mnode->nvars*sizint);
-    mnode->scale=(gdouble *)g_malloc(mnode->nvars*sizdbl);
-    mnode->offs1=(gint *)g_malloc(mnode->nvars*sizint);
-    mnode->min=(gint *)g_malloc(mnode->nvars*sizint);
-    mnode->max=(gint *)g_malloc(mnode->nvars*sizint);
+    mnode->offs0=(int *)g_malloc(mnode->nvars*sizint);
+    mnode->scale=(double *)g_malloc(mnode->nvars*sizdbl);
+    mnode->offs1=(int *)g_malloc(mnode->nvars*sizint);
+    mnode->min=(int *)g_malloc(mnode->nvars*sizint);
+    mnode->max=(int *)g_malloc(mnode->nvars*sizint);
     mnode->matchp=(boolean *)g_malloc(mnode->nvars*sizeof(boolean));
-    mnode->matchi=(gint *)g_malloc(mnode->nvars*sizint);
+    mnode->matchi=(int *)g_malloc(mnode->nvars*sizint);
   }
 
   for (i=0;i<mnode->nvars;i++) {
@@ -1835,16 +1834,16 @@ static lives_omc_match_node_t *lives_omc_match_node_new(gint str_type, gint inde
 
 
 
-static gint *omclearn_get_values(const gchar *string, gint nfixed) {
+static int *omclearn_get_values(const gchar *string, int nfixed) {
   register int i,j;
   size_t slen,tslen;
-  gint *retvals,count=0,nvars;
+  int *retvals,count=0,nvars;
 
   slen=strlen(string);
 
   nvars=get_token_count(string,' ')-nfixed;
 
-  retvals=(gint *)g_malloc(nvars*sizint);
+  retvals=(int *)g_malloc(nvars*sizint);
 
   for (i=0;i<slen;i++) {
     if (!strncmp((string+i)," ",1)) {
@@ -1876,7 +1875,7 @@ static gint *omclearn_get_values(const gchar *string, gint nfixed) {
 
 
 
-void omclearn_match_control (lives_omc_match_node_t *mnode, gint str_type, gint index, const gchar *string, gint nfixed, omclearn_w *omclw) {
+void omclearn_match_control (lives_omc_match_node_t *mnode, int str_type, int index, const gchar *string, int nfixed, omclearn_w *omclw) {
 
   if (nfixed==-1) {
     // already there : allow user to update
@@ -1899,7 +1898,7 @@ void omclearn_match_control (lives_omc_match_node_t *mnode, gint str_type, gint
 
 
 
-lives_omc_match_node_t *omc_learn(const gchar *string, gint str_type, gint idx, omclearn_w *omclw) {
+lives_omc_match_node_t *omc_learn(const gchar *string, int str_type, int idx, omclearn_w *omclw) {
   // here we come with a string, which must be a sequence of integers
   // separated by single spaces
 
@@ -1917,7 +1916,7 @@ lives_omc_match_node_t *omc_learn(const gchar *string, gint str_type, gint idx,
 
   lives_omc_match_node_t *mnode;
 
-  gint nfixed=get_nfixed(str_type,string);
+  int nfixed=get_nfixed(str_type,string);
 
 
   switch (str_type) {
@@ -2029,7 +2028,7 @@ lives_omc_match_node_t *omc_learn(const gchar *string, gint str_type, gint idx,
 
 // in playback mode, we match the string with our database, and then convert/append the variables
 
-boolean omc_process_string(gint supertype, const gchar *string, boolean learn, omclearn_w *omclw) {
+boolean omc_process_string(int supertype, const gchar *string, boolean learn, omclearn_w *omclw) {
   // only need to set omclw if learn is TRUE
   
   // returns TRUE if we learn new, or if we carry out an action
@@ -2097,7 +2096,7 @@ boolean omc_process_string(gint supertype, const gchar *string, boolean learn, o
 
 
 
-void on_midi_learn_activate (GtkMenuItem *menuitem, gpointer user_data) {
+void on_midi_learn_activate (LiVESMenuItem *menuitem, gpointer user_data) {
   omclearn_w *omclw=create_omclearn_dialog();
   gchar *string=NULL;
 
@@ -2186,7 +2185,7 @@ static void write_fx_tag(const gchar *string, int nfixed, lives_omc_match_node_t
       if (i==2) {
 	// auto scale for fx param
 	int error,ntmpls,hint,flags;
-	gint mode=rte_key_getmode(oval0);
+	int mode=rte_key_getmode(oval0);
 	weed_plant_t *filter;
 	weed_plant_t **ptmpls;
 	weed_plant_t *ptmpl;
@@ -2248,8 +2247,8 @@ static void write_fx_tag(const gchar *string, int nfixed, lives_omc_match_node_t
 
 
 
-OSCbuf *omc_learner_decode(gint type, gint idx, const gchar *string) {
-  gint macro,nfixed;
+OSCbuf *omc_learner_decode(int type, int idx, const gchar *string) {
+  int macro,nfixed;
   lives_omc_match_node_t *mnode;
   lives_omc_macro_t omacro;
   int oval0=1,oval1=0;
@@ -2333,7 +2332,7 @@ OSCbuf *omc_learner_decode(gint type, gint idx, const gchar *string) {
 	else { 
 	  if (macro==18&&i==2) {
 	    // auto scale for fx param
-	    gint mode=rte_key_getmode(oval0);
+	    int mode=rte_key_getmode(oval0);
 	    weed_plant_t *filter;
 	    weed_plant_t **ptmpls;
 	    weed_plant_t *ptmpl;
@@ -2419,7 +2418,7 @@ OSCbuf *omc_learner_decode(gint type, gint idx, const gchar *string) {
  */
 
 
-void on_midi_save_activate (GtkMenuItem *menuitem, gpointer user_data) {
+void on_midi_save_activate (LiVESMenuItem *menuitem, gpointer user_data) {
   GSList *slist=omc_node_list;
 
   size_t srchlen;
@@ -2541,7 +2540,7 @@ static void do_midi_version_error(const gchar *fname) {
 
 
 
-void on_midi_load_activate (GtkMenuItem *menuitem, gpointer user_data) {
+void on_midi_load_activate (LiVESMenuItem *menuitem, gpointer user_data) {
   lives_omc_match_node_t *mnode;
   lives_omc_macro_t omacro;
 
@@ -2745,9 +2744,9 @@ void on_midi_load_activate (GtkMenuItem *menuitem, gpointer user_data) {
 
     omacro=omc_macros[macro];
 
-    mnode->map=(gint *)g_malloc(omacro.nparams*sizint);
-    mnode->fvali=(gint *)g_malloc(omacro.nparams*sizint);
-    mnode->fvald=(gdouble *)g_malloc(omacro.nparams*sizdbl);
+    mnode->map=(int *)g_malloc(omacro.nparams*sizint);
+    mnode->fvali=(int *)g_malloc(omacro.nparams*sizint);
+    mnode->fvald=(double *)g_malloc(omacro.nparams*sizdbl);
 
     for (j=0;j<omacro.nparams;j++) {
       bytes=lives_read_le(fd,&mnode->map[j],4,TRUE);
