@@ -50,15 +50,15 @@ void init_special (void);
 
 void add_to_special (const gchar *special_string, lives_rfx_t *);
 
-void check_for_special (lives_rfx_t *, lives_param_t *param, GtkBox *);
+void check_for_special (lives_rfx_t *, lives_param_t *param, LiVESBox *);
 
 void fd_connect_spinbutton(lives_rfx_t *);
 
 void fd_tweak(lives_rfx_t *);
 
-void after_aspect_width_changed (GtkSpinButton *, gpointer);
+void after_aspect_width_changed (LiVESSpinButton *, gpointer);
 
-void after_aspect_height_changed (GtkToggleButton *, gpointer);
+void after_aspect_height_changed (LiVESToggleButton *, gpointer);
 
 void special_cleanup (void);
 
