@@ -1,6 +1,6 @@
 // pulse.c
 // LiVES (lives-exe)
-// (c) G. Finch 2005 - 2012
+// (c) G. Finch 2005 - 2014
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -24,11 +24,11 @@ static pa_context *pcon=NULL;
 
 static pa_cvolume out_vol;
 
-static guint pulse_server_rate=0;
+static uint32_t pulse_server_rate=0;
 
 #define PULSE_READ_BYTES 48000
 
-static guchar prbuf[PULSE_READ_BYTES*2];
+static uint8_t prbuf[PULSE_READ_BYTES*2];
 
 static size_t prb=0;
 
@@ -143,14 +143,20 @@ static void pulse_buff_free(void *ptr) {
 
 
 static void sample_silence_pulse (pulse_driver_t *pdriver, size_t nbytes, size_t xbytes) {
-  guchar *buff;
+  uint8_t *buff;
   if (xbytes<=0) return;
   if (mainw->aplayer_broken) return;
   while (nbytes>0) {
     if (nbytes<xbytes) xbytes=nbytes;
-    buff=(guchar *)g_try_malloc0(xbytes);
+    buff=(uint8_t *)g_try_malloc0(xbytes);
     if (!buff) return;
     if (pdriver->astream_fd!=-1) audio_stream(buff,xbytes,pdriver->astream_fd);
+    if (mainw->audio_frame_buffer!=NULL) {
+      pthread_mutex_lock(&mainw->abuf_frame_mutex);
+      append_to_audio_buffer16(mainw->audio_frame_buffer,buff,xbytes/2,0);
+      mainw->audio_frame_buffer->samples_filled+=xbytes/2;
+      pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+    }
     pa_stream_write(pdriver->pstream,buff,xbytes,pulse_buff_free,0,PA_SEEK_RELATIVE);
     nbytes-=xbytes;
   }
@@ -191,7 +197,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
    gchar *filename;
    boolean from_memory=FALSE;
 
-   guchar *buffer;
+   uint8_t *buffer;
    size_t xbytes=pa_stream_writable_size(pstream);
 
    boolean needs_free=FALSE;
@@ -279,7 +285,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
      uint64_t numFramesToWrite;
      int64_t in_frames=0;
      uint64_t in_bytes=0,xin_bytes=0;
-     gfloat shrink_factor=1.f;
+     float shrink_factor=1.f;
      int swap_sign;
 
      lives_clip_t *xfile=afile;
@@ -335,7 +341,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 				    (double)pulseFramesAvailable+((double)fastrand()/(double)G_MAXUINT32))))
 	     *pulsed->in_achans*(pulsed->in_asamps>>3);
 	   //g_print("in bytes=%ld %ld %ld %ld %d %d\n",in_bytes,pulsed->in_arate,pulsed->out_arate,pulseFramesAvailable,pulsed->in_achans,pulsed->in_asamps);
-	   if ((shrink_factor=(gfloat)in_frames/(gfloat)pulseFramesAvailable)<0.f) {
+	   if ((shrink_factor=(float)in_frames/(float)pulseFramesAvailable)<0.f) {
 	     // reverse playback
 	     if ((pulsed->seek_pos-=in_bytes)<0) {
 	       if (pulsed->loop==AUDIO_LOOP_NONE) {
@@ -485,7 +491,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
  #ifdef DEBUG_PULSE
 	   g_printerr("%ld inputFramesAvailable == %ld, %ld, %ld %ld,pulseFramesAvailable == %ld\n", pulsed->aPlayPtr->size, inputFramesAvailable, in_frames, pulsed->in_arate,pulsed->out_arate,pulseFramesAvailable);
 #endif
-	   buffer = (guchar *)pulsed->aPlayPtr->data;
+	   buffer = (uint8_t *)pulsed->aPlayPtr->data;
 	   
 	   numFramesToWrite = MIN(pulseFramesAvailable, (inputFramesAvailable/ABS(shrink_factor)+.001));
 
@@ -500,7 +506,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 	     pulsed->sound_buffer=buffer;
 	   }
 	   else {
-	     pulsed->sound_buffer=(guchar *)g_try_malloc0(pulsed->chunk_size);
+	     pulsed->sound_buffer=(uint8_t *)g_try_malloc0(pulsed->chunk_size);
 	     if (!pulsed->sound_buffer) {
 	       sample_silence_pulse(pulsed,nframes*pulsed->out_achans*
 				    (pulsed->out_asamps>>3),xbytes);
@@ -509,7 +515,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 	     }
 
 	     if (pulsed->in_asamps==8) {
-	       sample_move_d8_d16 ((short *)(pulsed->sound_buffer),(guchar *)buffer, numFramesToWrite, in_bytes, 
+	       sample_move_d8_d16 ((short *)(pulsed->sound_buffer),(uint8_t *)buffer, numFramesToWrite, in_bytes, 
 				   shrink_factor, pulsed->out_achans, pulsed->in_achans, swap_sign?SWAP_U_TO_S:0);
 	     }
 	     else {
@@ -593,7 +599,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 	     boolean memok=FALSE;
 	     float **fp=(float**)lives_malloc(pulsed->out_achans*sizeof(float *));
 	     void *buf;
-	     pulsed->sound_buffer=(guchar *)pulsed->aPlayPtr->data;
+	     pulsed->sound_buffer=(uint8_t *)pulsed->aPlayPtr->data;
 	     buf=(void *)pulsed->sound_buffer;
 
 	     if (has_audio_filters(AF_TYPE_ANY)) {
@@ -683,7 +689,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 	     buffer=pulsed->sound_buffer;
 	   }
 	   else {
-	     buffer=(guchar *)g_try_malloc(xbytes);
+	     buffer=(uint8_t *)g_try_malloc(xbytes);
 	     if (!buffer) {
 	       sample_silence_pulse(pulsed,nframes*pulsed->out_achans*
 				    (pulsed->out_asamps>>3),xbytes);
@@ -695,6 +701,12 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 	     needs_free=TRUE;
 	   }
 	   if (pulsed->astream_fd!=-1) audio_stream(buffer,xbytes,pulsed->astream_fd);
+	   if (mainw->audio_frame_buffer!=NULL) {
+	     pthread_mutex_lock(&mainw->abuf_frame_mutex);
+	     append_to_audio_buffer16(mainw->audio_frame_buffer,buffer,xbytes/2,0);
+	     mainw->audio_frame_buffer->samples_filled+=xbytes/2;
+	     pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+	   }
 	   pa_stream_write(pulsed->pstream,buffer,xbytes,buffer==pulsed->aPlayPtr->data?NULL:
 			   pulse_buff_free,0,PA_SEEK_RELATIVE);
 	 }
@@ -704,6 +716,12 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 	     if (!shortbuffer) return;
 	     sample_move_abuf_int16(shortbuffer,pulsed->out_achans,(xbytes>>1)/pulsed->out_achans,pulsed->out_arate);
 	     if (pulsed->astream_fd!=-1) audio_stream(shortbuffer,xbytes,pulsed->astream_fd);
+	     if (mainw->audio_frame_buffer!=NULL) {
+	       pthread_mutex_lock(&mainw->abuf_frame_mutex);
+	       append_to_audio_buffer16(mainw->audio_frame_buffer,shortbuffer,xbytes/2,0);
+	       mainw->audio_frame_buffer->samples_filled+=xbytes/2;
+	       pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+	     }
 	     pa_stream_write(pulsed->pstream,shortbuffer,xbytes,pulse_buff_free,0,PA_SEEK_RELATIVE);
 	   }
 	   else {
@@ -794,7 +812,8 @@ size_t pulse_flush_read_data(pulse_driver_t *pulsed, int fileno, size_t rbytes,
   if (!holding_buff) return 0;
 
   if (ofile->asampsize==16) {
-    sample_move_d16_d16((short *)holding_buff,gbuf,frames_out,prb,out_scale,ofile->achans,pulsed->in_achans,pulsed->reverse_endian?SWAP_L_TO_X:0,swap_sign?SWAP_S_TO_U:0);
+    sample_move_d16_d16((short *)holding_buff,gbuf,frames_out,prb,out_scale,ofile->achans,pulsed->in_achans,
+			pulsed->reverse_endian?SWAP_L_TO_X:0,swap_sign?SWAP_S_TO_U:0);
   }
   else {
     sample_move_d16_d8((uint8_t *)holding_buff,gbuf,frames_out,prb,out_scale,ofile->achans,pulsed->in_achans,swap_sign?SWAP_S_TO_U:0);
@@ -836,6 +855,8 @@ static void pulse_audio_read_process (pa_stream *pstream, size_t nbytes, void *a
   void *data;
   size_t rbytes=nbytes;
 
+  if (!pulsed->in_use) return;
+
   if (mainw->playing_file<0&&prefs->audio_src==AUDIO_SRC_EXT) return; 
 
   if (mainw->effects_paused) return; // pause during record ???
@@ -866,7 +887,7 @@ static void pulse_audio_read_process (pa_stream *pstream, size_t nbytes, void *a
     // - (do not call this when recording ext window or voiceover)
 
     // in this case we read external audio, but maybe not record it
-    // we may wish to analyse the audio for example
+    // we may wish to analyse the audio for example, or push it to a video generator
 
     if (has_audio_filters(AF_TYPE_A)) {
       // convert to float, apply any analysers
@@ -888,6 +909,14 @@ static void pulse_audio_read_process (pa_stream *pstream, size_t nbytes, void *a
 	}
 	
 	sample_move_d16_float(fltbuf[i],(short*)data+i,xnframes,pulsed->in_achans,FALSE,FALSE,1.0);
+
+	if (mainw->audio_frame_buffer!=NULL) {
+	  // if we have audio triggered gens., push audio to it
+	  pthread_mutex_lock(&mainw->abuf_frame_mutex);
+	  append_to_audio_bufferf(mainw->audio_frame_buffer,fltbuf[i],xnframes,i);
+	  mainw->audio_frame_buffer->samples_filled+=xnframes;
+	  pthread_mutex_unlock(&mainw->abuf_frame_mutex);
+	}
       }
       
       if (memok) {
@@ -1153,6 +1182,7 @@ int pulse_driver_activate(pulse_driver_t *pdriver) {
     pdriver->audio_ticks=0;
     pdriver->frames_written=0;
     pdriver->usec_start=0;
+    pdriver->in_use=FALSE;
     prb=0;
 
     pa_stream_set_read_callback(pdriver->pstream,pulse_audio_read_process,pdriver);
