@@ -1,6 +1,6 @@
 // resample.c
 // LiVES
-// (c) G. Finch 2004 - 2013 <salsaman@gmail.com>
+// (c) G. Finch 2004 - 2015 <salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -700,7 +700,7 @@ static void on_reorder_activate (int rwidth, int rheight) {
 
 
 void
-on_resample_audio_activate (GtkMenuItem     *menuitem,
+on_resample_audio_activate (LiVESMenuItem     *menuitem,
 			    gpointer         user_data)
 {
    // show the playback rate - real audio rate is cfile->arps
@@ -714,8 +714,8 @@ on_resample_audio_activate (GtkMenuItem     *menuitem,
 }
 
 void
-on_resaudio_ok_clicked                      (GtkButton *button,
-					     GtkEntry *entry)
+on_resaudio_ok_clicked                      (LiVESButton *button,
+					     LiVESEntry *entry)
 {
   gchar *com,*msg;  
   int arate,achans,asampsize,arps;
@@ -874,7 +874,7 @@ on_resaudio_ok_clicked                      (GtkButton *button,
 
 
 
-static void on_resaudw_achans_changed (GtkWidget *widg, gpointer user_data) {
+static void on_resaudw_achans_changed (LiVESWidget *widg, gpointer user_data) {
   _resaudw *resaudw=(_resaudw *)user_data;
   gchar *tmp;
 
@@ -927,7 +927,7 @@ static void on_resaudw_achans_changed (GtkWidget *widg, gpointer user_data) {
 
 
 void 
-on_resaudw_asamps_changed (GtkWidget *irrelevant, gpointer rubbish) {
+on_resaudw_asamps_changed (LiVESWidget *irrelevant, gpointer rubbish) {
   if (atoi (lives_entry_get_text (LIVES_ENTRY (resaudw->entry_asamps)))==8) {
     lives_widget_set_sensitive (resaudw->rb_bigend,FALSE);
     lives_widget_set_sensitive (resaudw->rb_littleend,FALSE);
@@ -949,7 +949,7 @@ on_resaudw_asamps_changed (GtkWidget *irrelevant, gpointer rubbish) {
 
 
 void
-on_resample_video_activate (GtkMenuItem     *menuitem,
+on_resample_video_activate (LiVESMenuItem     *menuitem,
 			    gpointer         user_data)
 {
   // change speed from the menu
@@ -959,7 +959,7 @@ on_resample_video_activate (GtkMenuItem     *menuitem,
 
 
 
-void on_resample_vid_ok (GtkButton *button, GtkEntry *entry) {
+void on_resample_vid_ok (LiVESButton *button, LiVESEntry *entry) {
   int i;
   int old_frames;
   int ostart=cfile->start;
@@ -1094,7 +1094,7 @@ void on_resample_vid_ok (GtkButton *button, GtkEntry *entry) {
 
 
 
-_resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox) {
+_resaudw *create_resaudw (short type, render_details *rdet, LiVESWidget *top_vbox) {
   // type 1 == resample
   // type 2 == insert silence
   // type 3 == enter multitrack or encode or render to clip
@@ -1107,33 +1107,33 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
   // type 10 == change inside multitrack
   // type 11 == rte audio gen as rfx
 
-  GtkWidget *dialog_vbox=NULL;
-  GtkWidget *vboxx;
-  GtkWidget *vbox2;
-  GtkWidget *frame;
-  GtkWidget *label_aud=NULL;
-  GtkWidget *combo_entry2;
-  GtkWidget *combo_entry3;
-  GtkWidget *combo_entry1;
-  GtkWidget *vseparator;
-  GtkWidget *radiobutton_u1;
-  GtkWidget *radiobutton_s1;
-  GtkWidget *vbox;
-  GtkWidget *radiobutton_b1;
-  GtkWidget *radiobutton_l1;
-  GtkWidget *combo4;
-  GtkWidget *combo5;
-  GtkWidget *combo6;
-  GtkWidget *dialog_action_area;
-  GtkWidget *cancelbutton;
-  GtkWidget *okbutton;
-  GtkWidget *label;
-  GtkWidget *hseparator;
-  GtkWidget *radiobutton;
-  GtkWidget *hbox;
-  GtkWidget *hbox2;
+  LiVESWidget *dialog_vbox=NULL;
+  LiVESWidget *vboxx;
+  LiVESWidget *vbox2;
+  LiVESWidget *frame;
+  LiVESWidget *label_aud=NULL;
+  LiVESWidget *combo_entry2;
+  LiVESWidget *combo_entry3;
+  LiVESWidget *combo_entry1;
+  LiVESWidget *vseparator;
+  LiVESWidget *radiobutton_u1;
+  LiVESWidget *radiobutton_s1;
+  LiVESWidget *vbox;
+  LiVESWidget *radiobutton_b1;
+  LiVESWidget *radiobutton_l1;
+  LiVESWidget *combo4;
+  LiVESWidget *combo5;
+  LiVESWidget *combo6;
+  LiVESWidget *dialog_action_area;
+  LiVESWidget *cancelbutton;
+  LiVESWidget *okbutton;
+  LiVESWidget *label;
+  LiVESWidget *hseparator;
+  LiVESWidget *radiobutton;
+  LiVESWidget *hbox;
+  LiVESWidget *hbox2;
 
-  GtkAccelGroup *accel_group=NULL;
+  LiVESAccelGroup *accel_group=NULL;
 
   GSList *s1_group=NULL;
   GSList *e1_group=NULL;
@@ -1204,11 +1204,11 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
     resaudw->dialog = lives_standard_dialog_new (title,FALSE);
     g_free(title);
 
-    accel_group = GTK_ACCEL_GROUP(lives_accel_group_new ());
+    accel_group = LIVES_ACCEL_GROUP(lives_accel_group_new ());
     lives_window_add_accel_group (LIVES_WINDOW (resaudw->dialog), accel_group);
 
     if (prefs->show_gui) {
-      lives_window_set_transient_for(LIVES_WINDOW(resaudw->dialog),GTK_WINDOW(mainw->LiVES));
+      lives_window_set_transient_for(LIVES_WINDOW(resaudw->dialog),LIVES_WINDOW(mainw->LiVES));
     }
 
     dialog_vbox = lives_dialog_get_content_area(LIVES_DIALOG(resaudw->dialog));
@@ -1220,7 +1220,7 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
   else vboxx=top_vbox;
 
   if (type==1) {
-    frame = gtk_frame_new (NULL);
+    frame = lives_frame_new (NULL);
  
     lives_box_pack_start (LIVES_BOX (vboxx), frame, TRUE, TRUE, 0);
     
@@ -1238,21 +1238,21 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
     combo_entry2 = lives_standard_entry_new(_("Rate (Hz) "),FALSE,tmp,10,6,LIVES_BOX(hbox2),NULL);
     g_free (tmp);
 
-    gtk_editable_set_editable (GTK_EDITABLE (combo_entry2), FALSE);
+    lives_editable_set_editable (LIVES_EDITABLE (combo_entry2), FALSE);
     lives_widget_set_can_focus (combo_entry2, FALSE);
     
     tmp=g_strdup_printf ("%d",(int)mainw->fx2_val);
     combo_entry3 = lives_standard_entry_new(_("Channels"),FALSE,tmp,6,2,LIVES_BOX(hbox2),NULL);
     g_free (tmp);
 
-    gtk_editable_set_editable (GTK_EDITABLE (combo_entry3), FALSE);
+    lives_editable_set_editable (LIVES_EDITABLE (combo_entry3), FALSE);
     lives_widget_set_can_focus (combo_entry3, FALSE);
     
     tmp=g_strdup_printf ("%d",(int)mainw->fx3_val);
     combo_entry1 = lives_standard_entry_new(_("Sample Size "),FALSE,tmp,6,2,LIVES_BOX(hbox2),NULL);
     g_free (tmp);
 
-    gtk_editable_set_editable (GTK_EDITABLE (combo_entry1), FALSE);
+    lives_editable_set_editable (LIVES_EDITABLE (combo_entry1), FALSE);
     lives_widget_set_can_focus (combo_entry1, FALSE);
 
     vseparator = lives_vseparator_new ();
@@ -1314,14 +1314,14 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
 
     label = lives_standard_label_new (_("Current"));
 
-    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    lives_frame_set_label_widget (LIVES_FRAME (frame), label);
 
   }
 
   resaudw->aud_checkbutton = NULL;
 
   if (type<9||type==11) {
-    frame = gtk_frame_new (NULL);
+    frame = lives_frame_new (NULL);
 
     if (type==4) lives_box_pack_start (LIVES_BOX (vboxx), frame, FALSE, FALSE, widget_opts.packing_height);
     else lives_box_pack_start (LIVES_BOX (vboxx), frame, TRUE, TRUE, 0);
@@ -1342,7 +1342,7 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
       if (rdet!=NULL) lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON (resaudw->aud_checkbutton), rdet->achans>0);
       else lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON (resaudw->aud_checkbutton), prefs->mt_def_achans>0);
     }
-    else resaudw->aud_checkbutton = gtk_check_button_new ();
+    else resaudw->aud_checkbutton = lives_check_button_new ();
 
     hbox2 = lives_hbox_new (FALSE, 0);
     lives_box_pack_start (LIVES_BOX (vbox2), hbox2, FALSE, FALSE, widget_opts.packing_height);
@@ -1397,8 +1397,8 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
     if (type==7) lives_widget_set_sensitive(combo6,FALSE);
 
     resaudw->entry_asamps = lives_combo_get_entry(LIVES_COMBO(combo6));
-    gtk_entry_set_max_length (LIVES_ENTRY (resaudw->entry_asamps), 2);
-    gtk_editable_set_editable (GTK_EDITABLE (resaudw->entry_asamps), FALSE);
+    lives_entry_set_max_length (LIVES_ENTRY (resaudw->entry_asamps), 2);
+    lives_editable_set_editable (LIVES_EDITABLE (resaudw->entry_asamps), FALSE);
     lives_entry_set_width_chars (LIVES_ENTRY (resaudw->entry_asamps), 2);
     
     if (type<3||(type>4&&type<8)||type==11) tmp=g_strdup_printf ("%d",(int)mainw->fx3_val);
@@ -1481,8 +1481,8 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
       lives_widget_set_sensitive (resaudw->rb_bigend, FALSE);
     }
 
-    g_signal_connect (GTK_OBJECT(resaudw->entry_asamps), "changed",
-		      G_CALLBACK (on_resaudw_asamps_changed),
+    lives_signal_connect (LIVES_GUI_OBJECT(resaudw->entry_asamps), LIVES_WIDGET_CHANGED_EVENT,
+		      LIVES_GUI_CALLBACK (on_resaudw_asamps_changed),
 		      NULL);
 
     if (type>=3&&type!=11) label_aud = lives_standard_label_new (_("Audio"));
@@ -1490,12 +1490,12 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
 
     if (type==3&&type!=11&&palette->style&STYLE_1) lives_widget_set_bg_color(frame, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
 
-    gtk_frame_set_label_widget (GTK_FRAME (frame), label_aud);
+    lives_frame_set_label_widget (LIVES_FRAME (frame), label_aud);
 
   }
 
   if (type>7&&type!=11) {
-    frame = gtk_frame_new (NULL);
+    frame = lives_frame_new (NULL);
     lives_widget_show (frame);
     lives_box_pack_start (LIVES_BOX (vboxx), frame, TRUE, TRUE, 0);
 
@@ -1515,7 +1515,7 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
 
     label = lives_standard_label_new (_("Video"));
 
-    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    lives_frame_set_label_widget (LIVES_FRAME (frame), label);
   }
 
   if (type>4&&type!=11) {
@@ -1545,8 +1545,8 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
       resaudw->unlim_radiobutton=lives_standard_radio_button_new(_("Unlimited"),FALSE,rbgroup,LIVES_BOX(hbox),NULL);
       rbgroup = lives_radio_button_get_group (LIVES_RADIO_BUTTON (resaudw->unlim_radiobutton));
 
-      g_signal_connect (GTK_OBJECT (radiobutton), "toggled",
-			G_CALLBACK (on_rb_audrec_time_toggled),
+      lives_signal_connect (LIVES_GUI_OBJECT (radiobutton), LIVES_WIDGET_TOGGLED_EVENT,
+			LIVES_GUI_CALLBACK (on_rb_audrec_time_toggled),
 			(gpointer)resaudw);
 
       lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(resaudw->unlim_radiobutton),(type==5||type>7)&&type!=11);
@@ -1568,46 +1568,46 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
   if (type<3||type>4) {
     dialog_action_area = lives_dialog_get_action_area(LIVES_DIALOG (resaudw->dialog));
     lives_widget_show (dialog_action_area);
-    gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
+    lives_button_box_set_layout (LIVES_BUTTON_BOX (dialog_action_area), LIVES_BUTTONBOX_END);
     
-    cancelbutton = lives_button_new_from_stock ("gtk-cancel");
+    cancelbutton = lives_button_new_from_stock (LIVES_STOCK_CANCEL);
  
-    lives_dialog_add_action_widget (LIVES_DIALOG (resaudw->dialog), cancelbutton, GTK_RESPONSE_CANCEL);
+    lives_dialog_add_action_widget (LIVES_DIALOG (resaudw->dialog), cancelbutton, LIVES_RESPONSE_CANCEL);
     lives_widget_set_can_focus_and_default (cancelbutton);
     
-    if (accel_group!=NULL) lives_widget_add_accelerator (cancelbutton, "activate", accel_group,
-						       LIVES_KEY_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
+    if (accel_group!=NULL) lives_widget_add_accelerator (cancelbutton, LIVES_WIDGET_CLICKED_EVENT, accel_group,
+						       LIVES_KEY_Escape, (LiVESXModifierType)0, (LiVESAccelFlags)0);
     
       
-    okbutton = lives_button_new_from_stock ("gtk-ok");
+    okbutton = lives_button_new_from_stock (LIVES_STOCK_OK);
  
-    lives_dialog_add_action_widget (LIVES_DIALOG (resaudw->dialog), okbutton, GTK_RESPONSE_OK);
+    lives_dialog_add_action_widget (LIVES_DIALOG (resaudw->dialog), okbutton, LIVES_RESPONSE_OK);
     lives_widget_set_can_focus_and_default (okbutton);
     lives_widget_grab_default (okbutton);
 
     if (type<8||type==11) {
-      g_signal_connect (GTK_OBJECT (cancelbutton), "clicked",
-			G_CALLBACK (lives_general_button_clicked),
+      lives_signal_connect (LIVES_GUI_OBJECT (cancelbutton), LIVES_WIDGET_CLICKED_EVENT,
+			LIVES_GUI_CALLBACK (lives_general_button_clicked),
 			resaudw);
 
       if (type==1) {
-	g_signal_connect (GTK_OBJECT (okbutton), "clicked",
-			  G_CALLBACK (on_resaudio_ok_clicked),
+	lives_signal_connect (LIVES_GUI_OBJECT (okbutton), LIVES_WIDGET_CLICKED_EVENT,
+			  LIVES_GUI_CALLBACK (on_resaudio_ok_clicked),
 			  NULL);
       }
       else if (type==2||type==11) {
-	g_signal_connect (GTK_OBJECT (okbutton), "clicked",
-			  G_CALLBACK (on_ins_silence_details_clicked),
+	lives_signal_connect (LIVES_GUI_OBJECT (okbutton), LIVES_WIDGET_CLICKED_EVENT,
+			  LIVES_GUI_CALLBACK (on_ins_silence_details_clicked),
 			  NULL);
       }
       else if (type==5) {
-	g_signal_connect (GTK_OBJECT (okbutton), "clicked",
-			  G_CALLBACK (on_recaudclip_ok_clicked),
+	lives_signal_connect (LIVES_GUI_OBJECT (okbutton), LIVES_WIDGET_CLICKED_EVENT,
+			  LIVES_GUI_CALLBACK (on_recaudclip_ok_clicked),
 			  GINT_TO_POINTER(0));
       }
       else if (type==6||type==7) {
-	g_signal_connect (GTK_OBJECT (okbutton), "clicked",
-			  G_CALLBACK (on_recaudclip_ok_clicked),
+	lives_signal_connect (LIVES_GUI_OBJECT (okbutton), LIVES_WIDGET_CLICKED_EVENT,
+			  LIVES_GUI_CALLBACK (on_recaudclip_ok_clicked),
 			  GINT_TO_POINTER(1));
       }
       
@@ -1618,8 +1618,8 @@ _resaudw *create_resaudw (gshort type, render_details *rdet, GtkWidget *top_vbox
   }
   else {
     if (type>2&&type<5) {
-      g_signal_connect_after (GTK_OBJECT(resaudw->aud_checkbutton), "toggled",
-			      G_CALLBACK (on_resaudw_achans_changed),
+      lives_signal_connect_after (LIVES_GUI_OBJECT(resaudw->aud_checkbutton), LIVES_WIDGET_TOGGLED_EVENT,
+			      LIVES_GUI_CALLBACK (on_resaudw_achans_changed),
 			      (gpointer)resaudw);
       on_resaudw_achans_changed(resaudw->aud_checkbutton,(gpointer)resaudw);
     }
@@ -1642,23 +1642,23 @@ void create_new_pb_speed (short type) {
   // type 1 = change speed
   // type 2 = resample
 
-  GtkWidget *new_pb_speed;
-  GtkWidget *dialog_vbox;
-  GtkWidget *vbox;
-  GtkWidget *hbox;
-  GtkWidget *ca_hbox;
-  GtkWidget *label;
-  GtkWidget *label2;
-  GtkWidget *radiobutton1=NULL;
-  GtkWidget *radiobutton2=NULL;
-  GtkWidget *spinbutton_pb_speed;
-  GtkWidget *spinbutton_pb_time=NULL;
-  GtkWidget *dialog_action_area;
-  GtkWidget *cancelbutton;
-  GtkWidget *change_pb_ok;
-  GtkWidget *change_audio_speed;
+  LiVESWidget *new_pb_speed;
+  LiVESWidget *dialog_vbox;
+  LiVESWidget *vbox;
+  LiVESWidget *hbox;
+  LiVESWidget *ca_hbox;
+  LiVESWidget *label;
+  LiVESWidget *label2;
+  LiVESWidget *radiobutton1=NULL;
+  LiVESWidget *radiobutton2=NULL;
+  LiVESWidget *spinbutton_pb_speed;
+  LiVESWidget *spinbutton_pb_time=NULL;
+  LiVESWidget *dialog_action_area;
+  LiVESWidget *cancelbutton;
+  LiVESWidget *change_pb_ok;
+  LiVESWidget *change_audio_speed;
 
-  GtkAccelGroup *accel_group;
+  LiVESAccelGroup *accel_group;
 
   GSList *rbgroup = NULL;
 
@@ -1678,11 +1678,11 @@ void create_new_pb_speed (short type) {
 
   lives_container_set_border_width (LIVES_CONTAINER (new_pb_speed), widget_opts.border_width*2);
 
-  accel_group = GTK_ACCEL_GROUP(lives_accel_group_new ());
+  accel_group = LIVES_ACCEL_GROUP(lives_accel_group_new ());
   lives_window_add_accel_group (LIVES_WINDOW (new_pb_speed), accel_group);
 
   if (prefs->show_gui) {
-    lives_window_set_transient_for(LIVES_WINDOW(new_pb_speed),GTK_WINDOW(mainw->LiVES));
+    lives_window_set_transient_for(LIVES_WINDOW(new_pb_speed),LIVES_WINDOW(mainw->LiVES));
   }
 
   dialog_vbox = lives_dialog_get_content_area(LIVES_DIALOG(new_pb_speed));
@@ -1733,11 +1733,11 @@ void create_new_pb_speed (short type) {
 							 (double)((int)(cfile->frames/cfile->fps*100.))/100., 
 							 1./FPS_MAX, cfile->frames, 1., 10., 2, LIVES_BOX(hbox),NULL);
 
-    gtk_label_set_mnemonic_widget (LIVES_LABEL (label2), spinbutton_pb_time);
+    lives_label_set_mnemonic_widget (LIVES_LABEL (label2), spinbutton_pb_time);
 
   }
 
-  gtk_label_set_mnemonic_widget (LIVES_LABEL (label), spinbutton_pb_speed);
+  lives_label_set_mnemonic_widget (LIVES_LABEL (label), spinbutton_pb_speed);
 
 
   ca_hbox = lives_hbox_new (FALSE, 0);
@@ -1748,17 +1748,17 @@ void create_new_pb_speed (short type) {
 
 
   dialog_action_area = lives_dialog_get_action_area(LIVES_DIALOG (new_pb_speed));
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
+  lives_button_box_set_layout (LIVES_BUTTON_BOX (dialog_action_area), LIVES_BUTTONBOX_END);
 
-  cancelbutton = lives_button_new_from_stock ("gtk-cancel");
-  lives_dialog_add_action_widget (LIVES_DIALOG (new_pb_speed), cancelbutton, GTK_RESPONSE_CANCEL);
+  cancelbutton = lives_button_new_from_stock (LIVES_STOCK_CANCEL);
+  lives_dialog_add_action_widget (LIVES_DIALOG (new_pb_speed), cancelbutton, LIVES_RESPONSE_CANCEL);
   lives_widget_set_can_focus (cancelbutton,TRUE);
 
-  lives_widget_add_accelerator (cancelbutton, "activate", accel_group,
-                              LIVES_KEY_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
+  lives_widget_add_accelerator (cancelbutton, LIVES_WIDGET_CLICKED_EVENT, accel_group,
+                              LIVES_KEY_Escape, (LiVESXModifierType)0, (LiVESAccelFlags)0);
 
-  change_pb_ok = lives_button_new_from_stock ("gtk-ok");
-  lives_dialog_add_action_widget (LIVES_DIALOG (new_pb_speed), change_pb_ok, GTK_RESPONSE_OK);
+  change_pb_ok = lives_button_new_from_stock (LIVES_STOCK_OK);
+  lives_dialog_add_action_widget (LIVES_DIALOG (new_pb_speed), change_pb_ok, LIVES_RESPONSE_OK);
   lives_widget_set_can_focus_and_default (change_pb_ok);
   lives_widget_grab_default (change_pb_ok);
   lives_widget_grab_focus(spinbutton_pb_speed);
@@ -1766,38 +1766,38 @@ void create_new_pb_speed (short type) {
 
   reorder_leave_back=FALSE;
 
-  g_signal_connect (GTK_OBJECT (change_audio_speed), "toggled",
-		    G_CALLBACK (on_boolean_toggled),
+  lives_signal_connect (LIVES_GUI_OBJECT (change_audio_speed), LIVES_WIDGET_TOGGLED_EVENT,
+		    LIVES_GUI_CALLBACK (on_boolean_toggled),
 		    &mainw->fx1_bool);
-  g_signal_connect (GTK_OBJECT (cancelbutton), "clicked",
-		    G_CALLBACK (lives_general_button_clicked),
+  lives_signal_connect (LIVES_GUI_OBJECT (cancelbutton), LIVES_WIDGET_CLICKED_EVENT,
+		    LIVES_GUI_CALLBACK (lives_general_button_clicked),
 		    NULL);
   if (type==1) {
-    g_signal_connect (GTK_OBJECT (change_pb_ok), "clicked",
-		      G_CALLBACK (on_change_speed_ok_clicked),
+    lives_signal_connect (LIVES_GUI_OBJECT (change_pb_ok), LIVES_WIDGET_CLICKED_EVENT,
+		      LIVES_GUI_CALLBACK (on_change_speed_ok_clicked),
 		      NULL);
   }
   else if (type==2) {
-    g_signal_connect (GTK_OBJECT (change_pb_ok), "clicked",
-		      G_CALLBACK (on_resample_vid_ok),
+    lives_signal_connect (LIVES_GUI_OBJECT (change_pb_ok), LIVES_WIDGET_CLICKED_EVENT,
+		      LIVES_GUI_CALLBACK (on_resample_vid_ok),
 		      NULL);
   }
-  g_signal_connect_after (GTK_OBJECT (spinbutton_pb_speed), "value_changed",
-			  G_CALLBACK (on_spin_value_changed),
+  lives_signal_connect_after (LIVES_GUI_OBJECT (spinbutton_pb_speed), "value_changed",
+			  LIVES_GUI_CALLBACK (on_spin_value_changed),
 			  GINT_TO_POINTER (1));
 
   if (type==1) {
-    g_signal_connect_after (GTK_OBJECT (spinbutton_pb_time), "value_changed",
-			    G_CALLBACK (on_spin_value_changed),
+    lives_signal_connect_after (LIVES_GUI_OBJECT (spinbutton_pb_time), "value_changed",
+			    LIVES_GUI_CALLBACK (on_spin_value_changed),
 			    GINT_TO_POINTER (2));
-    g_signal_connect_after (GTK_OBJECT (spinbutton_pb_speed), "value_changed",
-			    G_CALLBACK (widget_act_toggle),
+    lives_signal_connect_after (LIVES_GUI_OBJECT (spinbutton_pb_speed), "value_changed",
+			    LIVES_GUI_CALLBACK (widget_act_toggle),
 			    radiobutton1);
-    g_signal_connect_after (GTK_OBJECT (spinbutton_pb_time), "value_changed",
-			    G_CALLBACK (widget_act_toggle),
+    lives_signal_connect_after (LIVES_GUI_OBJECT (spinbutton_pb_time), "value_changed",
+			    LIVES_GUI_CALLBACK (widget_act_toggle),
 			    radiobutton2);
-    g_signal_connect (GTK_OBJECT (radiobutton2), "toggled",
-		      G_CALLBACK (on_boolean_toggled),
+    lives_signal_connect (LIVES_GUI_OBJECT (radiobutton2), LIVES_WIDGET_TOGGLED_EVENT,
+		      LIVES_GUI_CALLBACK (on_boolean_toggled),
 		      &mainw->fx2_bool);
   }
 
@@ -1812,7 +1812,7 @@ void create_new_pb_speed (short type) {
 
 
 void
-on_change_speed_activate                (GtkMenuItem     *menuitem,
+on_change_speed_activate                (LiVESMenuItem     *menuitem,
 					 gpointer         user_data)
 {
   // change speed from the menu
@@ -1823,7 +1823,7 @@ on_change_speed_activate                (GtkMenuItem     *menuitem,
 
 
 
-void on_change_speed_ok_clicked (GtkButton *button, gpointer user_data) {
+void on_change_speed_ok_clicked (LiVESButton *button, gpointer user_data) {
   double arate=cfile->arate/cfile->fps;
   gchar *msg;
   boolean has_lmap_error=FALSE;
