@@ -1,6 +1,6 @@
 // rte_window.c
 // LiVES (lives-exe)
-// (c) G. Finch 2005 - 2013
+// (c) G. Finch 2005 - 2014
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -26,26 +26,26 @@
 #include "paramwindow.h"
 #include "ce_thumbs.h"
 
-static GtkWidget *rte_window_back=NULL;
+static LiVESWidget *rte_window_back=NULL;
 static int old_rte_keys_virtual=0;
 
-static GtkWidget **key_checks;
-static GtkWidget **key_grabs;
-static GtkWidget **mode_radios;
-static GtkWidget **combos;
-static GtkWidget **combo_entries;
-static GtkWidget *dummy_radio;
-static GtkWidget **nlabels;
-static GtkWidget **type_labels;
-static GtkWidget **param_buttons;
-static GtkWidget **conx_buttons;
-static GtkWidget **clear_buttons;
-static GtkWidget **info_buttons;
-static GtkWidget *clear_all_button;
-static GtkWidget *save_keymap_button;
-static GtkWidget *load_keymap_button;
+static LiVESWidget **key_checks;
+static LiVESWidget **key_grabs;
+static LiVESWidget **mode_radios;
+static LiVESWidget **combos;
+static LiVESWidget **combo_entries;
+static LiVESWidget *dummy_radio;
+static LiVESWidget **nlabels;
+static LiVESWidget **type_labels;
+static LiVESWidget **param_buttons;
+static LiVESWidget **conx_buttons;
+static LiVESWidget **clear_buttons;
+static LiVESWidget **info_buttons;
+static LiVESWidget *clear_all_button;
+static LiVESWidget *save_keymap_button;
+static LiVESWidget *load_keymap_button;
 
-static GtkWidget *datacon_dialog=NULL;
+static LiVESWidget *datacon_dialog=NULL;
 
 static gulong *ch_fns;
 static gulong *gr_fns;
@@ -60,6 +60,8 @@ static GList *name_type_list=NULL;
 
 static boolean ca_canc;
 
+static char *empty_string="";
+
 //////////////////////////////////////////////////////////////////////////////
 
 
@@ -67,9 +69,9 @@ void ret_set_key_check_state(void) {
   // set (delayed) keycheck state
   register int i;
   for (i=0;i<prefs->rte_keys_virtual;i++) {
-    g_signal_handler_block(key_checks[i],ch_fns[i]);
+    lives_signal_handler_block(key_checks[i],ch_fns[i]);
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(key_checks[i]),GPOINTER_TO_INT(g_object_get_data(G_OBJECT(key_checks[i]),"active")));
-    g_signal_handler_unblock(key_checks[i],ch_fns[i]);
+    lives_signal_handler_unblock(key_checks[i],ch_fns[i]);
   }
 }
 
@@ -99,7 +101,7 @@ void type_label_set_text (int key, int mode) {
 
 
 
-boolean on_clear_all_clicked (GtkButton *button, gpointer user_data) {
+boolean on_clear_all_clicked (LiVESButton *button, gpointer user_data) {
   int modes=rte_getmodespk();
   register int i,j;
 
@@ -387,7 +389,7 @@ static boolean save_keymap3_file(gchar *kfname) {
 
 
 
-static boolean on_save_keymap_clicked (GtkButton *button, gpointer user_data) {
+static boolean on_save_keymap_clicked (LiVESButton *button, gpointer user_data) {
   // save as keymap type 1 file - to allow backwards compatibility with older versions of LiVES
   // default.keymap
 
@@ -507,7 +509,7 @@ static boolean on_save_keymap_clicked (GtkButton *button, gpointer user_data) {
 
 
 
-void on_save_rte_defs_activate (GtkMenuItem *menuitem, gpointer user_data) {
+void on_save_rte_defs_activate (LiVESMenuItem *menuitem, gpointer user_data) {
   int fd,i;
   int retval;
   int numfx;
@@ -1250,7 +1252,7 @@ static void set_param_and_con_buttons(int key, int mode) {
 
 
 
-boolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
+boolean on_load_keymap_clicked (LiVESButton *button, gpointer user_data) {
   // show file errors at this level
   FILE *kfile=NULL;
 
@@ -1560,10 +1562,10 @@ boolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
       g_free(tmp);
 
       if (fx_idx!=-1) {
-	hashname=g_list_nth_data(hash_list,fx_idx);
+	hashname=(gchar *)g_list_nth_data(hash_list,fx_idx);
 	g_object_set_data(G_OBJECT(combos[idx]),"hashname",hashname);
       }
-      else g_object_set_data(G_OBJECT(combos[idx]),"hashname","");
+      else g_object_set_data(G_OBJECT(combos[idx]),"hashname",empty_string);
 
       // set parameters button sensitive/insensitive
       set_param_and_con_buttons(key-1,mode);
@@ -1636,17 +1638,17 @@ boolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
 
 
 
-void on_rte_info_clicked (GtkButton *button, gpointer user_data) {
+void on_rte_info_clicked (LiVESButton *button, gpointer user_data) {
   weed_plant_t *filter;
 
-  GtkWidget *rte_info_window;
-  GtkWidget *vbox;
-  GtkWidget *hbox;
-  GtkWidget *label;
-  GtkWidget *textview;
+  LiVESWidget *rte_info_window;
+  LiVESWidget *vbox;
+  LiVESWidget *hbox;
+  LiVESWidget *label;
+  LiVESWidget *textview;
 
-  GtkWidget *hbuttonbox;
-  GtkWidget *ok_button;
+  LiVESWidget *hbuttonbox;
+  LiVESWidget *ok_button;
 
   gchar *filter_name;
   gchar *filter_author;
@@ -1692,7 +1694,7 @@ void on_rte_info_clicked (GtkButton *button, gpointer user_data) {
   }
 
   lives_container_set_border_width (LIVES_CONTAINER (rte_info_window), widget_opts.border_width);
-  lives_window_set_transient_for(LIVES_WINDOW(rte_info_window),GTK_WINDOW(lives_widget_get_toplevel(LIVES_WIDGET(button))));
+  lives_window_set_transient_for(LIVES_WINDOW(rte_info_window),LIVES_WINDOW(lives_widget_get_toplevel(LIVES_WIDGET(button))));
 
   lives_window_set_default_size (LIVES_WINDOW (rte_info_window), RTE_INFO_WIDTH, RTE_INFO_HEIGHT);
 
@@ -1732,35 +1734,35 @@ void on_rte_info_clicked (GtkButton *button, gpointer user_data) {
     label = lives_standard_label_new (_("Description: "));
     lives_box_pack_start (LIVES_BOX (hbox), label, FALSE, FALSE, 0);
 
-    textview = gtk_text_view_new ();
+    textview = lives_text_view_new ();
 
     if (palette->style&STYLE_1) {
       lives_widget_set_text_color(textview, LIVES_WIDGET_STATE_NORMAL, &palette->normal_fore);
       lives_widget_set_base_color(textview, LIVES_WIDGET_STATE_NORMAL, &palette->normal_back);
     }
   
-    gtk_text_view_set_editable (GTK_TEXT_VIEW (textview), FALSE);
-    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (textview), GTK_WRAP_WORD);
-    gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (textview), FALSE);
+    lives_text_view_set_editable (LIVES_TEXT_VIEW (textview), FALSE);
+    lives_text_view_set_wrap_mode (LIVES_TEXT_VIEW (textview), LIVES_WRAP_WORD);
+    lives_text_view_set_cursor_visible (LIVES_TEXT_VIEW (textview), FALSE);
   
-    text_view_set_text (LIVES_TEXT_VIEW(textview), filter_description,-1);
+    lives_text_view_set_text (LIVES_TEXT_VIEW(textview), filter_description,-1);
     lives_box_pack_start (LIVES_BOX (hbox), textview, TRUE, TRUE, 0);
   }
 
   hbuttonbox = lives_hbutton_box_new ();
   lives_box_pack_start (LIVES_BOX (vbox), hbuttonbox, TRUE, TRUE, 0);
 
-  ok_button = lives_button_new_from_stock ("gtk-ok");
+  ok_button = lives_button_new_from_stock (LIVES_STOCK_OK);
   lives_widget_show (ok_button);
 
   lives_container_add (LIVES_CONTAINER (hbuttonbox), ok_button);
   lives_widget_set_can_focus_and_default (ok_button);
   lives_widget_grab_default (ok_button);
 
-  set_button_width(hbuttonbox,ok_button,DEF_BUTTON_WIDTH);
+  lives_button_box_set_button_width (LIVES_BUTTON_BOX (hbuttonbox), ok_button, DEF_BUTTON_WIDTH);
 
-  g_signal_connect (GTK_OBJECT (ok_button), "clicked",
-		    G_CALLBACK (lives_general_button_clicked),
+  lives_signal_connect (LIVES_GUI_OBJECT (ok_button), LIVES_WIDGET_CLICKED_EVENT,
+		    LIVES_GUI_CALLBACK (lives_general_button_clicked),
 		    NULL);
 
   g_free(filter_name);
@@ -1776,7 +1778,7 @@ void on_rte_info_clicked (GtkButton *button, gpointer user_data) {
 
 
 
-void on_clear_clicked (GtkButton *button, gpointer user_data) {
+void on_clear_clicked (LiVESButton *button, gpointer user_data) {
   // this is for the "delete" buttons, c.f. clear_all
 
   int idx=GPOINTER_TO_INT(user_data);
@@ -1806,16 +1808,16 @@ void on_clear_clicked (GtkButton *button, gpointer user_data) {
     int fx_idx=rte_keymode_get_filter_idx(key,mode);
 
     idx=key*modes+i;
-    lives_entry_set_text (LIVES_ENTRY(combo_entries[idx]),lives_entry_get_text(GTK_ENTRY(combo_entries[idx+1])));
+    lives_entry_set_text (LIVES_ENTRY(combo_entries[idx]),lives_entry_get_text(LIVES_ENTRY(combo_entries[idx+1])));
     type_label_set_text(key,i);
     pconx_remap_mode(key,i+1,i);
     cconx_remap_mode(key,i+1,i);
 
     if (fx_idx!=-1) {
-      gchar *hashname=g_list_nth_data(hash_list,fx_idx);
+      gchar *hashname=(gchar *)g_list_nth_data(hash_list,fx_idx);
       g_object_set_data(G_OBJECT(combos[idx]),"hashname",hashname);
     }
-    else g_object_set_data(G_OBJECT(combos[idx]),"hashname","");
+    else g_object_set_data(G_OBJECT(combos[idx]),"hashname",empty_string);
 
     // set parameters button sensitive/insensitive
     set_param_and_con_buttons(key,i);
@@ -1824,7 +1826,7 @@ void on_clear_clicked (GtkButton *button, gpointer user_data) {
   idx++;
   lives_entry_set_text (LIVES_ENTRY(combo_entries[idx]),"");
 
-  g_object_set_data(G_OBJECT(combos[idx]),"hashname","");
+  g_object_set_data(G_OBJECT(combos[idx]),"hashname",empty_string);
 
   // set parameters button sensitive/insensitive
   set_param_and_con_buttons(key,i);
@@ -1839,7 +1841,7 @@ void on_clear_clicked (GtkButton *button, gpointer user_data) {
 }
 
 
-static void on_datacon_clicked (GtkButton *button, gpointer user_data) {
+static void on_datacon_clicked (LiVESButton *button, gpointer user_data) {
   int idx=GPOINTER_TO_INT(user_data);
   int modes=rte_getmodespk();
   int key=(int)(idx/modes);
@@ -1852,7 +1854,7 @@ static void on_datacon_clicked (GtkButton *button, gpointer user_data) {
 }
 
 
-static void on_params_clicked (GtkButton *button, gpointer user_data) {
+static void on_params_clicked (LiVESButton *button, gpointer user_data) {
   int idx=GPOINTER_TO_INT(user_data);
   int modes=rte_getmodespk();
   int key=(int)(idx/modes);
@@ -1865,7 +1867,11 @@ static void on_params_clicked (GtkButton *button, gpointer user_data) {
     weed_plant_t *filter=rte_keymode_get_filter(key+1,mode);
     if (filter==NULL) return;
     inst=weed_instance_from_filter(filter);
+
+    // do some fiddly stuff to show the key defs.
+    weed_reinit_effect(inst,TRUE);
     apply_key_defaults(inst,key,mode);
+    weed_reinit_effect(inst,TRUE);
   }
   else {
     int error;
@@ -1897,7 +1903,7 @@ static void on_params_clicked (GtkButton *button, gpointer user_data) {
 }
 
 
-static boolean on_rtew_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
+static boolean on_rtew_delete_event (LiVESWidget *widget, GdkEvent *event, gpointer user_data) {
   if (user_data==NULL) {
     rte_window_back=rte_window;
     old_rte_keys_virtual=prefs->rte_keys_virtual;
@@ -1942,7 +1948,7 @@ static boolean on_rtew_delete_event (GtkWidget *widget, GdkEvent *event, gpointe
 }
 
 
-static void on_rtew_ok_clicked (GtkButton *button, gpointer user_data) {
+static void on_rtew_ok_clicked (LiVESButton *button, gpointer user_data) {
   on_rtew_delete_event (NULL,NULL,NULL);
 }
 
@@ -1967,9 +1973,9 @@ enum {
 
 
 
-void fx_changed (GtkComboBox *combo, gpointer user_data) {
-  GtkTreeIter iter1;
-  GtkTreeModel *model;
+void fx_changed (LiVESCombo *combo, gpointer user_data) {
+  LiVESTreeIter iter1;
+  LiVESTreeModel *model;
 
   gchar *txt;
   gchar *tmp;
@@ -1990,7 +1996,7 @@ void fx_changed (GtkComboBox *combo, gpointer user_data) {
   lives_combo_get_active_iter(combo,&iter1);
   model=lives_combo_get_model(combo);
 
-  gtk_tree_model_get(model,&iter1,HASH_COLUMN,&hashname1,-1);
+  lives_tree_model_get(model,&iter1,HASH_COLUMN,&hashname1,-1);
 
   if (!strcmp(hashname1,hashname2)) {
     g_free(hashname1);
@@ -2025,7 +2031,7 @@ void fx_changed (GtkComboBox *combo, gpointer user_data) {
   lives_combo_get_active_iter(combo,&iter1);
   model=lives_combo_get_model(combo);
 
-  gtk_tree_model_get(model,&iter1,NAME_COLUMN,&txt,-1);
+  lives_tree_model_get(model,&iter1,NAME_COLUMN,&txt,-1);
   lives_entry_set_text (LIVES_ENTRY (combo_entries[key_mode]),txt);
   g_free(txt);
 
@@ -2050,9 +2056,9 @@ void fx_changed (GtkComboBox *combo, gpointer user_data) {
 
 
 static LiVESTreeModel *rte_window_fx_model (void) {
-  GtkTreeStore *tstore;
+  LiVESTreeStore *tstore;
 
-  GtkTreeIter iter1,iter2;
+  LiVESTreeIter iter1,iter2;
 
   // fill names of our effects
   int fx_idx=0;
@@ -2063,7 +2069,7 @@ static LiVESTreeModel *rte_window_fx_model (void) {
 
   gchar *pkg=NULL,*pkgstring,*fxname;
 
-  tstore=gtk_tree_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+  tstore=lives_tree_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 
   while (list!=NULL) {
     weed_plant_t *filter=get_weed_filter(weed_get_idx_for_hashname((gchar *)g_list_nth_data(hash_list,fx_idx),TRUE));
@@ -2084,26 +2090,33 @@ static LiVESTreeModel *rte_window_fx_model (void) {
 
     if ((pkgstring=strstr(fxname,": "))!=NULL) {
       // package effect
+      if (pkg!=NULL&&strncmp(pkg,fxname,strlen(pkg))) {
+	g_free(pkg);
+	pkg=NULL;
+	lives_tree_store_append (tstore, &iter1, NULL);  /* Acquire an iterator */
+	lives_tree_store_set(tstore,&iter1,NAME_TYPE_COLUMN,list->data,NAME_COLUMN,fxname,
+			     HASH_COLUMN,g_list_nth_data(hash_list,fx_idx),-1);
+      }
       if (pkg==NULL) {
 	pkg=fxname;
 	fxname=g_strdup(pkg);
 	memset(pkgstring,0,1);
 	/* TRANSLATORS: example " - LADSPA plugins -" */
 	pkgstring=g_strdup_printf(_(" - %s plugins -"),pkg);
-	gtk_tree_store_append (tstore, &iter1, NULL);
-	gtk_tree_store_set(tstore,&iter1,NAME_TYPE_COLUMN,pkgstring,NAME_COLUMN,fxname,
+	lives_tree_store_append (tstore, &iter1, NULL);
+	lives_tree_store_set(tstore,&iter1,NAME_TYPE_COLUMN,pkgstring,NAME_COLUMN,fxname,
 			 HASH_COLUMN,g_list_nth_data(hash_list,fx_idx),-1);
 	g_free(pkgstring);
       }
-      gtk_tree_store_append (tstore, &iter2, &iter1);
-      gtk_tree_store_set(tstore,&iter2,NAME_TYPE_COLUMN,list->data,NAME_COLUMN,fxname,
+      lives_tree_store_append (tstore, &iter2, &iter1);
+      lives_tree_store_set(tstore,&iter2,NAME_TYPE_COLUMN,list->data,NAME_COLUMN,fxname,
 			 HASH_COLUMN,g_list_nth_data(hash_list,fx_idx),-1);
     }
     else {
       if (pkg!=NULL) g_free(pkg);
       pkg=NULL;
-      gtk_tree_store_append (tstore, &iter1, NULL);  /* Acquire an iterator */
-      gtk_tree_store_set(tstore,&iter1,NAME_TYPE_COLUMN,list->data,NAME_COLUMN,fxname,
+      lives_tree_store_append (tstore, &iter1, NULL);  /* Acquire an iterator */
+      lives_tree_store_set(tstore,&iter1,NAME_TYPE_COLUMN,list->data,NAME_COLUMN,fxname,
 			 HASH_COLUMN,g_list_nth_data(hash_list,fx_idx),-1);
       }
 
@@ -2129,25 +2142,25 @@ static LiVESTreeModel *rte_window_fx_model (void) {
 
 
 
-GtkWidget * create_rte_window (void) {
-  GtkWidget *rte_window;
-  GtkWidget *table;
-  GtkWidget *hbox;
-  GtkWidget *hbox2;
+LiVESWidget * create_rte_window (void) {
+  LiVESWidget *rte_window;
+  LiVESWidget *table;
+  LiVESWidget *hbox;
+  LiVESWidget *hbox2;
 
-  GtkWidget *vbox;
-  GtkWidget *label;
-  GtkWidget *combo;
-  GtkWidget *ok_button;
-  GtkWidget *top_vbox;
-  GtkWidget *hbuttonbox;
+  LiVESWidget *vbox;
+  LiVESWidget *label;
+  LiVESWidget *combo;
+  LiVESWidget *ok_button;
+  LiVESWidget *top_vbox;
+  LiVESWidget *hbuttonbox;
 
-  GtkWidget *scrolledwindow;
+  LiVESWidget *scrolledwindow;
 
   GSList *mode_group = NULL;
   GSList *grab_group = NULL;
 
-  GtkAccelGroup *rtew_accel_group;
+  LiVESAccelGroup *rtew_accel_group;
 
   LiVESTreeModel *model;
 
@@ -2188,17 +2201,17 @@ GtkWidget * create_rte_window (void) {
     goto rte_window_ready;
   }
 
-  key_checks=(GtkWidget **)g_malloc((prefs->rte_keys_virtual)*sizeof(GtkWidget *));
-  key_grabs=(GtkWidget **)g_malloc((prefs->rte_keys_virtual)*sizeof(GtkWidget *));
-  mode_radios=(GtkWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(GtkWidget *));
-  combo_entries=(GtkWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(GtkWidget *));
-  combos=(GtkWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(GtkWidget *));
-  info_buttons=(GtkWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(GtkWidget *));
-  param_buttons=(GtkWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(GtkWidget *));
-  conx_buttons=(GtkWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(GtkWidget *));
-  clear_buttons=(GtkWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(GtkWidget *));
-  nlabels=(GtkWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(GtkWidget *));
-  type_labels=(GtkWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(GtkWidget *));
+  key_checks=(LiVESWidget **)g_malloc((prefs->rte_keys_virtual)*sizeof(LiVESWidget *));
+  key_grabs=(LiVESWidget **)g_malloc((prefs->rte_keys_virtual)*sizeof(LiVESWidget *));
+  mode_radios=(LiVESWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(LiVESWidget *));
+  combo_entries=(LiVESWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(LiVESWidget *));
+  combos=(LiVESWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(LiVESWidget *));
+  info_buttons=(LiVESWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(LiVESWidget *));
+  param_buttons=(LiVESWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(LiVESWidget *));
+  conx_buttons=(LiVESWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(LiVESWidget *));
+  clear_buttons=(LiVESWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(LiVESWidget *));
+  nlabels=(LiVESWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(LiVESWidget *));
+  type_labels=(LiVESWidget **)g_malloc((prefs->rte_keys_virtual)*modes*sizeof(LiVESWidget *));
 
   ch_fns=(gulong *)g_malloc((prefs->rte_keys_virtual)*sizeof(gulong));
   gr_fns=(gulong *)g_malloc((prefs->rte_keys_virtual)*sizeof(gulong));
@@ -2218,7 +2231,7 @@ GtkWidget * create_rte_window (void) {
   lives_table_set_col_spacings (LIVES_TABLE (table), 4*widget_opts.scale);
 
   // dummy button for "no grab", we dont show this...there is a button instead
-  dummy_radio = gtk_radio_button_new (grab_group);
+  dummy_radio = lives_radio_button_new (grab_group);
   grab_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (dummy_radio));
 
   name_list=weed_get_all_names(FX_LIST_NAME);
@@ -2237,8 +2250,8 @@ GtkWidget * create_rte_window (void) {
 
     hbox = lives_hbox_new (FALSE, 0);
     lives_table_attach (LIVES_TABLE (table), hbox, i, i+1, 0, 1,
-		      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+		      (LiVESAttachOptions) (LIVES_EXPAND | LIVES_FILL),
+		      (LiVESAttachOptions) (LIVES_EXPAND | LIVES_FILL), 0, 0);
     lives_container_set_border_width (LIVES_CONTAINER (hbox), widget_opts.border_width);
     
     label = lives_standard_label_new ((tmp=g_strdup_printf(_("Ctrl-%d"),i+1)));
@@ -2255,8 +2268,8 @@ GtkWidget * create_rte_window (void) {
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(key_checks[i]),mainw->rte&(GU641<<i));
     g_object_set_data(G_OBJECT(key_checks[i]),"active",GINT_TO_POINTER(lives_toggle_button_get_active(LIVES_TOGGLE_BUTTON(key_checks[i]))));
 
-    ch_fns[i]=g_signal_connect_after (GTK_OBJECT (key_checks[i]), "toggled",
-                      G_CALLBACK (rte_on_off_callback_hook),GINT_TO_POINTER (i+1));
+    ch_fns[i]=lives_signal_connect_after (LIVES_GUI_OBJECT (key_checks[i]), LIVES_WIDGET_TOGGLED_EVENT,
+                      LIVES_GUI_CALLBACK (rte_on_off_callback_hook),GINT_TO_POINTER (i+1));
 
 
 
@@ -2269,8 +2282,8 @@ GtkWidget * create_rte_window (void) {
     grab_group = lives_radio_button_get_group (LIVES_RADIO_BUTTON (key_grabs[i]));
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(key_grabs[i]),mainw->rte_keys==i);
 
-    gr_fns[i]=g_signal_connect_after (GTK_OBJECT (key_grabs[i]), "toggled",
-				      G_CALLBACK (grabkeys_callback_hook),GINT_TO_POINTER (i));
+    gr_fns[i]=lives_signal_connect_after (LIVES_GUI_OBJECT (key_grabs[i]), LIVES_WIDGET_TOGGLED_EVENT,
+				      LIVES_GUI_CALLBACK (grabkeys_callback_hook),GINT_TO_POINTER (i));
 
     mode_group=NULL;
 
@@ -2280,8 +2293,8 @@ GtkWidget * create_rte_window (void) {
       idx=i*modes+j;
       hbox = lives_hbox_new (FALSE, 0);
       lives_table_attach (LIVES_TABLE (table), hbox, i, i+1, j+1, j+2,
-			(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-			(GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+			(LiVESAttachOptions) (LIVES_EXPAND | LIVES_FILL),
+			(LiVESAttachOptions) (LIVES_EXPAND | LIVES_FILL), 0, 0);
       lives_container_set_border_width (LIVES_CONTAINER (hbox), widget_opts.border_width);
 
 
@@ -2293,8 +2306,8 @@ GtkWidget * create_rte_window (void) {
 
       if (rte_key_getmode(i+1)==j) lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(mode_radios[idx]),TRUE);
 
-      mode_ra_fns[idx]=g_signal_connect_after (GTK_OBJECT (mode_radios[idx]), "toggled",
-					       G_CALLBACK (rtemode_callback_hook),GINT_TO_POINTER (idx));
+      mode_ra_fns[idx]=lives_signal_connect_after (LIVES_GUI_OBJECT (mode_radios[idx]), LIVES_WIDGET_TOGGLED_EVENT,
+					       LIVES_GUI_CALLBACK (rtemode_callback_hook),GINT_TO_POINTER (idx));
 
       type_labels[idx] = lives_standard_label_new ("");
 
@@ -2318,7 +2331,7 @@ GtkWidget * create_rte_window (void) {
  
       lives_combo_set_entry_text_column(LIVES_COMBO(combo),NAME_TYPE_COLUMN);
 
-      g_object_set_data (G_OBJECT(combo), "hashname", "");
+      g_object_set_data (G_OBJECT(combo), "hashname", empty_string);
       lives_box_pack_start (LIVES_BOX (hbox), combo, TRUE, TRUE, widget_opts.packing_width);
       lives_box_pack_end (LIVES_BOX (hbox), clear_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
       lives_box_pack_end (LIVES_BOX (hbox), info_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
@@ -2334,20 +2347,20 @@ GtkWidget * create_rte_window (void) {
       hbox = lives_hbox_new (FALSE, 0);
       lives_box_pack_start (LIVES_BOX (vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
-      g_signal_connect(GTK_OBJECT (combo), "changed",
-		       G_CALLBACK (fx_changed),GINT_TO_POINTER(i*rte_getmodespk()+j));
+      lives_signal_connect(LIVES_GUI_OBJECT (combo), LIVES_WIDGET_CHANGED_EVENT,
+		       LIVES_GUI_CALLBACK (fx_changed),GINT_TO_POINTER(i*rte_getmodespk()+j));
       
-      g_signal_connect (GTK_OBJECT (info_buttons[idx]), "clicked",
-			G_CALLBACK (on_rte_info_clicked),GINT_TO_POINTER (idx));
+      lives_signal_connect (LIVES_GUI_OBJECT (info_buttons[idx]), LIVES_WIDGET_CLICKED_EVENT,
+			LIVES_GUI_CALLBACK (on_rte_info_clicked),GINT_TO_POINTER (idx));
 
-      g_signal_connect (GTK_OBJECT (clear_buttons[idx]), "clicked",
-			G_CALLBACK (on_clear_clicked),GINT_TO_POINTER (idx));
+      lives_signal_connect (LIVES_GUI_OBJECT (clear_buttons[idx]), LIVES_WIDGET_CLICKED_EVENT,
+			LIVES_GUI_CALLBACK (on_clear_clicked),GINT_TO_POINTER (idx));
 
-      g_signal_connect (GTK_OBJECT (param_buttons[idx]), "clicked",
-			G_CALLBACK (on_params_clicked),GINT_TO_POINTER (idx));
+      lives_signal_connect (LIVES_GUI_OBJECT (param_buttons[idx]), LIVES_WIDGET_CLICKED_EVENT,
+			LIVES_GUI_CALLBACK (on_params_clicked),GINT_TO_POINTER (idx));
 
-      g_signal_connect (GTK_OBJECT (conx_buttons[idx]), "clicked",
-			G_CALLBACK (on_datacon_clicked),GINT_TO_POINTER (idx));
+      lives_signal_connect (LIVES_GUI_OBJECT (conx_buttons[idx]), LIVES_WIDGET_CLICKED_EVENT,
+			LIVES_GUI_CALLBACK (on_datacon_clicked),GINT_TO_POINTER (idx));
       
       lives_box_pack_start (LIVES_BOX (hbox), type_labels[idx], FALSE, FALSE, widget_opts.packing_width);
       lives_box_pack_end (LIVES_BOX (hbox), conx_buttons[idx], FALSE, FALSE, widget_opts.packing_width);
@@ -2390,35 +2403,35 @@ GtkWidget * create_rte_window (void) {
   lives_container_add (LIVES_CONTAINER (hbuttonbox), ok_button);
   lives_widget_set_can_focus_and_default (ok_button);
 
-#if !GTK_CHECK_VERSION(3,0,0)
-  gtk_button_box_set_child_size (GTK_BUTTON_BOX (hbuttonbox), DEF_BUTTON_WIDTH, -1);
-#endif
+  lives_button_box_set_button_width (LIVES_BUTTON_BOX (hbuttonbox), clear_all_button, DEF_BUTTON_WIDTH);
+  lives_button_box_set_button_width (LIVES_BUTTON_BOX (hbuttonbox), save_keymap_button, DEF_BUTTON_WIDTH);
+  lives_button_box_set_button_width (LIVES_BUTTON_BOX (hbuttonbox), load_keymap_button, DEF_BUTTON_WIDTH);
+  lives_button_box_set_button_width (LIVES_BUTTON_BOX (hbuttonbox), ok_button, DEF_BUTTON_WIDTH);
 
-
-  rtew_accel_group = GTK_ACCEL_GROUP(lives_accel_group_new ());
+  rtew_accel_group = LIVES_ACCEL_GROUP(lives_accel_group_new ());
   lives_window_add_accel_group (LIVES_WINDOW (rte_window), rtew_accel_group);
 
-  lives_widget_add_accelerator (ok_button, "activate", rtew_accel_group,
-                              LIVES_KEY_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
+  lives_widget_add_accelerator (ok_button, LIVES_WIDGET_CLICKED_EVENT, rtew_accel_group,
+                              LIVES_KEY_Escape, (LiVESXModifierType)0, (LiVESAccelFlags)0);
 
-  g_signal_connect (GTK_OBJECT (rte_window), "delete_event",
-		    G_CALLBACK (on_rtew_ok_clicked),
+  lives_signal_connect (LIVES_GUI_OBJECT (rte_window), "delete_event",
+		    LIVES_GUI_CALLBACK (on_rtew_ok_clicked),
 		    NULL);
 
-  g_signal_connect (GTK_OBJECT (ok_button), "clicked",
-		    G_CALLBACK (on_rtew_ok_clicked),
+  lives_signal_connect (LIVES_GUI_OBJECT (ok_button), LIVES_WIDGET_CLICKED_EVENT,
+		    LIVES_GUI_CALLBACK (on_rtew_ok_clicked),
 		    NULL);
 
-  g_signal_connect (GTK_OBJECT (save_keymap_button), "clicked",
-		    G_CALLBACK (on_save_keymap_clicked),
+  lives_signal_connect (LIVES_GUI_OBJECT (save_keymap_button), LIVES_WIDGET_CLICKED_EVENT,
+		    LIVES_GUI_CALLBACK (on_save_keymap_clicked),
 		    NULL);
 
-  g_signal_connect (GTK_OBJECT (load_keymap_button), "clicked",
-		    G_CALLBACK (on_load_keymap_clicked),
+  lives_signal_connect (LIVES_GUI_OBJECT (load_keymap_button), LIVES_WIDGET_CLICKED_EVENT,
+		    LIVES_GUI_CALLBACK (on_load_keymap_clicked),
 		    GINT_TO_POINTER(1));
 
-  g_signal_connect (GTK_OBJECT (clear_all_button), "clicked",
-		    G_CALLBACK (on_clear_all_clicked),
+  lives_signal_connect (LIVES_GUI_OBJECT (clear_all_button), LIVES_WIDGET_CLICKED_EVENT,
+		    LIVES_GUI_CALLBACK (on_clear_all_clicked),
 		    GINT_TO_POINTER(1));
 
  rte_window_ready:
@@ -2444,7 +2457,7 @@ GtkWidget * create_rte_window (void) {
 }
 
 
-GtkWidget *refresh_rte_window (void) {
+LiVESWidget *refresh_rte_window (void) {
   if (rte_window!=NULL) {
     lives_set_cursor_style(LIVES_CURSOR_BUSY,NULL);
     lives_set_cursor_style(LIVES_CURSOR_BUSY,rte_window);
@@ -2457,9 +2470,9 @@ GtkWidget *refresh_rte_window (void) {
 }
 
 
-void on_assign_rte_keys_activate (GtkMenuItem *menuitem, gpointer user_data) {
+void on_assign_rte_keys_activate (LiVESMenuItem *menuitem, gpointer user_data) {
   if (rte_window!=NULL) {
-    on_rtew_ok_clicked(GTK_BUTTON(dummy_radio), user_data);
+    on_rtew_ok_clicked(LIVES_BUTTON(dummy_radio), user_data);
     return;
   }
   
@@ -2469,21 +2482,21 @@ void on_assign_rte_keys_activate (GtkMenuItem *menuitem, gpointer user_data) {
 
 
 void rtew_set_keych (int key, boolean on) {
-  g_signal_handler_block(key_checks[key],ch_fns[key]);
+  lives_signal_handler_block(key_checks[key],ch_fns[key]);
   if (!pthread_mutex_trylock(&mainw->gtk_mutex)) {
     lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(key_checks[key]),on);
     pthread_mutex_unlock(&mainw->gtk_mutex);
   }
-  g_signal_handler_unblock(key_checks[key],ch_fns[key]);
+  lives_signal_handler_unblock(key_checks[key],ch_fns[key]);
   g_object_set_data(G_OBJECT(key_checks[key]),"active",GINT_TO_POINTER(on));
 }
 
 
 void rtew_set_keygr (int key) {
   if (key>=0) {
-    g_signal_handler_block(key_grabs[key],gr_fns[key]);
+    lives_signal_handler_block(key_grabs[key],gr_fns[key]);
     lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(key_grabs[key]),TRUE);
-    g_signal_handler_unblock(key_grabs[key],gr_fns[key]);
+    lives_signal_handler_unblock(key_grabs[key],gr_fns[key]);
   }
   else {
     lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(dummy_radio),TRUE);
@@ -2492,9 +2505,9 @@ void rtew_set_keygr (int key) {
 
 void rtew_set_mode_radio (int key, int mode) {
   int modes=rte_getmodespk();
-  g_signal_handler_block(mode_radios[key*modes+mode],mode_ra_fns[key*modes+mode]);
+  lives_signal_handler_block(mode_radios[key*modes+mode],mode_ra_fns[key*modes+mode]);
   lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(mode_radios[key*modes+mode]),TRUE);
-  g_signal_handler_unblock(mode_radios[key*modes+mode],mode_ra_fns[key*modes+mode]);
+  lives_signal_handler_unblock(mode_radios[key*modes+mode],mode_ra_fns[key*modes+mode]);
 }
 
 
@@ -2503,7 +2516,7 @@ void redraw_pwindow (int key, int mode) {
   GList *child_list;
   lives_rfx_t *rfx;
 
-  GtkWidget *action_area;
+  LiVESWidget *action_area;
 
   int keyw=0,modew=0;
   int i;
@@ -2517,14 +2530,16 @@ void redraw_pwindow (int key, int mode) {
     if (rfx->is_template||(key==keyw&&mode==modew)) {
       // rip out the contents
       if (mainw->invis==NULL) mainw->invis=lives_vbox_new(FALSE,0);
-      child_list=gtk_container_get_children(LIVES_CONTAINER(lives_dialog_get_content_area(LIVES_DIALOG(fx_dialog[1]))));
+      child_list=lives_container_get_children(LIVES_CONTAINER(lives_dialog_get_content_area(LIVES_DIALOG(fx_dialog[1]))));
       action_area=lives_dialog_get_action_area(LIVES_DIALOG(fx_dialog[1]));
-      gtk_container_set_focus_child(LIVES_CONTAINER(action_area),NULL);
+      // remove focus from any widget we are ripping out
+      lives_container_set_focus_child(LIVES_CONTAINER(action_area),NULL);
       for (i=0;i<g_list_length(child_list);i++) {
-	GtkWidget *widget=(GtkWidget *)g_list_nth_data(child_list,i);
+	LiVESWidget *widget=(LiVESWidget *)g_list_nth_data(child_list,i);
 	if (widget!=action_area) {
 	  // we have to do this, because using lives_widget_destroy() here 
 	  // can causes a crash [bug in gtk+ ???]
+	  // TODO - test: is this still the case ?
 	  lives_widget_reparent (widget,mainw->invis);
 	}
       }
@@ -2567,7 +2582,7 @@ void update_pwindow (int key, int i, GList *list) {
   }
 }
 
-void rte_set_defs_activate (GtkMenuItem *menuitem, gpointer user_data) {
+void rte_set_defs_activate (LiVESMenuItem *menuitem, gpointer user_data) {
   int idx=GPOINTER_TO_INT(user_data);
   weed_plant_t *filter=get_weed_filter(idx);
   lives_rfx_t *rfx;
@@ -2586,10 +2601,10 @@ void rte_set_defs_activate (GtkMenuItem *menuitem, gpointer user_data) {
 
 
 
-void rte_set_key_defs (GtkButton *button, lives_rfx_t *rfx) {
+void rte_set_key_defs (LiVESButton *button, lives_rfx_t *rfx) {
   int key,mode;
   if (mainw->textwidget_focus!=NULL) {
-    GtkWidget *textwidget=(GtkWidget *)g_object_get_data (G_OBJECT (mainw->textwidget_focus),"textwidget");
+    LiVESWidget *textwidget=(LiVESWidget *)g_object_get_data (G_OBJECT (mainw->textwidget_focus),"textwidget");
     after_param_text_changed(textwidget,rfx);
   }
 
@@ -2603,7 +2618,7 @@ void rte_set_key_defs (GtkButton *button, lives_rfx_t *rfx) {
 
 
 
-void rte_set_defs_ok (GtkButton *button, lives_rfx_t *rfx) {
+void rte_set_defs_ok (LiVESButton *button, lives_rfx_t *rfx) {
   weed_plant_t *ptmpl,*filter;
 
   lives_colRGB24_t *rgbp;
@@ -2611,7 +2626,7 @@ void rte_set_defs_ok (GtkButton *button, lives_rfx_t *rfx) {
   register int i;
 
   if (mainw->textwidget_focus!=NULL) {
-    GtkWidget *textwidget=(GtkWidget *)g_object_get_data (G_OBJECT (mainw->textwidget_focus),"textwidget");
+    LiVESWidget *textwidget=(LiVESWidget *)g_object_get_data (G_OBJECT (mainw->textwidget_focus),"textwidget");
     after_param_text_changed(textwidget,rfx);
   }
 
@@ -2650,7 +2665,7 @@ void rte_set_defs_ok (GtkButton *button, lives_rfx_t *rfx) {
 
 
 
-void rte_set_defs_cancel (GtkButton *button, lives_rfx_t *rfx) {
+void rte_set_defs_cancel (LiVESButton *button, lives_rfx_t *rfx) {
   on_paramwindow_cancel_clicked(button,rfx);
   fx_dialog[1]=NULL;
 }
@@ -2658,7 +2673,7 @@ void rte_set_defs_cancel (GtkButton *button, lives_rfx_t *rfx) {
 
 
 
-void rte_reset_defs_clicked (GtkButton *button, lives_rfx_t *rfx) {
+void rte_reset_defs_clicked (LiVESButton *button, lives_rfx_t *rfx) {
   weed_plant_t **ptmpls,**inp,**xinp;
   weed_plant_t **ctmpls;
 
@@ -2666,7 +2681,7 @@ void rte_reset_defs_clicked (GtkButton *button, lives_rfx_t *rfx) {
 
   GList *child_list;
 
-  GtkWidget *pbox,*fxdialog,*cancelbutton,*action_area;
+  LiVESWidget *pbox,*fxdialog,*cancelbutton,*action_area;
 
   int error;
   int nchans;
@@ -2678,7 +2693,7 @@ void rte_reset_defs_clicked (GtkButton *button, lives_rfx_t *rfx) {
 
   register int i;
 
-  cancelbutton=(GtkWidget *)g_object_get_data(G_OBJECT(button),"cancelbutton");
+  cancelbutton=(LiVESWidget *)g_object_get_data(G_OBJECT(button),"cancelbutton");
 
   if (cancelbutton!=NULL) is_generic_defs=TRUE;
 
@@ -2764,12 +2779,12 @@ void rte_reset_defs_clicked (GtkButton *button, lives_rfx_t *rfx) {
   // redraw the window
 
   if (mainw->invis==NULL) mainw->invis=lives_vbox_new(FALSE,0);
-  child_list=gtk_container_get_children(LIVES_CONTAINER(lives_dialog_get_content_area(LIVES_DIALOG(fxdialog))));
+  child_list=lives_container_get_children(LIVES_CONTAINER(lives_dialog_get_content_area(LIVES_DIALOG(fxdialog))));
 
   action_area=lives_dialog_get_action_area(LIVES_DIALOG (fxdialog));
 
   for (i=0;i<g_list_length(child_list);i++) {
-    GtkWidget *widget=(GtkWidget *)g_list_nth_data(child_list,i);
+    LiVESWidget *widget=(LiVESWidget *)g_list_nth_data(child_list,i);
     if (widget!=action_area) {
       // we have to do this, because using lives_widget_destroy() here 
       // can causes a crash [bug in gtk+ ???]
@@ -2777,6 +2792,8 @@ void rte_reset_defs_clicked (GtkButton *button, lives_rfx_t *rfx) {
     }
   }
   
+  if (child_list!=NULL) g_list_free(child_list);
+
   if (cancelbutton!=NULL) lives_widget_set_sensitive(cancelbutton,FALSE);
 
   make_param_box(LIVES_VBOX (pbox), rfx);
