@@ -81,7 +81,7 @@ boolean do_tempdir_query(void) {
   while (!ok) {
     response=lives_dialog_run(LIVES_DIALOG(tdentry->dialog));
 
-    if (response==GTK_RESPONSE_CANCEL) {
+    if (response==LIVES_RESPONSE_CANCEL) {
       return FALSE;
     }
     dirname=g_strdup(lives_entry_get_text(LIVES_ENTRY(tdentry->entry)));
@@ -176,7 +176,7 @@ boolean do_tempdir_query(void) {
 
 
 
-static void on_init_aplayer_toggled (GtkToggleButton *tbutton, gpointer user_data) {
+static void on_init_aplayer_toggled (LiVESToggleButton *tbutton, gpointer user_data) {
   int audp=GPOINTER_TO_INT(user_data);
 
   if (!lives_toggle_button_get_active(tbutton)) return;
@@ -207,11 +207,11 @@ static void on_init_aplayer_toggled (GtkToggleButton *tbutton, gpointer user_dat
 
 
 boolean do_audio_choice_dialog(short startup_phase) {
-  GtkWidget *dialog,*dialog_vbox,*radiobutton0,*radiobutton1,*radiobutton2,*radiobutton3,*radiobutton4,*label;
-  GtkWidget *okbutton,*cancelbutton;
-  GtkWidget *hbox;
+  LiVESWidget *dialog,*dialog_vbox,*radiobutton0,*radiobutton1,*radiobutton2,*radiobutton3,*radiobutton4,*label;
+  LiVESWidget *okbutton,*cancelbutton;
+  LiVESWidget *hbox;
 
-  GtkAccelGroup *accel_group;
+  LiVESAccelGroup *accel_group;
 
   GSList *radiobutton_group = NULL;
 
@@ -280,7 +280,7 @@ boolean do_audio_choice_dialog(short startup_phase) {
 
   dialog = lives_standard_dialog_new (_("LiVES: - Choose an audio player"),FALSE);
 
-  accel_group = GTK_ACCEL_GROUP(lives_accel_group_new ());
+  accel_group = LIVES_ACCEL_GROUP(lives_accel_group_new ());
   lives_window_add_accel_group (LIVES_WINDOW (dialog), accel_group);
 
   dialog_vbox = lives_dialog_get_content_area(LIVES_DIALOG(dialog));
@@ -305,8 +305,8 @@ boolean do_audio_choice_dialog(short startup_phase) {
     set_pref("audio_player","pulse");
   }
 
-  g_signal_connect (GTK_OBJECT (radiobutton0), "toggled",
-                      G_CALLBACK (on_init_aplayer_toggled),
+  lives_signal_connect (LIVES_GUI_OBJECT (radiobutton0), LIVES_WIDGET_TOGGLED_EVENT,
+                      LIVES_GUI_CALLBACK (on_init_aplayer_toggled),
                       GINT_TO_POINTER(AUD_PLAYER_PULSE));
 
 
@@ -326,8 +326,8 @@ boolean do_audio_choice_dialog(short startup_phase) {
     set_pref("audio_player","jack");
   }
 
-  g_signal_connect (GTK_OBJECT (radiobutton1), "toggled",
-                      G_CALLBACK (on_init_aplayer_toggled),
+  lives_signal_connect (LIVES_GUI_OBJECT (radiobutton1), LIVES_WIDGET_TOGGLED_EVENT,
+                      LIVES_GUI_CALLBACK (on_init_aplayer_toggled),
                       GINT_TO_POINTER(AUD_PLAYER_JACK));
 
 
@@ -347,8 +347,8 @@ boolean do_audio_choice_dialog(short startup_phase) {
       set_pref("audio_player","sox");
     }
 
-    g_signal_connect (GTK_OBJECT (radiobutton2), "toggled",
-                      G_CALLBACK (on_init_aplayer_toggled),
+    lives_signal_connect (LIVES_GUI_OBJECT (radiobutton2), LIVES_WIDGET_TOGGLED_EVENT,
+                      LIVES_GUI_CALLBACK (on_init_aplayer_toggled),
                       GINT_TO_POINTER(AUD_PLAYER_SOX));
 
 
@@ -367,8 +367,8 @@ boolean do_audio_choice_dialog(short startup_phase) {
       set_pref("audio_player","mplayer");
     }
 						    
-    g_signal_connect (GTK_OBJECT (radiobutton3), "toggled",
-		      G_CALLBACK (on_init_aplayer_toggled),
+    lives_signal_connect (LIVES_GUI_OBJECT (radiobutton3), LIVES_WIDGET_TOGGLED_EVENT,
+		      LIVES_GUI_CALLBACK (on_init_aplayer_toggled),
                       GINT_TO_POINTER(AUD_PLAYER_MPLAYER));
 
 
@@ -387,24 +387,24 @@ boolean do_audio_choice_dialog(short startup_phase) {
       set_pref("audio_player","mplayer2");
     }
 						    
-    g_signal_connect (GTK_OBJECT (radiobutton4), "toggled",
-		      G_CALLBACK (on_init_aplayer_toggled),
+    lives_signal_connect (LIVES_GUI_OBJECT (radiobutton4), LIVES_WIDGET_TOGGLED_EVENT,
+		      LIVES_GUI_CALLBACK (on_init_aplayer_toggled),
                       GINT_TO_POINTER(AUD_PLAYER_MPLAYER2));
 
 
   }
 
-  cancelbutton = lives_button_new_from_stock ("gtk-cancel");
+  cancelbutton = lives_button_new_from_stock (LIVES_STOCK_CANCEL);
   lives_widget_show (cancelbutton);
-  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), cancelbutton, GTK_RESPONSE_CANCEL);
+  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), cancelbutton, LIVES_RESPONSE_CANCEL);
 
-  lives_widget_add_accelerator (cancelbutton, "activate", accel_group,
-                              LIVES_KEY_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
+  lives_widget_add_accelerator (cancelbutton, LIVES_WIDGET_CLICKED_EVENT, accel_group,
+                              LIVES_KEY_Escape, (LiVESXModifierType)0, (LiVESAccelFlags)0);
 
-  okbutton = lives_button_new_from_stock ("gtk-go-forward");
-  lives_button_set_label(GTK_BUTTON(okbutton),_("_Next"));
+  okbutton = lives_button_new_from_stock (LIVES_STOCK_GO_FORWARD);
+  lives_button_set_label(LIVES_BUTTON(okbutton),_("_Next"));
   lives_widget_show (okbutton);
-  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), okbutton, GTK_RESPONSE_OK);
+  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), okbutton, LIVES_RESPONSE_OK);
   lives_widget_set_can_focus_and_default (okbutton);
   lives_widget_grab_default(okbutton);
   lives_widget_grab_focus(okbutton);
@@ -412,7 +412,7 @@ boolean do_audio_choice_dialog(short startup_phase) {
 
   if (prefs->audio_player==-1) {
     do_no_mplayer_sox_error();
-    return GTK_RESPONSE_CANCEL;
+    return LIVES_RESPONSE_CANCEL;
   }
 
   lives_widget_show_all(dialog);
@@ -429,25 +429,25 @@ boolean do_audio_choice_dialog(short startup_phase) {
 
   lives_widget_context_update();
 
-  return (response==GTK_RESPONSE_OK);
+  return (response==LIVES_RESPONSE_OK);
 }
 
 
-static void add_test(GtkWidget *table, int row, gchar *ttext, boolean noskip) {
-  GtkWidget *label=lives_standard_label_new(ttext);
+static void add_test(LiVESWidget *table, int row, gchar *ttext, boolean noskip) {
+  LiVESWidget *label=lives_standard_label_new(ttext);
 
-  lives_table_attach (LIVES_TABLE (table), label, 0, 1, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
+  lives_table_attach (LIVES_TABLE (table), label, 0, 1, row, row+1, (LiVESAttachOptions)0, (LiVESAttachOptions)0, 10, 10);
   lives_widget_show(label);
 
   if (!noskip) {
-    GtkWidget *image=lives_image_new_from_stock(LIVES_STOCK_REMOVE,LIVES_ICON_SIZE_LARGE_TOOLBAR);
+    LiVESWidget *image=lives_image_new_from_stock(LIVES_STOCK_REMOVE,LIVES_ICON_SIZE_LARGE_TOOLBAR);
     // TRANSLATORS - as in "skipped test"
     label=lives_standard_label_new(_("Skipped"));
 
-    lives_table_attach (LIVES_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
+    lives_table_attach (LIVES_TABLE (table), label, 1, 2, row, row+1, (LiVESAttachOptions)0, (LiVESAttachOptions)0, 10, 10);
     lives_widget_show(label);
 
-    lives_table_attach (LIVES_TABLE (table), image, 2, 3, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 0, 10);
+    lives_table_attach (LIVES_TABLE (table), image, 2, 3, row, row+1, (LiVESAttachOptions)0, (LiVESAttachOptions)0, 0, 10);
     lives_widget_show(image);
   }
 
@@ -455,20 +455,20 @@ static void add_test(GtkWidget *table, int row, gchar *ttext, boolean noskip) {
 }
 
 
-static boolean pass_test(GtkWidget *table, int row) {
+static boolean pass_test(LiVESWidget *table, int row) {
   // TRANSLATORS - as in "passed test"
-  GtkWidget *label=lives_standard_label_new(_("Passed"));
+  LiVESWidget *label=lives_standard_label_new(_("Passed"));
 
 #if GTK_CHECK_VERSION(3,10,0)
-  GtkWidget *image=lives_image_new_from_stock(LIVES_STOCK_ADD,LIVES_ICON_SIZE_LARGE_TOOLBAR);
+  LiVESWidget *image=lives_image_new_from_stock(LIVES_STOCK_ADD,LIVES_ICON_SIZE_LARGE_TOOLBAR);
 #else
-  GtkWidget *image=lives_image_new_from_stock(GTK_STOCK_APPLY,LIVES_ICON_SIZE_LARGE_TOOLBAR);
+  LiVESWidget *image=lives_image_new_from_stock(LIVES_STOCK_APPLY,LIVES_ICON_SIZE_LARGE_TOOLBAR);
 #endif
 
-  lives_table_attach (LIVES_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
+  lives_table_attach (LIVES_TABLE (table), label, 1, 2, row, row+1, (LiVESAttachOptions)0, (LiVESAttachOptions)0, 10, 10);
   lives_widget_show(label);
 
-  lives_table_attach (LIVES_TABLE (table), image, 2, 3, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 0, 10);
+  lives_table_attach (LIVES_TABLE (table), image, 2, 3, row, row+1, (LiVESAttachOptions)0, (LiVESAttachOptions)0, 0, 10);
   lives_widget_show(image);
 
   lives_widget_context_update();
@@ -476,26 +476,26 @@ static boolean pass_test(GtkWidget *table, int row) {
 }
 
 
-static boolean fail_test(GtkWidget *table, int row, gchar *ftext) {
-  GtkWidget *label;
+static boolean fail_test(LiVESWidget *table, int row, gchar *ftext) {
+  LiVESWidget *label;
 #if GTK_CHECK_VERSION(3,10,0)
-  GtkWidget *image=lives_image_new_from_stock(LIVES_STOCK_REMOVE,LIVES_ICON_SIZE_LARGE_TOOLBAR);
+  LiVESWidget *image=lives_image_new_from_stock(LIVES_STOCK_REMOVE,LIVES_ICON_SIZE_LARGE_TOOLBAR);
 #else
-  GtkWidget *image=lives_image_new_from_stock(GTK_STOCK_CANCEL,LIVES_ICON_SIZE_LARGE_TOOLBAR);
+  LiVESWidget *image=lives_image_new_from_stock(GTK_STOCK_CANCEL,LIVES_ICON_SIZE_LARGE_TOOLBAR);
 #endif
 
   label=lives_standard_label_new(ftext);
 
-  lives_table_attach (LIVES_TABLE (table), label, 3, 4, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
+  lives_table_attach (LIVES_TABLE (table), label, 3, 4, row, row+1, (LiVESAttachOptions)0, (LiVESAttachOptions)0, 10, 10);
   lives_widget_show(label);
   
   // TRANSLATORS - as in "failed test"
   label=lives_standard_label_new(_("Failed"));
 
-  lives_table_attach (LIVES_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
+  lives_table_attach (LIVES_TABLE (table), label, 1, 2, row, row+1, (LiVESAttachOptions)0, (LiVESAttachOptions)0, 10, 10);
   lives_widget_show(label);
 
-  lives_table_attach (LIVES_TABLE (table), image, 2, 3, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 0, 10);
+  lives_table_attach (LIVES_TABLE (table), image, 2, 3, row, row+1, (LiVESAttachOptions)0, (LiVESAttachOptions)0, 0, 10);
   lives_widget_show(image);
 
   lives_widget_context_update();
@@ -511,15 +511,15 @@ LIVES_INLINE gchar *get_resource(gchar *fname) {
 
 
 boolean do_startup_tests(boolean tshoot) {
-  GtkWidget *dialog;
-  GtkWidget *dialog_vbox;
+  LiVESWidget *dialog;
+  LiVESWidget *dialog_vbox;
 
-  GtkWidget *label;
-  GtkWidget *table;
-  GtkWidget *okbutton;
-  GtkWidget *cancelbutton;
+  LiVESWidget *label;
+  LiVESWidget *table;
+  LiVESWidget *okbutton;
+  LiVESWidget *cancelbutton;
 
-  GtkAccelGroup *accel_group;
+  LiVESAccelGroup *accel_group;
 
   gchar *com,*rname,*afile,*tmp;
   gchar *image_ext=g_strdup(prefs->image_ext);
@@ -558,7 +558,7 @@ boolean do_startup_tests(boolean tshoot) {
 
   dialog = lives_standard_dialog_new (title,FALSE);
 
-  accel_group = GTK_ACCEL_GROUP(lives_accel_group_new ());
+  accel_group = LIVES_ACCEL_GROUP(lives_accel_group_new ());
   lives_window_add_accel_group (LIVES_WINDOW (dialog), accel_group);
 
   g_free(title);
@@ -568,20 +568,20 @@ boolean do_startup_tests(boolean tshoot) {
   label=lives_standard_label_new(_("LiVES will now run some basic configuration tests\n"));
   lives_container_add (LIVES_CONTAINER (dialog_vbox), label);
 
-  cancelbutton = lives_button_new_from_stock ("gtk-cancel");
+  cancelbutton = lives_button_new_from_stock (LIVES_STOCK_CANCEL);
   lives_widget_show (cancelbutton);
-  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), cancelbutton, GTK_RESPONSE_CANCEL);
+  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), cancelbutton, LIVES_RESPONSE_CANCEL);
 
-  lives_widget_add_accelerator (cancelbutton, "activate", accel_group,
-                              LIVES_KEY_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
+  lives_widget_add_accelerator (cancelbutton, LIVES_WIDGET_CLICKED_EVENT, accel_group,
+                              LIVES_KEY_Escape, (LiVESXModifierType)0, (LiVESAccelFlags)0);
 
   if (!tshoot) {
-    okbutton = lives_button_new_from_stock ("gtk-go-forward");
-    lives_button_set_label(GTK_BUTTON(okbutton),_("_Next"));
+    okbutton = lives_button_new_from_stock (LIVES_STOCK_GO_FORWARD);
+    lives_button_set_label(LIVES_BUTTON(okbutton),_("_Next"));
   }
-  else okbutton = lives_button_new_from_stock ("gtk-ok");
+  else okbutton = lives_button_new_from_stock (LIVES_STOCK_OK);
   lives_widget_show (okbutton);
-  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), okbutton, GTK_RESPONSE_OK);
+  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), okbutton, LIVES_RESPONSE_OK);
   lives_widget_set_can_focus_and_default (okbutton);
   lives_widget_grab_default(okbutton);
   lives_widget_grab_focus(okbutton);
@@ -927,7 +927,7 @@ boolean do_startup_tests(boolean tshoot) {
     mainw->multitrack->idlefunc=mt_idle_add(mainw->multitrack);
   }
 
-  return (response==GTK_RESPONSE_OK);
+  return (response==LIVES_RESPONSE_OK);
 }
 
 
@@ -940,9 +940,9 @@ void do_startup_interface_query(void) {
   // prompt for startup ce or startup mt
 
 
-  GtkWidget *dialog,*dialog_vbox,*radiobutton0,*radiobutton1,*label;
-  GtkWidget *okbutton;
-  GtkWidget *hbox;
+  LiVESWidget *dialog,*dialog_vbox,*radiobutton0,*radiobutton1,*label;
+  LiVESWidget *okbutton;
+  LiVESWidget *hbox;
   GSList *radiobutton_group = NULL;
   gchar *txt1,*txt2,*txt3,*msg;
 
@@ -988,11 +988,11 @@ void do_startup_interface_query(void) {
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton1),TRUE);
   }
 
-  okbutton = lives_button_new_from_stock ("gtk-go-forward");
-  lives_button_set_label(GTK_BUTTON(okbutton),_("_Finish"));
+  okbutton = lives_button_new_from_stock (LIVES_STOCK_GO_FORWARD);
+  lives_button_set_label(LIVES_BUTTON(okbutton),_("_Finish"));
 
   lives_widget_show (okbutton);
-  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), okbutton, GTK_RESPONSE_OK);
+  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), okbutton, LIVES_RESPONSE_OK);
   lives_widget_set_can_focus_and_default (okbutton);
   lives_widget_grab_default(okbutton);
   lives_widget_grab_focus(okbutton);
@@ -1016,6 +1016,6 @@ void do_startup_interface_query(void) {
 
 
 
-void on_troubleshoot_activate (GtkMenuItem *menuitem, gpointer user_data) {
+void on_troubleshoot_activate (LiVESMenuItem *menuitem, gpointer user_data) {
   do_startup_tests(TRUE);
 }
