@@ -14,7 +14,7 @@ boolean do_audio_choice_dialog(short startup_phase);
 boolean do_startup_tests(boolean tshoot);
 void do_startup_interface_query(void);
 
-void on_troubleshoot_activate (GtkMenuItem *, gpointer);
+void on_troubleshoot_activate (LiVESMenuItem *, gpointer);
 
 
 #endif
