@@ -1001,7 +1001,7 @@ void weed_layer_set_from_lives2lives(weed_plant_t *layer, int clip, lives_vstrea
 
 // gui bits
 
-void on_send_lives2lives_activate (GtkMenuItem *menuitem, gpointer user_data) {
+void on_send_lives2lives_activate (LiVESMenuItem *menuitem, gpointer user_data) {
   _vppaw *vppa;
 
   gchar *orig_name=g_strdup(mainw->string_constants[LIVES_STRING_CONSTANT_NONE]);
@@ -1020,7 +1020,7 @@ void on_send_lives2lives_activate (GtkMenuItem *menuitem, gpointer user_data) {
   vppa=on_vpp_advanced_clicked(NULL,NULL);
   resp=lives_dialog_run(LIVES_DIALOG(vppa->dialog));
 
-  if (resp==GTK_RESPONSE_CANCEL) {
+  if (resp==LIVES_RESPONSE_CANCEL) {
     g_free(orig_name);
     return;
   }
@@ -1038,7 +1038,7 @@ void on_send_lives2lives_activate (GtkMenuItem *menuitem, gpointer user_data) {
 
 
 
-void on_open_lives2lives_activate (GtkMenuItem *menuitem, gpointer user_data) {
+void on_open_lives2lives_activate (LiVESMenuItem *menuitem, gpointer user_data) {
   lives_pandh_w *pandh=create_pandh_dialog(0);
 
   gchar *host=NULL;
@@ -1046,7 +1046,7 @@ void on_open_lives2lives_activate (GtkMenuItem *menuitem, gpointer user_data) {
   int port=0;
   int response=lives_dialog_run (LIVES_DIALOG (pandh->dialog));
 
-  if (response==GTK_RESPONSE_OK) {
+  if (response==LIVES_RESPONSE_OK) {
     if (!lives_toggle_button_get_active(LIVES_TOGGLE_BUTTON(pandh->rb_anyhost))) {
       host=g_strdup_printf("%s.%s.%s.%s",lives_entry_get_text(LIVES_ENTRY(pandh->entry1)),
 			   lives_entry_get_text(LIVES_ENTRY(pandh->entry2)),
@@ -1072,7 +1072,7 @@ void on_open_lives2lives_activate (GtkMenuItem *menuitem, gpointer user_data) {
 
 
 
-static void pandhw_anyhost_toggled(GtkToggleButton *tbut, gpointer user_data) {
+static void pandhw_anyhost_toggled(LiVESToggleButton *tbut, gpointer user_data) {
   lives_pandh_w *pandhw=(lives_pandh_w *)user_data;
 
   if (lives_toggle_button_get_active(tbut)) {
@@ -1094,9 +1094,9 @@ static void pandhw_anyhost_toggled(GtkToggleButton *tbut, gpointer user_data) {
 lives_pandh_w* create_pandh_dialog (int type) {
   // type = 0 lives2lives stream input
 
-  GtkWidget *dialog_vbox;
-  GtkWidget *hbox;
-  GtkWidget *label;
+  LiVESWidget *dialog_vbox;
+  LiVESWidget *hbox;
+  LiVESWidget *label;
 
   LiVESSList *radiobutton_group = NULL;
 
@@ -1107,7 +1107,7 @@ lives_pandh_w* create_pandh_dialog (int type) {
   pandhw->dialog = lives_standard_dialog_new (_("LiVES: - Receive LiVES stream"),TRUE);
 
   if (prefs->show_gui) {
-    lives_window_set_transient_for(LIVES_WINDOW(pandhw->dialog),GTK_WINDOW(mainw->LiVES));
+    lives_window_set_transient_for(LIVES_WINDOW(pandhw->dialog),LIVES_WINDOW(mainw->LiVES));
   }
 
   dialog_vbox = lives_dialog_get_content_area(LIVES_DIALOG(pandhw->dialog));
@@ -1133,8 +1133,8 @@ lives_pandh_w* create_pandh_dialog (int type) {
 
   g_free(tmp); g_free(tmp2);
 
-  g_signal_connect_after (GTK_OBJECT (pandhw->rb_anyhost), "toggled",
-			  G_CALLBACK (pandhw_anyhost_toggled),
+  lives_signal_connect_after (LIVES_GUI_OBJECT (pandhw->rb_anyhost), LIVES_WIDGET_TOGGLED_EVENT,
+			  LIVES_GUI_CALLBACK (pandhw_anyhost_toggled),
 			  (gpointer)pandhw);
 
   hbox = lives_hbox_new (FALSE, 0);
