@@ -43,21 +43,21 @@ typedef struct {
 
 
 void lives2lives_read_stream (const gchar *host, int port);
-void weed_layer_set_from_lives2lives (weed_plant_t *layer, gint clip, lives_vstream_t *lstream);
-void on_open_lives2lives_activate (GtkMenuItem *, gpointer);
-void on_send_lives2lives_activate (GtkMenuItem *, gpointer);
+void weed_layer_set_from_lives2lives (weed_plant_t *layer, int clip, lives_vstream_t *lstream);
+void on_open_lives2lives_activate (LiVESMenuItem *, gpointer);
+void on_send_lives2lives_activate (LiVESMenuItem *, gpointer);
 
 typedef struct {
-  GtkWidget *dialog;
-  GtkWidget *entry1;
-  GtkWidget *entry2;
-  GtkWidget *entry3;
-  GtkWidget *entry4;
-  GtkWidget *port_spin;
-  GtkWidget *rb_anyhost;
+  LiVESWidget *dialog;
+  LiVESWidget *entry1;
+  LiVESWidget *entry2;
+  LiVESWidget *entry3;
+  LiVESWidget *entry4;
+  LiVESWidget *port_spin;
+  LiVESWidget *rb_anyhost;
 } lives_pandh_w;
 
-lives_pandh_w* create_pandh_dialog (gint type);
+lives_pandh_w* create_pandh_dialog (int type);
 
 
 
